Class: TeamBattlesSdk::Generated::Game::Matches::Item::Forfeit::ForfeitRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/teambattles_sdk/generated/game/matches/item/forfeit/forfeit_request_builder.rb

Overview

Builds and executes requests for operations under #game#matches#matchId#forfeit

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new ForfeitRequestBuilder and sets the default values.

Parameters:

  • path_parameters

    Path parameters for the request

  • request_adapter

    The request adapter to use to execute the requests.



27
28
29
# File 'lib/teambattles_sdk/generated/game/matches/item/forfeit/forfeit_request_builder.rb', line 27

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/game/matches/{matchId}/forfeit")
end

Instance Method Details

#post(body, request_configuration = nil) ⇒ Object

Forfeits the match for the supplied team; the other participating team wins. Valid only while the match is ACCEPTED, READY, or IN_PROGRESS. Requires the game.lifecycle:read-write permission and a key bound to the match’s game. Supports an optional ‘Idempotency-Key` request header: a retry with the same key and body replays the original response, while the same key with a different body returns 409 error_idempotency_key_conflict.

Parameters:

  • body

    Request body for forfeiting a match on behalf of one participating team.

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of game_forfeit_response

Raises:

  • (StandardError)


36
37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/teambattles_sdk/generated/game/matches/item/forfeit/forfeit_request_builder.rb', line 36

def post(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_post_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["400"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) }
    error_mapping["401"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) }
    error_mapping["403"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) }
    error_mapping["404"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) }
    error_mapping["409"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) }
    error_mapping["429"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| TeamBattlesSdk::Generated::Models::GameForfeitResponse.create_from_discriminator_value(pn) }, error_mapping)
end

#to_post_request_information(body, request_configuration = nil) ⇒ Object

Forfeits the match for the supplied team; the other participating team wins. Valid only while the match is ACCEPTED, READY, or IN_PROGRESS. Requires the game.lifecycle:read-write permission and a key bound to the match’s game. Supports an optional ‘Idempotency-Key` request header: a retry with the same key and body replays the original response, while the same key with a different body returns 409 error_idempotency_key_conflict.

Parameters:

  • body

    Request body for forfeiting a match on behalf of one participating team.

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:

  • (StandardError)


56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/teambattles_sdk/generated/game/matches/item/forfeit/forfeit_request_builder.rb', line 56

def to_post_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, 'application/json', body)
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    request_info.headers.try_add('Accept', 'application/json')
    return request_info
end

#with_url(raw_url) ⇒ Object

Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.

Parameters:

  • raw_url

    The raw URL to use for the request builder.

Returns:

  • a forfeit_request_builder

Raises:

  • (StandardError)


75
76
77
78
# File 'lib/teambattles_sdk/generated/game/matches/item/forfeit/forfeit_request_builder.rb', line 75

def with_url(raw_url)
    raise StandardError, 'raw_url cannot be null' if raw_url.nil?
    return ForfeitRequestBuilder.new(raw_url, @request_adapter)
end