Class: TeamBattlesSdk::Generated::Game::Matches::Item::PlayerStats::PlayerStatsRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- TeamBattlesSdk::Generated::Game::Matches::Item::PlayerStats::PlayerStatsRequestBuilder
- Defined in:
- lib/teambattles_sdk/generated/game/matches/item/player_stats/player_stats_request_builder.rb
Overview
Builds and executes requests for operations under #game#matches#matchId#player-stats
Instance Method Summary collapse
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new PlayerStatsRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Sets per-player stats on an existing map score for the given mapIndex.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Sets per-player stats on an existing map score for the given mapIndex.
-
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new PlayerStatsRequestBuilder and sets the default values.
27 28 29 |
# File 'lib/teambattles_sdk/generated/game/matches/item/player_stats/player_stats_request_builder.rb', line 27 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/game/matches/{matchId}/player-stats") end |
Instance Method Details
#post(body, request_configuration = nil) ⇒ Object
Sets per-player stats on an existing map score for the given mapIndex. Requires the game.scores:write permission.
36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/teambattles_sdk/generated/game/matches/item/player_stats/player_stats_request_builder.rb', line 36 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["400"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["401"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["403"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["404"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| TeamBattlesSdk::Generated::Models::GamePlayerStatsResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Sets per-player stats on an existing map score for the given mapIndex. Requires the game.scores:write permission.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/teambattles_sdk/generated/game/matches/item/player_stats/player_stats_request_builder.rb', line 54 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, 'application/json', body) request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.try_add('Accept', 'application/json') return request_info end |
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
73 74 75 76 |
# File 'lib/teambattles_sdk/generated/game/matches/item/player_stats/player_stats_request_builder.rb', line 73 def with_url(raw_url) raise StandardError, 'raw_url cannot be null' if raw_url.nil? return PlayerStatsRequestBuilder.new(raw_url, @request_adapter) end |