Class: TeamBattlesSdk::Generated::Game::Matches::Item::Rosters::RostersRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- TeamBattlesSdk::Generated::Game::Matches::Item::Rosters::RostersRequestBuilder
- Defined in:
- lib/teambattles_sdk/generated/game/matches/item/rosters/rosters_request_builder.rb
Overview
Builds and executes requests for operations under #game#matches#matchId#rosters
Instance Method Summary collapse
-
#get(request_configuration = nil) ⇒ Object
Returns the creator and accepted team rosters for a match, validated to belong to the API key owner’s approved game.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new RostersRequestBuilder and sets the default values.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Returns the creator and accepted team rosters for a match, validated to belong to the API key owner’s approved game.
-
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new RostersRequestBuilder and sets the default values.
26 27 28 |
# File 'lib/teambattles_sdk/generated/game/matches/item/rosters/rosters_request_builder.rb', line 26 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/game/matches/{matchId}/rosters") end |
Instance Method Details
#get(request_configuration = nil) ⇒ Object
Returns the creator and accepted team rosters for a match, validated to belong to the API key owner’s approved game. Requires the game.lifecycle:read permission.
34 35 36 37 38 39 40 41 42 43 |
# File 'lib/teambattles_sdk/generated/game/matches/item/rosters/rosters_request_builder.rb', line 34 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["401"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["403"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["404"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| TeamBattlesSdk::Generated::Models::GameMatchRostersResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Returns the creator and accepted team rosters for a match, validated to belong to the API key owner’s approved game. Requires the game.lifecycle:read permission.
49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/teambattles_sdk/generated/game/matches/item/rosters/rosters_request_builder.rb', line 49 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.try_add('Accept', 'application/json') return request_info end |
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
66 67 68 69 |
# File 'lib/teambattles_sdk/generated/game/matches/item/rosters/rosters_request_builder.rb', line 66 def with_url(raw_url) raise StandardError, 'raw_url cannot be null' if raw_url.nil? return RostersRequestBuilder.new(raw_url, @request_adapter) end |