Class: TeamBattlesSdk::Generated::Game::Matches::MatchesPostResponsePagination::MatchesPostResponsePaginationCursor

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/teambattles_sdk/generated/game/matches/matches_post_response_pagination.rb

Overview

Composed type wrapper for classes MatchesPostResponsePaginationCursorMember1, string

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a matches_post_response_pagination_cursor

Raises:

  • (StandardError)


93
94
95
96
# File 'lib/teambattles_sdk/generated/game/matches/matches_post_response_pagination.rb', line 93

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return MatchesPostResponsePaginationCursor.new
end

Instance Method Details

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



101
102
103
104
105
106
# File 'lib/teambattles_sdk/generated/game/matches/matches_post_response_pagination.rb', line 101

def get_field_deserializers()
    return {
        "matchesPostResponse_pagination_cursorMember1" => lambda {|n| @matches_post_response_pagination_cursor_member1 = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Game::Matches::MatchesPostResponsePaginationCursorMember1.create_from_discriminator_value(pn) }) },
        "string" => lambda {|n| @string = n.get_string_value() },
    }
end

#matches_post_response_pagination_cursor_member1Object

Gets the matchesPostResponse_pagination_cursorMember1 property value. Composed type representation for type MatchesPostResponsePaginationCursorMember1

Returns:

  • a matches_post_response_pagination_cursor_member1



111
112
113
# File 'lib/teambattles_sdk/generated/game/matches/matches_post_response_pagination.rb', line 111

def matches_post_response_pagination_cursor_member1
    return @matches_post_response_pagination_cursor_member1
end

#matches_post_response_pagination_cursor_member1=(value) ⇒ Object

Sets the matchesPostResponse_pagination_cursorMember1 property value. Composed type representation for type MatchesPostResponsePaginationCursorMember1

Parameters:

  • value

    Value to set for the matchesPostResponse_pagination_cursorMember1 property.

Returns:

  • a void



119
120
121
# File 'lib/teambattles_sdk/generated/game/matches/matches_post_response_pagination.rb', line 119

def matches_post_response_pagination_cursor_member1=(value)
    @matches_post_response_pagination_cursor_member1 = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


127
128
129
130
131
# File 'lib/teambattles_sdk/generated/game/matches/matches_post_response_pagination.rb', line 127

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_object_value("matchesPostResponse_pagination_cursorMember1", @matches_post_response_pagination_cursor_member1)
    writer.write_string_value("string", @string)
end

#stringObject

Gets the string property value. Composed type representation for type string

Returns:

  • a string



136
137
138
# File 'lib/teambattles_sdk/generated/game/matches/matches_post_response_pagination.rb', line 136

def string
    return @string
end

#string=(value) ⇒ Object

Sets the string property value. Composed type representation for type string

Parameters:

  • value

    Value to set for the string property.

Returns:

  • a void



144
145
146
# File 'lib/teambattles_sdk/generated/game/matches/matches_post_response_pagination.rb', line 144

def string=(value)
    @string = value
end