Class: TeamBattlesSdk::Generated::Game::Matches::MatchesRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- TeamBattlesSdk::Generated::Game::Matches::MatchesRequestBuilder
- Defined in:
- lib/teambattles_sdk/generated/game/matches/matches_request_builder.rb
Overview
Builds and executes requests for operations under #game#matches
Instance Method Summary collapse
-
#batch_scores ⇒ Object
The batchScores property.
-
#by_match_id(match_id) ⇒ Object
Gets an item from the TeamBattlesSdk::Generated.game.matches.item collection.
-
#create ⇒ Object
The create property.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new MatchesRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Returns matches for the API key owner’s approved (bound) game, with legacy cursor pagination.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Returns matches for the API key owner’s approved (bound) game, with legacy cursor pagination.
-
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new MatchesRequestBuilder and sets the default values.
46 47 48 |
# File 'lib/teambattles_sdk/generated/game/matches/matches_request_builder.rb', line 46 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/game/matches") end |
Instance Method Details
#batch_scores ⇒ Object
The batchScores property
21 22 23 |
# File 'lib/teambattles_sdk/generated/game/matches/matches_request_builder.rb', line 21 def batch_scores() return TeamBattlesSdk::Generated::Game::Matches::BatchScores::BatchScoresRequestBuilder.new(@path_parameters, @request_adapter) end |
#by_match_id(match_id) ⇒ Object
Gets an item from the TeamBattlesSdk::Generated.game.matches.item collection
34 35 36 37 38 39 |
# File 'lib/teambattles_sdk/generated/game/matches/matches_request_builder.rb', line 34 def by_match_id(match_id) raise StandardError, 'match_id cannot be null' if match_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["matchId"] = match_id return TeamBattlesSdk::Generated::Game::Matches::Item::WithMatchItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#create ⇒ Object
The create property
26 27 28 |
# File 'lib/teambattles_sdk/generated/game/matches/matches_request_builder.rb', line 26 def create() return TeamBattlesSdk::Generated::Game::Matches::Create::CreateRequestBuilder.new(@path_parameters, @request_adapter) end |
#post(body, request_configuration = nil) ⇒ Object
Returns matches for the API key owner’s approved (bound) game, with legacy cursor pagination. Requires the game.lifecycle:read permission.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/teambattles_sdk/generated/game/matches/matches_request_builder.rb', line 55 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["400"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["401"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["403"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| TeamBattlesSdk::Generated::Game::Matches::MatchesPostResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Returns matches for the API key owner’s approved (bound) game, with legacy cursor pagination. Requires the game.lifecycle:read permission.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/teambattles_sdk/generated/game/matches/matches_request_builder.rb', line 72 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, 'application/json', body) request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.try_add('Accept', 'application/json') return request_info end |
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
91 92 93 94 |
# File 'lib/teambattles_sdk/generated/game/matches/matches_request_builder.rb', line 91 def with_url(raw_url) raise StandardError, 'raw_url cannot be null' if raw_url.nil? return MatchesRequestBuilder.new(raw_url, @request_adapter) end |