Class: TeamBattlesSdk::Generated::Leaderboards::Organizations::OrganizationsRequestBuilder::OrganizationsRequestBuilderGetQueryParameters
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Leaderboards::Organizations::OrganizationsRequestBuilder::OrganizationsRequestBuilderGetQueryParameters
- Defined in:
- lib/teambattles_sdk/generated/leaderboards/organizations/organizations_request_builder.rb
Overview
Returns active, public, non-disabled organizations ranked from active, enabled, non-private team stats. Requires orgs.profile:read.
Instance Attribute Summary collapse
-
#game_slug ⇒ Object
Returns the value of attribute game_slug.
-
#limit ⇒ Object
Returns the value of attribute limit.
-
#sort_by ⇒ Object
Returns the value of attribute sort_by.
Instance Method Summary collapse
-
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
Instance Attribute Details
#game_slug ⇒ Object
Returns the value of attribute game_slug.
88 89 90 |
# File 'lib/teambattles_sdk/generated/leaderboards/organizations/organizations_request_builder.rb', line 88 def game_slug @game_slug end |
#limit ⇒ Object
Returns the value of attribute limit.
89 90 91 |
# File 'lib/teambattles_sdk/generated/leaderboards/organizations/organizations_request_builder.rb', line 89 def limit @limit end |
#sort_by ⇒ Object
Returns the value of attribute sort_by.
90 91 92 |
# File 'lib/teambattles_sdk/generated/leaderboards/organizations/organizations_request_builder.rb', line 90 def sort_by @sort_by end |
Instance Method Details
#get_query_parameter(original_name) ⇒ Object
Maps the query parameters names to their encoded names for the URI template parsing.
96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/teambattles_sdk/generated/leaderboards/organizations/organizations_request_builder.rb', line 96 def get_query_parameter(original_name) raise StandardError, 'original_name cannot be null' if original_name.nil? case original_name when "game_slug" return "gameSlug" when "sort_by" return "sortBy" else return original_name end end |