Class: TeamBattlesSdk::Generated::Leagues::LeaguesRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- TeamBattlesSdk::Generated::Leagues::LeaguesRequestBuilder
- Defined in:
- lib/teambattles_sdk/generated/leagues/leagues_request_builder.rb
Overview
Builds and executes requests for operations under #leagues
Instance Method Summary collapse
-
#by_identifier(identifier) ⇒ Object
Gets an item from the TeamBattlesSdk::Generated.leagues.item collection.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new LeaguesRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Returns a paginated list of public leagues with optional search and game filtering.
-
#templates ⇒ Object
The templates property.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Returns a paginated list of public leagues with optional search and game filtering.
-
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new LeaguesRequestBuilder and sets the default values.
38 39 40 |
# File 'lib/teambattles_sdk/generated/leagues/leagues_request_builder.rb', line 38 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/leagues") end |
Instance Method Details
#by_identifier(identifier) ⇒ Object
Gets an item from the TeamBattlesSdk::Generated.leagues.item collection
26 27 28 29 30 31 |
# File 'lib/teambattles_sdk/generated/leagues/leagues_request_builder.rb', line 26 def by_identifier(identifier) raise StandardError, 'identifier cannot be null' if identifier.nil? url_tpl_params = @path_parameters.clone url_tpl_params["identifier"] = identifier return TeamBattlesSdk::Generated::Leagues::Item::WithIdentifierItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#post(body, request_configuration = nil) ⇒ Object
Returns a paginated list of public leagues with optional search and game filtering. Requires the leagues.league_public:read permission.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/teambattles_sdk/generated/leagues/leagues_request_builder.rb', line 47 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["400"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["401"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["403"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| TeamBattlesSdk::Generated::Leagues::LeaguesPostResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#templates ⇒ Object
The templates property
18 19 20 |
# File 'lib/teambattles_sdk/generated/leagues/leagues_request_builder.rb', line 18 def templates() return TeamBattlesSdk::Generated::Leagues::Templates::TemplatesRequestBuilder.new(@path_parameters, @request_adapter) end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Returns a paginated list of public leagues with optional search and game filtering. Requires the leagues.league_public:read permission.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/teambattles_sdk/generated/leagues/leagues_request_builder.rb', line 64 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, 'application/json', body) request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.try_add('Accept', 'application/json') return request_info end |
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
83 84 85 86 |
# File 'lib/teambattles_sdk/generated/leagues/leagues_request_builder.rb', line 83 def with_url(raw_url) raise StandardError, 'raw_url cannot be null' if raw_url.nil? return LeaguesRequestBuilder.new(raw_url, @request_adapter) end |