Class: TeamBattlesSdk::Generated::Matches::Item::Chat::ChatGetResponse::ChatGetResponseNextCursor

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/teambattles_sdk/generated/matches/item/chat/chat_get_response.rb

Overview

Composed type wrapper for classes ChatGetResponseNextCursorMember1, string

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a chat_get_response_next_cursor

Raises:

  • (StandardError)


151
152
153
154
# File 'lib/teambattles_sdk/generated/matches/item/chat/chat_get_response.rb', line 151

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return ChatGetResponseNextCursor.new
end

Instance Method Details

#chat_get_response_next_cursor_member1Object

Gets the chatGetResponse_nextCursorMember1 property value. Composed type representation for type ChatGetResponseNextCursorMember1

Returns:

  • a chat_get_response_next_cursor_member1



135
136
137
# File 'lib/teambattles_sdk/generated/matches/item/chat/chat_get_response.rb', line 135

def chat_get_response_next_cursor_member1
    return @chat_get_response_next_cursor_member1
end

#chat_get_response_next_cursor_member1=(value) ⇒ Object

Sets the chatGetResponse_nextCursorMember1 property value. Composed type representation for type ChatGetResponseNextCursorMember1

Parameters:

  • value

    Value to set for the chatGetResponse_nextCursorMember1 property.

Returns:

  • a void



143
144
145
# File 'lib/teambattles_sdk/generated/matches/item/chat/chat_get_response.rb', line 143

def chat_get_response_next_cursor_member1=(value)
    @chat_get_response_next_cursor_member1 = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



159
160
161
162
163
164
# File 'lib/teambattles_sdk/generated/matches/item/chat/chat_get_response.rb', line 159

def get_field_deserializers()
    return {
        "chatGetResponse_nextCursorMember1" => lambda {|n| @chat_get_response_next_cursor_member1 = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Matches::Item::Chat::ChatGetResponseNextCursorMember1.create_from_discriminator_value(pn) }) },
        "string" => lambda {|n| @string = n.get_string_value() },
    }
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


170
171
172
173
174
# File 'lib/teambattles_sdk/generated/matches/item/chat/chat_get_response.rb', line 170

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_object_value("chatGetResponse_nextCursorMember1", @chat_get_response_next_cursor_member1)
    writer.write_string_value("string", @string)
end

#stringObject

Gets the string property value. Composed type representation for type string

Returns:

  • a string



179
180
181
# File 'lib/teambattles_sdk/generated/matches/item/chat/chat_get_response.rb', line 179

def string
    return @string
end

#string=(value) ⇒ Object

Sets the string property value. Composed type representation for type string

Parameters:

  • value

    Value to set for the string property.

Returns:

  • a void



187
188
189
# File 'lib/teambattles_sdk/generated/matches/item/chat/chat_get_response.rb', line 187

def string=(value)
    @string = value
end