Class: TeamBattlesSdk::Generated::Models::AcceptMatchResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::AcceptMatchResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/accept_match_response.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#acceptance_id ⇒ Object
Gets the acceptanceId property value.
-
#acceptance_id=(value) ⇒ Object
Sets the acceptanceId property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#success ⇒ Object
Gets the success property value.
-
#success=(value) ⇒ Object
Sets the success property value.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
39 40 41 42 |
# File 'lib/teambattles_sdk/generated/models/accept_match_response.rb', line 39 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return AcceptMatchResponse.new end |
Instance Method Details
#acceptance_id ⇒ Object
Gets the acceptanceId property value. The acceptanceId property
23 24 25 |
# File 'lib/teambattles_sdk/generated/models/accept_match_response.rb', line 23 def acceptance_id return @acceptance_id end |
#acceptance_id=(value) ⇒ Object
Sets the acceptanceId property value. The acceptanceId property
31 32 33 |
# File 'lib/teambattles_sdk/generated/models/accept_match_response.rb', line 31 def acceptance_id=(value) @acceptance_id = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
47 48 49 50 51 52 53 |
# File 'lib/teambattles_sdk/generated/models/accept_match_response.rb', line 47 def get_field_deserializers() return { "acceptanceId" => lambda {|n| @acceptance_id = n.get_string_value() }, "success" => lambda {|n| @success = n.get_boolean_value() }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
59 60 61 62 63 64 |
# File 'lib/teambattles_sdk/generated/models/accept_match_response.rb', line 59 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("acceptanceId", @acceptance_id) writer.write_boolean_value("success", @success) writer.write_string_value("timestamp", @timestamp) end |
#success ⇒ Object
Gets the success property value. The success property
69 70 71 |
# File 'lib/teambattles_sdk/generated/models/accept_match_response.rb', line 69 def success return @success end |
#success=(value) ⇒ Object
Sets the success property value. The success property
77 78 79 |
# File 'lib/teambattles_sdk/generated/models/accept_match_response.rb', line 77 def success=(value) @success = value end |
#timestamp ⇒ Object
Gets the timestamp property value. The timestamp property
84 85 86 |
# File 'lib/teambattles_sdk/generated/models/accept_match_response.rb', line 84 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. The timestamp property
92 93 94 |
# File 'lib/teambattles_sdk/generated/models/accept_match_response.rb', line 92 def (value) @timestamp = value end |