Class: TeamBattlesSdk::Generated::Models::AddLeagueGameRequestBody

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/teambattles_sdk/generated/models/add_league_game_request_body.rb

Overview

Adds a league game.

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new AddLeagueGameRequestBody and sets the default values.



37
38
39
# File 'lib/teambattles_sdk/generated/models/add_league_game_request_body.rb', line 37

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a add_league_game_request_body

Raises:

  • (StandardError)


45
46
47
48
# File 'lib/teambattles_sdk/generated/models/add_league_game_request_body.rb', line 45

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return AddLeagueGameRequestBody.new
end

Instance Method Details

#additional_dataObject

Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



22
23
24
# File 'lib/teambattles_sdk/generated/models/add_league_game_request_body.rb', line 22

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the AdditionalData property.

Returns:

  • a void



30
31
32
# File 'lib/teambattles_sdk/generated/models/add_league_game_request_body.rb', line 30

def additional_data=(value)
    @additional_data = value
end

#game_idObject

Gets the gameId property value. Game ID to add to the league.

Returns:

  • a string



53
54
55
# File 'lib/teambattles_sdk/generated/models/add_league_game_request_body.rb', line 53

def game_id
    return @game_id
end

#game_id=(value) ⇒ Object

Sets the gameId property value. Game ID to add to the league.

Parameters:

  • value

    Value to set for the gameId property.

Returns:

  • a void



61
62
63
# File 'lib/teambattles_sdk/generated/models/add_league_game_request_body.rb', line 61

def game_id=(value)
    @game_id = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



68
69
70
71
72
# File 'lib/teambattles_sdk/generated/models/add_league_game_request_body.rb', line 68

def get_field_deserializers()
    return {
        "gameId" => lambda {|n| @game_id = n.get_string_value() },
    }
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


78
79
80
81
82
# File 'lib/teambattles_sdk/generated/models/add_league_game_request_body.rb', line 78

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("gameId", @game_id)
    writer.write_additional_data(@additional_data)
end