Class: TeamBattlesSdk::Generated::Models::AnnounceLeagueResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::AnnounceLeagueResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/announce_league_response.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#notified ⇒ Object
Gets the notified property value.
-
#notified=(value) ⇒ Object
Sets the notified property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#success ⇒ Object
Gets the success property value.
-
#success=(value) ⇒ Object
Sets the success property value.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
24 25 26 27 |
# File 'lib/teambattles_sdk/generated/models/announce_league_response.rb', line 24 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return AnnounceLeagueResponse.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
32 33 34 35 36 37 38 |
# File 'lib/teambattles_sdk/generated/models/announce_league_response.rb', line 32 def get_field_deserializers() return { "notified" => lambda {|n| @notified = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) }, "success" => lambda {|n| @success = n.get_boolean_value() }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, } end |
#notified ⇒ Object
Gets the notified property value. Number of members notified by the announcement.
43 44 45 |
# File 'lib/teambattles_sdk/generated/models/announce_league_response.rb', line 43 def notified return @notified end |
#notified=(value) ⇒ Object
Sets the notified property value. Number of members notified by the announcement.
51 52 53 |
# File 'lib/teambattles_sdk/generated/models/announce_league_response.rb', line 51 def notified=(value) @notified = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
59 60 61 62 63 64 |
# File 'lib/teambattles_sdk/generated/models/announce_league_response.rb', line 59 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("notified", @notified) writer.write_boolean_value("success", @success) writer.write_string_value("timestamp", @timestamp) end |
#success ⇒ Object
Gets the success property value. The success property
69 70 71 |
# File 'lib/teambattles_sdk/generated/models/announce_league_response.rb', line 69 def success return @success end |
#success=(value) ⇒ Object
Sets the success property value. The success property
77 78 79 |
# File 'lib/teambattles_sdk/generated/models/announce_league_response.rb', line 77 def success=(value) @success = value end |
#timestamp ⇒ Object
Gets the timestamp property value. Response generation time (ISO 8601).
84 85 86 |
# File 'lib/teambattles_sdk/generated/models/announce_league_response.rb', line 84 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. Response generation time (ISO 8601).
92 93 94 |
# File 'lib/teambattles_sdk/generated/models/announce_league_response.rb', line 92 def (value) @timestamp = value end |