Class: TeamBattlesSdk::Generated::Models::ApiGameCatalogEntry::ApiGameCatalogEntryDescriptionKey
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::ApiGameCatalogEntry::ApiGameCatalogEntryDescriptionKey
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/api_game_catalog_entry.rb
Overview
Composed type wrapper for classes ApiGameCatalogEntryDescriptionKeyMember1, string
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#api_game_catalog_entry_description_key_member1 ⇒ Object
Gets the ApiGameCatalogEntry_descriptionKeyMember1 property value.
-
#api_game_catalog_entry_description_key_member1=(value) ⇒ Object
Sets the ApiGameCatalogEntry_descriptionKeyMember1 property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#string ⇒ Object
Gets the string property value.
-
#string=(value) ⇒ Object
Sets the string property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
621 622 623 624 |
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_entry.rb', line 621 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ApiGameCatalogEntryDescriptionKey.new end |
Instance Method Details
#api_game_catalog_entry_description_key_member1 ⇒ Object
Gets the ApiGameCatalogEntry_descriptionKeyMember1 property value. Composed type representation for type ApiGameCatalogEntryDescriptionKeyMember1
605 606 607 |
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_entry.rb', line 605 def api_game_catalog_entry_description_key_member1 return @api_game_catalog_entry_description_key_member1 end |
#api_game_catalog_entry_description_key_member1=(value) ⇒ Object
Sets the ApiGameCatalogEntry_descriptionKeyMember1 property value. Composed type representation for type ApiGameCatalogEntryDescriptionKeyMember1
613 614 615 |
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_entry.rb', line 613 def api_game_catalog_entry_description_key_member1=(value) @api_game_catalog_entry_description_key_member1 = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
629 630 631 632 633 634 |
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_entry.rb', line 629 def get_field_deserializers() return { "ApiGameCatalogEntry_descriptionKeyMember1" => lambda {|n| @api_game_catalog_entry_description_key_member1 = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiGameCatalogEntryDescriptionKeyMember1.create_from_discriminator_value(pn) }) }, "string" => lambda {|n| @string = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
640 641 642 643 644 |
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_entry.rb', line 640 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("ApiGameCatalogEntry_descriptionKeyMember1", @api_game_catalog_entry_description_key_member1) writer.write_string_value("string", @string) end |
#string ⇒ Object
Gets the string property value. Composed type representation for type string
649 650 651 |
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_entry.rb', line 649 def string return @string end |
#string=(value) ⇒ Object
Sets the string property value. Composed type representation for type string
657 658 659 |
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_entry.rb', line 657 def string=(value) @string = value end |