Class: TeamBattlesSdk::Generated::Models::ApiGameCatalogResponse

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/teambattles_sdk/generated/models/api_game_catalog_response.rb

Overview

Game catalog list response.

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a api_game_catalog_response

Raises:

  • (StandardError)


26
27
28
29
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_response.rb', line 26

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return ApiGameCatalogResponse.new
end

Instance Method Details

#gamesObject

Gets the games property value. The games property

Returns:

  • a api_game_catalog_entry



34
35
36
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_response.rb', line 34

def games
    return @games
end

#games=(value) ⇒ Object

Sets the games property value. The games property

Parameters:

  • value

    Value to set for the games property.

Returns:

  • a void



42
43
44
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_response.rb', line 42

def games=(value)
    @games = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



49
50
51
52
53
54
55
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_response.rb', line 49

def get_field_deserializers()
    return {
        "games" => lambda {|n| @games = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiGameCatalogEntry.create_from_discriminator_value(pn) }) },
        "objectives" => lambda {|n| @objectives = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiObjective.create_from_discriminator_value(pn) }) },
        "timestamp" => lambda {|n| @timestamp = n.get_string_value() },
    }
end

#objectivesObject

Gets the objectives property value. The objectives property

Returns:

  • a api_objective



60
61
62
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_response.rb', line 60

def objectives
    return @objectives
end

#objectives=(value) ⇒ Object

Sets the objectives property value. The objectives property

Parameters:

  • value

    Value to set for the objectives property.

Returns:

  • a void



68
69
70
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_response.rb', line 68

def objectives=(value)
    @objectives = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


76
77
78
79
80
81
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_response.rb', line 76

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_collection_of_object_values("games", @games)
    writer.write_collection_of_object_values("objectives", @objectives)
    writer.write_string_value("timestamp", @timestamp)
end

#timestampObject

Gets the timestamp property value. The timestamp property

Returns:

  • a string



86
87
88
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_response.rb', line 86

def timestamp
    return @timestamp
end

#timestamp=(value) ⇒ Object

Sets the timestamp property value. The timestamp property

Parameters:

  • value

    Value to set for the timestamp property.

Returns:

  • a void



94
95
96
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_response.rb', line 94

def timestamp=(value)
    @timestamp = value
end