Class: TeamBattlesSdk::Generated::Models::ApiGameModeMapPool
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::ApiGameModeMapPool
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/api_game_mode_map_pool.rb
Overview
Game-scoped map pool for a single mode.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#map_ids ⇒ Object
Gets the mapIds property value.
-
#map_ids=(value) ⇒ Object
Sets the mapIds property value.
-
#mode_id ⇒ Object
Gets the modeId property value.
-
#mode_id=(value) ⇒ Object
Sets the modeId property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
23 24 25 26 |
# File 'lib/teambattles_sdk/generated/models/api_game_mode_map_pool.rb', line 23 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ApiGameModeMapPool.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
31 32 33 34 35 36 |
# File 'lib/teambattles_sdk/generated/models/api_game_mode_map_pool.rb', line 31 def get_field_deserializers() return { "mapIds" => lambda {|n| @map_ids = n.get_collection_of_primitive_values(String) }, "modeId" => lambda {|n| @mode_id = n.get_string_value() }, } end |
#map_ids ⇒ Object
Gets the mapIds property value. The mapIds property
41 42 43 |
# File 'lib/teambattles_sdk/generated/models/api_game_mode_map_pool.rb', line 41 def map_ids return @map_ids end |
#map_ids=(value) ⇒ Object
Sets the mapIds property value. The mapIds property
49 50 51 |
# File 'lib/teambattles_sdk/generated/models/api_game_mode_map_pool.rb', line 49 def map_ids=(value) @map_ids = value end |
#mode_id ⇒ Object
Gets the modeId property value. The modeId property
56 57 58 |
# File 'lib/teambattles_sdk/generated/models/api_game_mode_map_pool.rb', line 56 def mode_id return @mode_id end |
#mode_id=(value) ⇒ Object
Sets the modeId property value. The modeId property
64 65 66 |
# File 'lib/teambattles_sdk/generated/models/api_game_mode_map_pool.rb', line 64 def mode_id=(value) @mode_id = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
72 73 74 75 76 |
# File 'lib/teambattles_sdk/generated/models/api_game_mode_map_pool.rb', line 72 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_collection_of_primitive_values("mapIds", @map_ids) writer.write_string_value("modeId", @mode_id) end |