Class: TeamBattlesSdk::Generated::Models::ApiMatchDetail
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::ApiMatchDetail
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/api_match_detail.rb
Overview
Participant-gated SP-2 match detail. Lobby codes are intentionally omitted.
Defined Under Namespace
Classes: ApiMatchDetailCompletedAt, ApiMatchDetailCreatedAt, ApiMatchDetailLeagueId, ApiMatchDetailLeagueSeasonId, ApiMatchDetailMatchType, ApiMatchDetailPlatform, ApiMatchDetailRegion, ApiMatchDetailScheduledAt, ApiMatchDetailStartedAt, ApiMatchDetailWinnerTeamId
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#accepted_team ⇒ Object
Gets the acceptedTeam property value.
-
#accepted_team=(value) ⇒ Object
Sets the acceptedTeam property value.
-
#best_of ⇒ Object
Gets the bestOf property value.
-
#best_of=(value) ⇒ Object
Sets the bestOf property value.
-
#challenged_team ⇒ Object
Gets the challengedTeam property value.
-
#challenged_team=(value) ⇒ Object
Sets the challengedTeam property value.
-
#completed_at ⇒ Object
Gets the completedAt property value.
-
#completed_at=(value) ⇒ Object
Sets the completedAt property value.
-
#created_at ⇒ Object
Gets the createdAt property value.
-
#created_at=(value) ⇒ Object
Sets the createdAt property value.
-
#creator_team ⇒ Object
Gets the creatorTeam property value.
-
#creator_team=(value) ⇒ Object
Sets the creatorTeam property value.
-
#game ⇒ Object
Gets the game property value.
-
#game=(value) ⇒ Object
Sets the game property value.
-
#game_mode ⇒ Object
Gets the gameMode property value.
-
#game_mode=(value) ⇒ Object
Sets the gameMode property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#id ⇒ Object
Gets the id property value.
-
#id=(value) ⇒ Object
Sets the id property value.
-
#league_id ⇒ Object
Gets the leagueId property value.
-
#league_id=(value) ⇒ Object
Sets the leagueId property value.
-
#league_season_id ⇒ Object
Gets the leagueSeasonId property value.
-
#league_season_id=(value) ⇒ Object
Sets the leagueSeasonId property value.
-
#match_type ⇒ Object
Gets the matchType property value.
-
#match_type=(value) ⇒ Object
Sets the matchType property value.
-
#platform ⇒ Object
Gets the platform property value.
-
#platform=(value) ⇒ Object
Sets the platform property value.
-
#publish_status ⇒ Object
Gets the publishStatus property value.
-
#publish_status=(value) ⇒ Object
Sets the publishStatus property value.
-
#region ⇒ Object
Gets the region property value.
-
#region=(value) ⇒ Object
Sets the region property value.
-
#scheduled_at ⇒ Object
Gets the scheduledAt property value.
-
#scheduled_at=(value) ⇒ Object
Sets the scheduledAt property value.
-
#selected_maps ⇒ Object
Gets the selectedMaps property value.
-
#selected_maps=(value) ⇒ Object
Sets the selectedMaps property value.
-
#selected_objectives ⇒ Object
Gets the selectedObjectives property value.
-
#selected_objectives=(value) ⇒ Object
Sets the selectedObjectives property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#started_at ⇒ Object
Gets the startedAt property value.
-
#started_at=(value) ⇒ Object
Sets the startedAt property value.
-
#status ⇒ Object
Gets the status property value.
-
#status=(value) ⇒ Object
Sets the status property value.
-
#team_size ⇒ Object
Gets the teamSize property value.
-
#team_size=(value) ⇒ Object
Sets the teamSize property value.
-
#winner_team_id ⇒ Object
Gets the winnerTeamId property value.
-
#winner_team_id=(value) ⇒ Object
Sets the winnerTeamId property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
158 159 160 161 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 158 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ApiMatchDetail.new end |
Instance Method Details
#accepted_team ⇒ Object
Gets the acceptedTeam property value. The acceptedTeam property
82 83 84 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 82 def accepted_team return @accepted_team end |
#accepted_team=(value) ⇒ Object
Sets the acceptedTeam property value. The acceptedTeam property
90 91 92 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 90 def accepted_team=(value) @accepted_team = value end |
#best_of ⇒ Object
Gets the bestOf property value. The bestOf property
97 98 99 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 97 def best_of return @best_of end |
#best_of=(value) ⇒ Object
Sets the bestOf property value. The bestOf property
105 106 107 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 105 def best_of=(value) @best_of = value end |
#challenged_team ⇒ Object
Gets the challengedTeam property value. The challengedTeam property
112 113 114 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 112 def challenged_team return @challenged_team end |
#challenged_team=(value) ⇒ Object
Sets the challengedTeam property value. The challengedTeam property
120 121 122 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 120 def challenged_team=(value) @challenged_team = value end |
#completed_at ⇒ Object
Gets the completedAt property value. The completedAt property
127 128 129 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 127 def completed_at return @completed_at end |
#completed_at=(value) ⇒ Object
Sets the completedAt property value. The completedAt property
135 136 137 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 135 def completed_at=(value) @completed_at = value end |
#created_at ⇒ Object
Gets the createdAt property value. The createdAt property
142 143 144 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 142 def created_at return @created_at end |
#created_at=(value) ⇒ Object
Sets the createdAt property value. The createdAt property
150 151 152 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 150 def created_at=(value) @created_at = value end |
#creator_team ⇒ Object
Gets the creatorTeam property value. The creatorTeam property
166 167 168 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 166 def creator_team return @creator_team end |
#creator_team=(value) ⇒ Object
Sets the creatorTeam property value. The creatorTeam property
174 175 176 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 174 def creator_team=(value) @creator_team = value end |
#game ⇒ Object
Gets the game property value. Game definition.
181 182 183 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 181 def game return @game end |
#game=(value) ⇒ Object
Sets the game property value. Game definition.
189 190 191 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 189 def game=(value) @game = value end |
#game_mode ⇒ Object
Gets the gameMode property value. The gameMode property
196 197 198 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 196 def game_mode return @game_mode end |
#game_mode=(value) ⇒ Object
Sets the gameMode property value. The gameMode property
204 205 206 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 204 def game_mode=(value) @game_mode = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 211 def get_field_deserializers() return { "acceptedTeam" => lambda {|n| @accepted_team = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiMatchTeam.create_from_discriminator_value(pn) }) }, "bestOf" => lambda {|n| @best_of = n.get_number_value() }, "challengedTeam" => lambda {|n| @challenged_team = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiMatchTeam.create_from_discriminator_value(pn) }) }, "completedAt" => lambda {|n| @completed_at = n.get_object_value(lambda {|pn| ApiMatchDetail::ApiMatchDetailCompletedAt.create_from_discriminator_value(pn) }) }, "createdAt" => lambda {|n| @created_at = n.get_object_value(lambda {|pn| ApiMatchDetail::ApiMatchDetailCreatedAt.create_from_discriminator_value(pn) }) }, "creatorTeam" => lambda {|n| @creator_team = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiMatchTeam.create_from_discriminator_value(pn) }) }, "game" => lambda {|n| @game = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::Game.create_from_discriminator_value(pn) }) }, "gameMode" => lambda {|n| @game_mode = n.get_string_value() }, "id" => lambda {|n| @id = n.get_string_value() }, "leagueId" => lambda {|n| @league_id = n.get_object_value(lambda {|pn| ApiMatchDetail::ApiMatchDetailLeagueId.create_from_discriminator_value(pn) }) }, "leagueSeasonId" => lambda {|n| @league_season_id = n.get_object_value(lambda {|pn| ApiMatchDetail::ApiMatchDetailLeagueSeasonId.create_from_discriminator_value(pn) }) }, "matchType" => lambda {|n| @match_type = n.get_object_value(lambda {|pn| ApiMatchDetail::ApiMatchDetailMatchType.create_from_discriminator_value(pn) }) }, "platform" => lambda {|n| @platform = n.get_object_value(lambda {|pn| ApiMatchDetail::ApiMatchDetailPlatform.create_from_discriminator_value(pn) }) }, "publishStatus" => lambda {|n| @publish_status = n.get_string_value() }, "region" => lambda {|n| @region = n.get_object_value(lambda {|pn| ApiMatchDetail::ApiMatchDetailRegion.create_from_discriminator_value(pn) }) }, "scheduledAt" => lambda {|n| @scheduled_at = n.get_object_value(lambda {|pn| ApiMatchDetail::ApiMatchDetailScheduledAt.create_from_discriminator_value(pn) }) }, "selectedMaps" => lambda {|n| @selected_maps = n.get_collection_of_primitive_values(String) }, "selectedObjectives" => lambda {|n| @selected_objectives = n.get_collection_of_primitive_values(String) }, "startedAt" => lambda {|n| @started_at = n.get_object_value(lambda {|pn| ApiMatchDetail::ApiMatchDetailStartedAt.create_from_discriminator_value(pn) }) }, "status" => lambda {|n| @status = n.get_enum_value(TeamBattlesSdk::Generated::Models::MatchStatus) }, "teamSize" => lambda {|n| @team_size = n.get_number_value() }, "winnerTeamId" => lambda {|n| @winner_team_id = n.get_object_value(lambda {|pn| ApiMatchDetail::ApiMatchDetailWinnerTeamId.create_from_discriminator_value(pn) }) }, } end |
#id ⇒ Object
Gets the id property value. The id property
241 242 243 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 241 def id return @id end |
#id=(value) ⇒ Object
Sets the id property value. The id property
249 250 251 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 249 def id=(value) @id = value end |
#league_id ⇒ Object
Gets the leagueId property value. The leagueId property
256 257 258 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 256 def league_id return @league_id end |
#league_id=(value) ⇒ Object
Sets the leagueId property value. The leagueId property
264 265 266 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 264 def league_id=(value) @league_id = value end |
#league_season_id ⇒ Object
Gets the leagueSeasonId property value. The leagueSeasonId property
271 272 273 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 271 def league_season_id return @league_season_id end |
#league_season_id=(value) ⇒ Object
Sets the leagueSeasonId property value. The leagueSeasonId property
279 280 281 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 279 def league_season_id=(value) @league_season_id = value end |
#match_type ⇒ Object
Gets the matchType property value. The matchType property
286 287 288 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 286 def match_type return @match_type end |
#match_type=(value) ⇒ Object
Sets the matchType property value. The matchType property
294 295 296 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 294 def match_type=(value) @match_type = value end |
#platform ⇒ Object
Gets the platform property value. The platform property
301 302 303 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 301 def platform return @platform end |
#platform=(value) ⇒ Object
Sets the platform property value. The platform property
309 310 311 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 309 def platform=(value) @platform = value end |
#publish_status ⇒ Object
Gets the publishStatus property value. The publishStatus property
316 317 318 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 316 def publish_status return @publish_status end |
#publish_status=(value) ⇒ Object
Sets the publishStatus property value. The publishStatus property
324 325 326 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 324 def publish_status=(value) @publish_status = value end |
#region ⇒ Object
Gets the region property value. The region property
331 332 333 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 331 def region return @region end |
#region=(value) ⇒ Object
Sets the region property value. The region property
339 340 341 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 339 def region=(value) @region = value end |
#scheduled_at ⇒ Object
Gets the scheduledAt property value. The scheduledAt property
346 347 348 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 346 def scheduled_at return @scheduled_at end |
#scheduled_at=(value) ⇒ Object
Sets the scheduledAt property value. The scheduledAt property
354 355 356 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 354 def scheduled_at=(value) @scheduled_at = value end |
#selected_maps ⇒ Object
Gets the selectedMaps property value. The selectedMaps property
361 362 363 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 361 def selected_maps return @selected_maps end |
#selected_maps=(value) ⇒ Object
Sets the selectedMaps property value. The selectedMaps property
369 370 371 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 369 def selected_maps=(value) @selected_maps = value end |
#selected_objectives ⇒ Object
Gets the selectedObjectives property value. The selectedObjectives property
376 377 378 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 376 def selected_objectives return @selected_objectives end |
#selected_objectives=(value) ⇒ Object
Sets the selectedObjectives property value. The selectedObjectives property
384 385 386 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 384 def selected_objectives=(value) @selected_objectives = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 392 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("acceptedTeam", @accepted_team) writer.write_number_value("bestOf", @best_of) writer.write_object_value("challengedTeam", @challenged_team) writer.write_object_value("completedAt", @completed_at) writer.write_object_value("createdAt", @created_at) writer.write_object_value("creatorTeam", @creator_team) writer.write_object_value("game", @game) writer.write_string_value("gameMode", @game_mode) writer.write_string_value("id", @id) writer.write_object_value("leagueId", @league_id) writer.write_object_value("leagueSeasonId", @league_season_id) writer.write_object_value("matchType", @match_type) writer.write_object_value("platform", @platform) writer.write_string_value("publishStatus", @publish_status) writer.write_object_value("region", @region) writer.write_object_value("scheduledAt", @scheduled_at) writer.write_collection_of_primitive_values("selectedMaps", @selected_maps) writer.write_collection_of_primitive_values("selectedObjectives", @selected_objectives) writer.write_object_value("startedAt", @started_at) writer.write_enum_value("status", @status) writer.write_number_value("teamSize", @team_size) writer.write_object_value("winnerTeamId", @winner_team_id) end |
#started_at ⇒ Object
Gets the startedAt property value. The startedAt property
421 422 423 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 421 def started_at return @started_at end |
#started_at=(value) ⇒ Object
Sets the startedAt property value. The startedAt property
429 430 431 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 429 def started_at=(value) @started_at = value end |
#status ⇒ Object
Gets the status property value. Lifecycle status of a match.
436 437 438 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 436 def status return @status end |
#status=(value) ⇒ Object
Sets the status property value. Lifecycle status of a match.
444 445 446 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 444 def status=(value) @status = value end |
#team_size ⇒ Object
Gets the teamSize property value. The teamSize property
451 452 453 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 451 def team_size return @team_size end |
#team_size=(value) ⇒ Object
Sets the teamSize property value. The teamSize property
459 460 461 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 459 def team_size=(value) @team_size = value end |
#winner_team_id ⇒ Object
Gets the winnerTeamId property value. The winnerTeamId property
466 467 468 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 466 def winner_team_id return @winner_team_id end |
#winner_team_id=(value) ⇒ Object
Sets the winnerTeamId property value. The winnerTeamId property
474 475 476 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 474 def winner_team_id=(value) @winner_team_id = value end |