Class: TeamBattlesSdk::Generated::Models::ApiMatchDetail::ApiMatchDetailLeagueId
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::ApiMatchDetail::ApiMatchDetailLeagueId
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/api_match_detail.rb
Overview
Composed type wrapper for classes ApiMatchDetailLeagueIdMember1, string
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#api_match_detail_league_id_member1 ⇒ Object
Gets the ApiMatchDetail_leagueIdMember1 property value.
-
#api_match_detail_league_id_member1=(value) ⇒ Object
Sets the ApiMatchDetail_leagueIdMember1 property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#string ⇒ Object
Gets the string property value.
-
#string=(value) ⇒ Object
Sets the string property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
650 651 652 653 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 650 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ApiMatchDetailLeagueId.new end |
Instance Method Details
#api_match_detail_league_id_member1 ⇒ Object
Gets the ApiMatchDetail_leagueIdMember1 property value. Composed type representation for type ApiMatchDetailLeagueIdMember1
634 635 636 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 634 def api_match_detail_league_id_member1 return @api_match_detail_league_id_member1 end |
#api_match_detail_league_id_member1=(value) ⇒ Object
Sets the ApiMatchDetail_leagueIdMember1 property value. Composed type representation for type ApiMatchDetailLeagueIdMember1
642 643 644 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 642 def api_match_detail_league_id_member1=(value) @api_match_detail_league_id_member1 = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
658 659 660 661 662 663 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 658 def get_field_deserializers() return { "ApiMatchDetail_leagueIdMember1" => lambda {|n| @api_match_detail_league_id_member1 = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiMatchDetailLeagueIdMember1.create_from_discriminator_value(pn) }) }, "string" => lambda {|n| @string = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
669 670 671 672 673 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 669 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("ApiMatchDetail_leagueIdMember1", @api_match_detail_league_id_member1) writer.write_string_value("string", @string) end |
#string ⇒ Object
Gets the string property value. Composed type representation for type string
678 679 680 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 678 def string return @string end |
#string=(value) ⇒ Object
Sets the string property value. Composed type representation for type string
686 687 688 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 686 def string=(value) @string = value end |