Class: TeamBattlesSdk::Generated::Models::ApiMatchDetail::ApiMatchDetailPlatform
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::ApiMatchDetail::ApiMatchDetailPlatform
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/api_match_detail.rb
Overview
Composed type wrapper for classes ApiMatchDetailPlatformMember1, string
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#api_match_detail_platform_member1 ⇒ Object
Gets the ApiMatchDetail_platformMember1 property value.
-
#api_match_detail_platform_member1=(value) ⇒ Object
Sets the ApiMatchDetail_platformMember1 property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#string ⇒ Object
Gets the string property value.
-
#string=(value) ⇒ Object
Sets the string property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
863 864 865 866 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 863 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ApiMatchDetailPlatform.new end |
Instance Method Details
#api_match_detail_platform_member1 ⇒ Object
Gets the ApiMatchDetail_platformMember1 property value. Composed type representation for type ApiMatchDetailPlatformMember1
847 848 849 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 847 def api_match_detail_platform_member1 return @api_match_detail_platform_member1 end |
#api_match_detail_platform_member1=(value) ⇒ Object
Sets the ApiMatchDetail_platformMember1 property value. Composed type representation for type ApiMatchDetailPlatformMember1
855 856 857 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 855 def api_match_detail_platform_member1=(value) @api_match_detail_platform_member1 = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
871 872 873 874 875 876 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 871 def get_field_deserializers() return { "ApiMatchDetail_platformMember1" => lambda {|n| @api_match_detail_platform_member1 = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiMatchDetailPlatformMember1.create_from_discriminator_value(pn) }) }, "string" => lambda {|n| @string = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
882 883 884 885 886 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 882 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("ApiMatchDetail_platformMember1", @api_match_detail_platform_member1) writer.write_string_value("string", @string) end |
#string ⇒ Object
Gets the string property value. Composed type representation for type string
891 892 893 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 891 def string return @string end |
#string=(value) ⇒ Object
Sets the string property value. Composed type representation for type string
899 900 901 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 899 def string=(value) @string = value end |