Class: TeamBattlesSdk::Generated::Models::ApiMatchDetail::ApiMatchDetailStartedAt
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::ApiMatchDetail::ApiMatchDetailStartedAt
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/api_match_detail.rb
Overview
Composed type wrapper for classes ApiMatchDetailStartedAtMember1, string
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#api_match_detail_started_at_member1 ⇒ Object
Gets the ApiMatchDetail_startedAtMember1 property value.
-
#api_match_detail_started_at_member1=(value) ⇒ Object
Sets the ApiMatchDetail_startedAtMember1 property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#string ⇒ Object
Gets the string property value.
-
#string=(value) ⇒ Object
Sets the string property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
1076 1077 1078 1079 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 1076 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ApiMatchDetailStartedAt.new end |
Instance Method Details
#api_match_detail_started_at_member1 ⇒ Object
Gets the ApiMatchDetail_startedAtMember1 property value. Composed type representation for type ApiMatchDetailStartedAtMember1
1060 1061 1062 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 1060 def api_match_detail_started_at_member1 return @api_match_detail_started_at_member1 end |
#api_match_detail_started_at_member1=(value) ⇒ Object
Sets the ApiMatchDetail_startedAtMember1 property value. Composed type representation for type ApiMatchDetailStartedAtMember1
1068 1069 1070 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 1068 def api_match_detail_started_at_member1=(value) @api_match_detail_started_at_member1 = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
1084 1085 1086 1087 1088 1089 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 1084 def get_field_deserializers() return { "ApiMatchDetail_startedAtMember1" => lambda {|n| @api_match_detail_started_at_member1 = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiMatchDetailStartedAtMember1.create_from_discriminator_value(pn) }) }, "string" => lambda {|n| @string = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
1095 1096 1097 1098 1099 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 1095 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("ApiMatchDetail_startedAtMember1", @api_match_detail_started_at_member1) writer.write_string_value("string", @string) end |
#string ⇒ Object
Gets the string property value. Composed type representation for type string
1104 1105 1106 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 1104 def string return @string end |
#string=(value) ⇒ Object
Sets the string property value. Composed type representation for type string
1112 1113 1114 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail.rb', line 1112 def string=(value) @string = value end |