Class: TeamBattlesSdk::Generated::Models::ApiMatchDetailResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::ApiMatchDetailResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/api_match_detail_response.rb
Overview
SP-2 match detail response.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#match ⇒ Object
Gets the match property value.
-
#match=(value) ⇒ Object
Sets the match property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
23 24 25 26 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail_response.rb', line 23 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ApiMatchDetailResponse.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
31 32 33 34 35 36 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail_response.rb', line 31 def get_field_deserializers() return { "match" => lambda {|n| @match = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiMatchDetail.create_from_discriminator_value(pn) }) }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, } end |
#match ⇒ Object
Gets the match property value. Participant-gated SP-2 match detail. Lobby codes are intentionally omitted.
41 42 43 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail_response.rb', line 41 def match return @match end |
#match=(value) ⇒ Object
Sets the match property value. Participant-gated SP-2 match detail. Lobby codes are intentionally omitted.
49 50 51 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail_response.rb', line 49 def match=(value) @match = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
57 58 59 60 61 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail_response.rb', line 57 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("match", @match) writer.write_string_value("timestamp", @timestamp) end |
#timestamp ⇒ Object
Gets the timestamp property value. The timestamp property
66 67 68 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail_response.rb', line 66 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. The timestamp property
74 75 76 |
# File 'lib/teambattles_sdk/generated/models/api_match_detail_response.rb', line 74 def (value) @timestamp = value end |