Class: TeamBattlesSdk::Generated::Models::ApiOrganizationStats
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::ApiOrganizationStats
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/api_organization_stats.rb
Overview
API-safe organization aggregate stats.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#losses ⇒ Object
Gets the losses property value.
-
#losses=(value) ⇒ Object
Sets the losses property value.
-
#matches_played ⇒ Object
Gets the matchesPlayed property value.
-
#matches_played=(value) ⇒ Object
Sets the matchesPlayed property value.
-
#members ⇒ Object
Gets the members property value.
-
#members=(value) ⇒ Object
Sets the members property value.
-
#organization_id ⇒ Object
Gets the organizationId property value.
-
#organization_id=(value) ⇒ Object
Sets the organizationId property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#teams ⇒ Object
Gets the teams property value.
-
#teams=(value) ⇒ Object
Sets the teams property value.
-
#win_rate ⇒ Object
Gets the winRate property value.
-
#win_rate=(value) ⇒ Object
Sets the winRate property value.
-
#wins ⇒ Object
Gets the wins property value.
-
#wins=(value) ⇒ Object
Sets the wins property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
38 39 40 41 |
# File 'lib/teambattles_sdk/generated/models/api_organization_stats.rb', line 38 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ApiOrganizationStats.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/teambattles_sdk/generated/models/api_organization_stats.rb', line 46 def get_field_deserializers() return { "losses" => lambda {|n| @losses = n.get_number_value() }, "matchesPlayed" => lambda {|n| @matches_played = n.get_number_value() }, "members" => lambda {|n| @members = n.get_number_value() }, "organizationId" => lambda {|n| @organization_id = n.get_string_value() }, "teams" => lambda {|n| @teams = n.get_number_value() }, "winRate" => lambda {|n| @win_rate = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) }, "wins" => lambda {|n| @wins = n.get_number_value() }, } end |
#losses ⇒ Object
Gets the losses property value. The losses property
61 62 63 |
# File 'lib/teambattles_sdk/generated/models/api_organization_stats.rb', line 61 def losses return @losses end |
#losses=(value) ⇒ Object
Sets the losses property value. The losses property
69 70 71 |
# File 'lib/teambattles_sdk/generated/models/api_organization_stats.rb', line 69 def losses=(value) @losses = value end |
#matches_played ⇒ Object
Gets the matchesPlayed property value. The matchesPlayed property
76 77 78 |
# File 'lib/teambattles_sdk/generated/models/api_organization_stats.rb', line 76 def matches_played return @matches_played end |
#matches_played=(value) ⇒ Object
Sets the matchesPlayed property value. The matchesPlayed property
84 85 86 |
# File 'lib/teambattles_sdk/generated/models/api_organization_stats.rb', line 84 def matches_played=(value) @matches_played = value end |
#members ⇒ Object
Gets the members property value. The members property
91 92 93 |
# File 'lib/teambattles_sdk/generated/models/api_organization_stats.rb', line 91 def members return @members end |
#members=(value) ⇒ Object
Sets the members property value. The members property
99 100 101 |
# File 'lib/teambattles_sdk/generated/models/api_organization_stats.rb', line 99 def members=(value) @members = value end |
#organization_id ⇒ Object
Gets the organizationId property value. The organizationId property
106 107 108 |
# File 'lib/teambattles_sdk/generated/models/api_organization_stats.rb', line 106 def organization_id return @organization_id end |
#organization_id=(value) ⇒ Object
Sets the organizationId property value. The organizationId property
114 115 116 |
# File 'lib/teambattles_sdk/generated/models/api_organization_stats.rb', line 114 def organization_id=(value) @organization_id = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
122 123 124 125 126 127 128 129 130 131 |
# File 'lib/teambattles_sdk/generated/models/api_organization_stats.rb', line 122 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("losses", @losses) writer.write_number_value("matchesPlayed", @matches_played) writer.write_number_value("members", @members) writer.write_string_value("organizationId", @organization_id) writer.write_number_value("teams", @teams) writer.write_object_value("winRate", @win_rate) writer.write_number_value("wins", @wins) end |
#teams ⇒ Object
Gets the teams property value. The teams property
136 137 138 |
# File 'lib/teambattles_sdk/generated/models/api_organization_stats.rb', line 136 def teams return @teams end |
#teams=(value) ⇒ Object
Sets the teams property value. The teams property
144 145 146 |
# File 'lib/teambattles_sdk/generated/models/api_organization_stats.rb', line 144 def teams=(value) @teams = value end |
#win_rate ⇒ Object
Gets the winRate property value. The winRate property
151 152 153 |
# File 'lib/teambattles_sdk/generated/models/api_organization_stats.rb', line 151 def win_rate return @win_rate end |
#win_rate=(value) ⇒ Object
Sets the winRate property value. The winRate property
159 160 161 |
# File 'lib/teambattles_sdk/generated/models/api_organization_stats.rb', line 159 def win_rate=(value) @win_rate = value end |
#wins ⇒ Object
Gets the wins property value. The wins property
166 167 168 |
# File 'lib/teambattles_sdk/generated/models/api_organization_stats.rb', line 166 def wins return @wins end |
#wins=(value) ⇒ Object
Sets the wins property value. The wins property
174 175 176 |
# File 'lib/teambattles_sdk/generated/models/api_organization_stats.rb', line 174 def wins=(value) @wins = value end |