Class: TeamBattlesSdk::Generated::Models::ApiStrategyEnvelope
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::ApiStrategyEnvelope
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/api_strategy_envelope.rb
Overview
Strategy plus a response timestamp.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#strategy ⇒ Object
Gets the strategy property value.
-
#strategy=(value) ⇒ Object
Sets the strategy property value.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
23 24 25 26 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_envelope.rb', line 23 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ApiStrategyEnvelope.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
31 32 33 34 35 36 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_envelope.rb', line 31 def get_field_deserializers() return { "strategy" => lambda {|n| @strategy = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiStrategy.create_from_discriminator_value(pn) }) }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
42 43 44 45 46 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_envelope.rb', line 42 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("strategy", @strategy) writer.write_string_value("timestamp", @timestamp) end |
#strategy ⇒ Object
Gets the strategy property value. API-safe shareable strategy.
51 52 53 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_envelope.rb', line 51 def strategy return @strategy end |
#strategy=(value) ⇒ Object
Sets the strategy property value. API-safe shareable strategy.
59 60 61 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_envelope.rb', line 59 def strategy=(value) @strategy = value end |
#timestamp ⇒ Object
Gets the timestamp property value. ISO 8601 timestamp.
66 67 68 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_envelope.rb', line 66 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. ISO 8601 timestamp.
74 75 76 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_envelope.rb', line 74 def (value) @timestamp = value end |