Class: TeamBattlesSdk::Generated::Models::ApiStrategyShape
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::ApiStrategyShape
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/api_strategy_shape.rb
Overview
API-safe strategy shape. Hidden working shapes are omitted from responses.
Defined Under Namespace
Classes: ApiStrategyShapeUpdatedAt
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#id ⇒ Object
Gets the id property value.
-
#id=(value) ⇒ Object
Sets the id property value.
-
#layer ⇒ Object
Gets the layer property value.
-
#layer=(value) ⇒ Object
Sets the layer property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#shape_id ⇒ Object
Gets the shapeId property value.
-
#shape_id=(value) ⇒ Object
Sets the shapeId property value.
-
#stage_id ⇒ Object
Gets the stageId property value.
-
#stage_id=(value) ⇒ Object
Sets the stageId property value.
-
#type ⇒ Object
Gets the type property value.
-
#type=(value) ⇒ Object
Sets the type property value.
-
#updated_at ⇒ Object
Gets the updatedAt property value.
-
#updated_at=(value) ⇒ Object
Sets the updatedAt property value.
-
#z_index ⇒ Object
Gets the zIndex property value.
-
#z_index=(value) ⇒ Object
Sets the zIndex property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
38 39 40 41 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_shape.rb', line 38 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ApiStrategyShape.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_shape.rb', line 46 def get_field_deserializers() return { "id" => lambda {|n| @id = n.get_string_value() }, "layer" => lambda {|n| @layer = n.get_enum_value(TeamBattlesSdk::Generated::Models::ApiStrategyShapeLayer) }, "shapeId" => lambda {|n| @shape_id = n.get_string_value() }, "stageId" => lambda {|n| @stage_id = n.get_string_value() }, "type" => lambda {|n| @type = n.get_enum_value(TeamBattlesSdk::Generated::Models::ApiStrategyShapeType) }, "updatedAt" => lambda {|n| @updated_at = n.get_object_value(lambda {|pn| ApiStrategyShape::ApiStrategyShapeUpdatedAt.create_from_discriminator_value(pn) }) }, "zIndex" => lambda {|n| @z_index = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) }, } end |
#id ⇒ Object
Gets the id property value. Shape row ID.
61 62 63 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_shape.rb', line 61 def id return @id end |
#id=(value) ⇒ Object
Sets the id property value. Shape row ID.
69 70 71 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_shape.rb', line 69 def id=(value) @id = value end |
#layer ⇒ Object
Gets the layer property value. Canvas layer the shape renders on.
76 77 78 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_shape.rb', line 76 def layer return @layer end |
#layer=(value) ⇒ Object
Sets the layer property value. Canvas layer the shape renders on.
84 85 86 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_shape.rb', line 84 def layer=(value) @layer = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
92 93 94 95 96 97 98 99 100 101 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_shape.rb', line 92 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("id", @id) writer.write_enum_value("layer", @layer) writer.write_string_value("shapeId", @shape_id) writer.write_string_value("stageId", @stage_id) writer.write_enum_value("type", @type) writer.write_object_value("updatedAt", @updated_at) writer.write_object_value("zIndex", @z_index) end |
#shape_id ⇒ Object
Gets the shapeId property value. Stable client-side shape id.
106 107 108 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_shape.rb', line 106 def shape_id return @shape_id end |
#shape_id=(value) ⇒ Object
Sets the shapeId property value. Stable client-side shape id.
114 115 116 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_shape.rb', line 114 def shape_id=(value) @shape_id = value end |
#stage_id ⇒ Object
Gets the stageId property value. Stage this shape belongs to.
121 122 123 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_shape.rb', line 121 def stage_id return @stage_id end |
#stage_id=(value) ⇒ Object
Sets the stageId property value. Stage this shape belongs to.
129 130 131 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_shape.rb', line 129 def stage_id=(value) @stage_id = value end |
#type ⇒ Object
Gets the type property value. Shape primitive type.
136 137 138 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_shape.rb', line 136 def type return @type end |
#type=(value) ⇒ Object
Sets the type property value. Shape primitive type.
144 145 146 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_shape.rb', line 144 def type=(value) @type = value end |
#updated_at ⇒ Object
Gets the updatedAt property value. The updatedAt property
151 152 153 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_shape.rb', line 151 def updated_at return @updated_at end |
#updated_at=(value) ⇒ Object
Sets the updatedAt property value. The updatedAt property
159 160 161 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_shape.rb', line 159 def updated_at=(value) @updated_at = value end |
#z_index ⇒ Object
Gets the zIndex property value. Stacking order within its layer.
166 167 168 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_shape.rb', line 166 def z_index return @z_index end |
#z_index=(value) ⇒ Object
Sets the zIndex property value. Stacking order within its layer.
174 175 176 |
# File 'lib/teambattles_sdk/generated/models/api_strategy_shape.rb', line 174 def z_index=(value) @z_index = value end |