Class: TeamBattlesSdk::Generated::Models::ApiTeamProfile::ApiTeamProfileOrganizationId
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::ApiTeamProfile::ApiTeamProfileOrganizationId
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/api_team_profile.rb
Overview
Composed type wrapper for classes ApiTeamProfileOrganizationIdMember1, string
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#api_team_profile_organization_id_member1 ⇒ Object
Gets the ApiTeamProfile_organizationIdMember1 property value.
-
#api_team_profile_organization_id_member1=(value) ⇒ Object
Sets the ApiTeamProfile_organizationIdMember1 property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#string ⇒ Object
Gets the string property value.
-
#string=(value) ⇒ Object
Sets the string property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
783 784 785 786 |
# File 'lib/teambattles_sdk/generated/models/api_team_profile.rb', line 783 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ApiTeamProfileOrganizationId.new end |
Instance Method Details
#api_team_profile_organization_id_member1 ⇒ Object
Gets the ApiTeamProfile_organizationIdMember1 property value. Composed type representation for type ApiTeamProfileOrganizationIdMember1
767 768 769 |
# File 'lib/teambattles_sdk/generated/models/api_team_profile.rb', line 767 def api_team_profile_organization_id_member1 return @api_team_profile_organization_id_member1 end |
#api_team_profile_organization_id_member1=(value) ⇒ Object
Sets the ApiTeamProfile_organizationIdMember1 property value. Composed type representation for type ApiTeamProfileOrganizationIdMember1
775 776 777 |
# File 'lib/teambattles_sdk/generated/models/api_team_profile.rb', line 775 def api_team_profile_organization_id_member1=(value) @api_team_profile_organization_id_member1 = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
791 792 793 794 795 796 |
# File 'lib/teambattles_sdk/generated/models/api_team_profile.rb', line 791 def get_field_deserializers() return { "ApiTeamProfile_organizationIdMember1" => lambda {|n| @api_team_profile_organization_id_member1 = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiTeamProfileOrganizationIdMember1.create_from_discriminator_value(pn) }) }, "string" => lambda {|n| @string = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
802 803 804 805 806 |
# File 'lib/teambattles_sdk/generated/models/api_team_profile.rb', line 802 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("ApiTeamProfile_organizationIdMember1", @api_team_profile_organization_id_member1) writer.write_string_value("string", @string) end |
#string ⇒ Object
Gets the string property value. Composed type representation for type string
811 812 813 |
# File 'lib/teambattles_sdk/generated/models/api_team_profile.rb', line 811 def string return @string end |
#string=(value) ⇒ Object
Sets the string property value. Composed type representation for type string
819 820 821 |
# File 'lib/teambattles_sdk/generated/models/api_team_profile.rb', line 819 def string=(value) @string = value end |