Class: TeamBattlesSdk::Generated::Models::ApiUserProfile
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::ApiUserProfile
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/api_user_profile.rb
Overview
API-safe public user profile.
Defined Under Namespace
Classes: ApiUserProfileAvatarUrl, ApiUserProfileBannerUrl, ApiUserProfileBio, ApiUserProfileCreatedAt, ApiUserProfileName, ApiUserProfileUsername
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#avatar_url ⇒ Object
Gets the avatarUrl property value.
-
#avatar_url=(value) ⇒ Object
Sets the avatarUrl property value.
-
#banner_url ⇒ Object
Gets the bannerUrl property value.
-
#banner_url=(value) ⇒ Object
Sets the bannerUrl property value.
-
#bio ⇒ Object
Gets the bio property value.
-
#bio=(value) ⇒ Object
Sets the bio property value.
-
#created_at ⇒ Object
Gets the createdAt property value.
-
#created_at=(value) ⇒ Object
Sets the createdAt property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#id ⇒ Object
Gets the id property value.
-
#id=(value) ⇒ Object
Sets the id property value.
-
#is_verified ⇒ Object
Gets the isVerified property value.
-
#is_verified=(value) ⇒ Object
Sets the isVerified property value.
-
#name ⇒ Object
Gets the name property value.
-
#name=(value) ⇒ Object
Sets the name property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#username ⇒ Object
Gets the username property value.
-
#username=(value) ⇒ Object
Sets the username property value.
-
#visibility ⇒ Object
Gets the visibility property value.
-
#visibility=(value) ⇒ Object
Sets the visibility property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
104 105 106 107 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 104 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ApiUserProfile.new end |
Instance Method Details
#avatar_url ⇒ Object
Gets the avatarUrl property value. Avatar image URL, when set.
43 44 45 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 43 def avatar_url return @avatar_url end |
#avatar_url=(value) ⇒ Object
Sets the avatarUrl property value. Avatar image URL, when set.
51 52 53 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 51 def avatar_url=(value) @avatar_url = value end |
#banner_url ⇒ Object
Gets the bannerUrl property value. Banner image URL, when set.
58 59 60 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 58 def return @banner_url end |
#banner_url=(value) ⇒ Object
Sets the bannerUrl property value. Banner image URL, when set.
66 67 68 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 66 def (value) @banner_url = value end |
#bio ⇒ Object
Gets the bio property value. Public profile bio.
73 74 75 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 73 def bio return @bio end |
#bio=(value) ⇒ Object
Sets the bio property value. Public profile bio.
81 82 83 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 81 def bio=(value) @bio = value end |
#created_at ⇒ Object
Gets the createdAt property value. The createdAt property
88 89 90 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 88 def created_at return @created_at end |
#created_at=(value) ⇒ Object
Sets the createdAt property value. The createdAt property
96 97 98 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 96 def created_at=(value) @created_at = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 112 def get_field_deserializers() return { "avatarUrl" => lambda {|n| @avatar_url = n.get_object_value(lambda {|pn| ApiUserProfile::ApiUserProfileAvatarUrl.create_from_discriminator_value(pn) }) }, "bannerUrl" => lambda {|n| @banner_url = n.get_object_value(lambda {|pn| ApiUserProfile::ApiUserProfileBannerUrl.create_from_discriminator_value(pn) }) }, "bio" => lambda {|n| @bio = n.get_object_value(lambda {|pn| ApiUserProfile::ApiUserProfileBio.create_from_discriminator_value(pn) }) }, "createdAt" => lambda {|n| @created_at = n.get_object_value(lambda {|pn| ApiUserProfile::ApiUserProfileCreatedAt.create_from_discriminator_value(pn) }) }, "id" => lambda {|n| @id = n.get_string_value() }, "isVerified" => lambda {|n| @is_verified = n.get_boolean_value() }, "name" => lambda {|n| @name = n.get_object_value(lambda {|pn| ApiUserProfile::ApiUserProfileName.create_from_discriminator_value(pn) }) }, "username" => lambda {|n| @username = n.get_object_value(lambda {|pn| ApiUserProfile::ApiUserProfileUsername.create_from_discriminator_value(pn) }) }, "visibility" => lambda {|n| @visibility = n.get_enum_value(TeamBattlesSdk::Generated::Models::ProfileVisibility) }, } end |
#id ⇒ Object
Gets the id property value. User ID.
129 130 131 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 129 def id return @id end |
#id=(value) ⇒ Object
Sets the id property value. User ID.
137 138 139 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 137 def id=(value) @id = value end |
#is_verified ⇒ Object
Gets the isVerified property value. The isVerified property
144 145 146 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 144 def is_verified return @is_verified end |
#is_verified=(value) ⇒ Object
Sets the isVerified property value. The isVerified property
152 153 154 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 152 def is_verified=(value) @is_verified = value end |
#name ⇒ Object
Gets the name property value. Display name, when set.
159 160 161 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 159 def name return @name end |
#name=(value) ⇒ Object
Sets the name property value. Display name, when set.
167 168 169 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 167 def name=(value) @name = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 175 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("avatarUrl", @avatar_url) writer.write_object_value("bannerUrl", @banner_url) writer.write_object_value("bio", @bio) writer.write_object_value("createdAt", @created_at) writer.write_string_value("id", @id) writer.write_boolean_value("isVerified", @is_verified) writer.write_object_value("name", @name) writer.write_object_value("username", @username) writer.write_enum_value("visibility", @visibility) end |
#username ⇒ Object
Gets the username property value. User handle, when set.
191 192 193 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 191 def username return @username end |
#username=(value) ⇒ Object
Sets the username property value. User handle, when set.
199 200 201 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 199 def username=(value) @username = value end |
#visibility ⇒ Object
Gets the visibility property value. Public profile visibility setting.
206 207 208 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 206 def visibility return @visibility end |
#visibility=(value) ⇒ Object
Sets the visibility property value. Public profile visibility setting.
214 215 216 |
# File 'lib/teambattles_sdk/generated/models/api_user_profile.rb', line 214 def visibility=(value) @visibility = value end |