Class: TeamBattlesSdk::Generated::Models::ApplyRuleTemplateRequestBody
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::ApplyRuleTemplateRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/apply_rule_template_request_body.rb
Overview
Applies a rule template.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#game_id ⇒ Object
Gets the gameId property value.
-
#game_id=(value) ⇒ Object
Sets the gameId property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new ApplyRuleTemplateRequestBody and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#template_id ⇒ Object
Gets the templateId property value.
-
#template_id=(value) ⇒ Object
Sets the templateId property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new ApplyRuleTemplateRequestBody and sets the default values.
40 41 42 |
# File 'lib/teambattles_sdk/generated/models/apply_rule_template_request_body.rb', line 40 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
48 49 50 51 |
# File 'lib/teambattles_sdk/generated/models/apply_rule_template_request_body.rb', line 48 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ApplyRuleTemplateRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
25 26 27 |
# File 'lib/teambattles_sdk/generated/models/apply_rule_template_request_body.rb', line 25 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
33 34 35 |
# File 'lib/teambattles_sdk/generated/models/apply_rule_template_request_body.rb', line 33 def additional_data=(value) @additional_data = value end |
#game_id ⇒ Object
Gets the gameId property value. Game ID to apply the template to.
56 57 58 |
# File 'lib/teambattles_sdk/generated/models/apply_rule_template_request_body.rb', line 56 def game_id return @game_id end |
#game_id=(value) ⇒ Object
Sets the gameId property value. Game ID to apply the template to.
64 65 66 |
# File 'lib/teambattles_sdk/generated/models/apply_rule_template_request_body.rb', line 64 def game_id=(value) @game_id = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
71 72 73 74 75 76 |
# File 'lib/teambattles_sdk/generated/models/apply_rule_template_request_body.rb', line 71 def get_field_deserializers() return { "gameId" => lambda {|n| @game_id = n.get_string_value() }, "templateId" => lambda {|n| @template_id = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
82 83 84 85 86 87 |
# File 'lib/teambattles_sdk/generated/models/apply_rule_template_request_body.rb', line 82 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("gameId", @game_id) writer.write_string_value("templateId", @template_id) writer.write_additional_data(@additional_data) end |
#template_id ⇒ Object
Gets the templateId property value. League rule template ID.
92 93 94 |
# File 'lib/teambattles_sdk/generated/models/apply_rule_template_request_body.rb', line 92 def template_id return @template_id end |
#template_id=(value) ⇒ Object
Sets the templateId property value. League rule template ID.
100 101 102 |
# File 'lib/teambattles_sdk/generated/models/apply_rule_template_request_body.rb', line 100 def template_id=(value) @template_id = value end |