Class: TeamBattlesSdk::Generated::Models::CreateMatchRequestBody
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::CreateMatchRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/create_match_request_body.rb
Overview
Creates a new match as the API key owner.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#active_roster ⇒ Object
Gets the activeRoster property value.
-
#active_roster=(value) ⇒ Object
Sets the activeRoster property value.
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#bench_roster ⇒ Object
Gets the benchRoster property value.
-
#bench_roster=(value) ⇒ Object
Sets the benchRoster property value.
-
#best_of ⇒ Object
Gets the bestOf property value.
-
#best_of=(value) ⇒ Object
Sets the bestOf property value.
-
#challenged_team_id ⇒ Object
Gets the challengedTeamId property value.
-
#challenged_team_id=(value) ⇒ Object
Sets the challengedTeamId property value.
-
#game_id ⇒ Object
Gets the gameId property value.
-
#game_id=(value) ⇒ Object
Sets the gameId property value.
-
#game_mode_id ⇒ Object
Gets the gameModeId property value.
-
#game_mode_id=(value) ⇒ Object
Sets the gameModeId property value.
-
#game_specific_options ⇒ Object
Gets the gameSpecificOptions property value.
-
#game_specific_options=(value) ⇒ Object
Sets the gameSpecificOptions property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new CreateMatchRequestBody and sets the default values.
-
#input_device ⇒ Object
Gets the inputDevice property value.
-
#input_device=(value) ⇒ Object
Sets the inputDevice property value.
-
#is_challenge ⇒ Object
Gets the isChallenge property value.
-
#is_challenge=(value) ⇒ Object
Sets the isChallenge property value.
-
#league_id ⇒ Object
Gets the leagueId property value.
-
#league_id=(value) ⇒ Object
Sets the leagueId property value.
-
#locked_rules ⇒ Object
Gets the lockedRules property value.
-
#locked_rules=(value) ⇒ Object
Sets the lockedRules property value.
-
#map_preference_mode ⇒ Object
Gets the mapPreferenceMode property value.
-
#map_preference_mode=(value) ⇒ Object
Sets the mapPreferenceMode property value.
-
#map_selection_type ⇒ Object
Gets the mapSelectionType property value.
-
#map_selection_type=(value) ⇒ Object
Sets the mapSelectionType property value.
-
#match_type ⇒ Object
Gets the matchType property value.
-
#match_type=(value) ⇒ Object
Sets the matchType property value.
-
#notes ⇒ Object
Gets the notes property value.
-
#notes=(value) ⇒ Object
Sets the notes property value.
-
#platform ⇒ Object
Gets the platform property value.
-
#platform=(value) ⇒ Object
Sets the platform property value.
-
#publish_status ⇒ Object
Gets the publishStatus property value.
-
#publish_status=(value) ⇒ Object
Sets the publishStatus property value.
-
#region ⇒ Object
Gets the region property value.
-
#region=(value) ⇒ Object
Sets the region property value.
-
#scheduled_at ⇒ Object
Gets the scheduledAt property value.
-
#scheduled_at=(value) ⇒ Object
Sets the scheduledAt property value.
-
#selected_maps ⇒ Object
Gets the selectedMaps property value.
-
#selected_maps=(value) ⇒ Object
Sets the selectedMaps property value.
-
#selected_objectives ⇒ Object
Gets the selectedObjectives property value.
-
#selected_objectives=(value) ⇒ Object
Sets the selectedObjectives property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#team_id ⇒ Object
Gets the teamId property value.
-
#team_id=(value) ⇒ Object
Sets the teamId property value.
-
#team_size ⇒ Object
Gets the teamSize property value.
-
#team_size=(value) ⇒ Object
Sets the teamSize property value.
-
#wager_amount ⇒ Object
Gets the wagerAmount property value.
-
#wager_amount=(value) ⇒ Object
Sets the wagerAmount property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new CreateMatchRequestBody and sets the default values.
166 167 168 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 166 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
174 175 176 177 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 174 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return CreateMatchRequestBody.new end |
Instance Method Details
#active_roster ⇒ Object
Gets the activeRoster property value. Active roster user IDs (must be creator-team members).
91 92 93 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 91 def active_roster return @active_roster end |
#active_roster=(value) ⇒ Object
Sets the activeRoster property value. Active roster user IDs (must be creator-team members).
99 100 101 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 99 def active_roster=(value) @active_roster = value end |
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
106 107 108 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 106 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
114 115 116 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 114 def additional_data=(value) @additional_data = value end |
#bench_roster ⇒ Object
Gets the benchRoster property value. Optional bench roster.
121 122 123 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 121 def bench_roster return @bench_roster end |
#bench_roster=(value) ⇒ Object
Sets the benchRoster property value. Optional bench roster.
129 130 131 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 129 def bench_roster=(value) @bench_roster = value end |
#best_of ⇒ Object
Gets the bestOf property value. Series length (best of N).
136 137 138 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 136 def best_of return @best_of end |
#best_of=(value) ⇒ Object
Sets the bestOf property value. Series length (best of N).
144 145 146 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 144 def best_of=(value) @best_of = value end |
#challenged_team_id ⇒ Object
Gets the challengedTeamId property value. Challenged team ID (required when isChallenge is true).
151 152 153 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 151 def challenged_team_id return @challenged_team_id end |
#challenged_team_id=(value) ⇒ Object
Sets the challengedTeamId property value. Challenged team ID (required when isChallenge is true).
159 160 161 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 159 def challenged_team_id=(value) @challenged_team_id = value end |
#game_id ⇒ Object
Gets the gameId property value. Game ID for the match.
182 183 184 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 182 def game_id return @game_id end |
#game_id=(value) ⇒ Object
Sets the gameId property value. Game ID for the match.
190 191 192 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 190 def game_id=(value) @game_id = value end |
#game_mode_id ⇒ Object
Gets the gameModeId property value. Game mode ID (client-side definition).
197 198 199 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 197 def game_mode_id return @game_mode_id end |
#game_mode_id=(value) ⇒ Object
Sets the gameModeId property value. Game mode ID (client-side definition).
205 206 207 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 205 def game_mode_id=(value) @game_mode_id = value end |
#game_specific_options ⇒ Object
Gets the gameSpecificOptions property value. Game-specific options.
212 213 214 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 212 def return @game_specific_options end |
#game_specific_options=(value) ⇒ Object
Sets the gameSpecificOptions property value. Game-specific options.
220 221 222 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 220 def (value) @game_specific_options = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 227 def get_field_deserializers() return { "activeRoster" => lambda {|n| @active_roster = n.get_collection_of_primitive_values(String) }, "benchRoster" => lambda {|n| @bench_roster = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::CreateMatchRequestBodyBenchRoster.create_from_discriminator_value(pn) }) }, "bestOf" => lambda {|n| @best_of = n.get_number_value() }, "challengedTeamId" => lambda {|n| @challenged_team_id = n.get_string_value() }, "gameId" => lambda {|n| @game_id = n.get_string_value() }, "gameModeId" => lambda {|n| @game_mode_id = n.get_string_value() }, "gameSpecificOptions" => lambda {|n| @game_specific_options = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::CreateMatchRequestBodyGameSpecificOptions.create_from_discriminator_value(pn) }) }, "inputDevice" => lambda {|n| @input_device = n.get_enum_value(TeamBattlesSdk::Generated::Models::CreateMatchRequestBodyInputDevice) }, "isChallenge" => lambda {|n| @is_challenge = n.get_boolean_value() }, "leagueId" => lambda {|n| @league_id = n.get_string_value() }, "lockedRules" => lambda {|n| @locked_rules = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::CreateMatchRequestBodyLockedRules.create_from_discriminator_value(pn) }) }, "mapPreferenceMode" => lambda {|n| @map_preference_mode = n.get_enum_value(TeamBattlesSdk::Generated::Models::CreateMatchRequestBodyMapPreferenceMode) }, "mapSelectionType" => lambda {|n| @map_selection_type = n.get_enum_value(TeamBattlesSdk::Generated::Models::CreateMatchRequestBodyMapSelectionType) }, "matchType" => lambda {|n| @match_type = n.get_enum_value(TeamBattlesSdk::Generated::Models::CreateMatchRequestBodyMatchType) }, "notes" => lambda {|n| @notes = n.get_string_value() }, "platform" => lambda {|n| @platform = n.get_enum_value(TeamBattlesSdk::Generated::Models::CreateMatchRequestBodyPlatform) }, "publishStatus" => lambda {|n| @publish_status = n.get_enum_value(TeamBattlesSdk::Generated::Models::CreateMatchRequestBodyPublishStatus) }, "region" => lambda {|n| @region = n.get_enum_value(TeamBattlesSdk::Generated::Models::CreateMatchRequestBodyRegion) }, "scheduledAt" => lambda {|n| @scheduled_at = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) }, "selectedMaps" => lambda {|n| @selected_maps = n.get_collection_of_primitive_values(String) }, "selectedObjectives" => lambda {|n| @selected_objectives = n.get_collection_of_primitive_values(String) }, "teamId" => lambda {|n| @team_id = n.get_string_value() }, "teamSize" => lambda {|n| @team_size = n.get_number_value() }, "wagerAmount" => lambda {|n| @wager_amount = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) }, } end |
#input_device ⇒ Object
Gets the inputDevice property value. Input device (defaults to ALL).
259 260 261 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 259 def input_device return @input_device end |
#input_device=(value) ⇒ Object
Sets the inputDevice property value. Input device (defaults to ALL).
267 268 269 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 267 def input_device=(value) @input_device = value end |
#is_challenge ⇒ Object
Gets the isChallenge property value. Create as a direct challenge to another team.
274 275 276 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 274 def is_challenge return @is_challenge end |
#is_challenge=(value) ⇒ Object
Sets the isChallenge property value. Create as a direct challenge to another team.
282 283 284 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 282 def is_challenge=(value) @is_challenge = value end |
#league_id ⇒ Object
Gets the leagueId property value. League ID for a league match.
289 290 291 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 289 def league_id return @league_id end |
#league_id=(value) ⇒ Object
Sets the leagueId property value. League ID for a league match.
297 298 299 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 297 def league_id=(value) @league_id = value end |
#locked_rules ⇒ Object
Gets the lockedRules property value. Locked rule flags.
304 305 306 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 304 def locked_rules return @locked_rules end |
#locked_rules=(value) ⇒ Object
Sets the lockedRules property value. Locked rule flags.
312 313 314 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 312 def locked_rules=(value) @locked_rules = value end |
#map_preference_mode ⇒ Object
Gets the mapPreferenceMode property value. Map preference mode.
319 320 321 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 319 def map_preference_mode return @map_preference_mode end |
#map_preference_mode=(value) ⇒ Object
Sets the mapPreferenceMode property value. Map preference mode.
327 328 329 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 327 def map_preference_mode=(value) @map_preference_mode = value end |
#map_selection_type ⇒ Object
Gets the mapSelectionType property value. Map selection type.
334 335 336 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 334 def map_selection_type return @map_selection_type end |
#map_selection_type=(value) ⇒ Object
Sets the mapSelectionType property value. Map selection type.
342 343 344 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 342 def map_selection_type=(value) @map_selection_type = value end |
#match_type ⇒ Object
Gets the matchType property value. Match type.
349 350 351 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 349 def match_type return @match_type end |
#match_type=(value) ⇒ Object
Sets the matchType property value. Match type.
357 358 359 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 357 def match_type=(value) @match_type = value end |
#notes ⇒ Object
Gets the notes property value. Optional match notes.
364 365 366 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 364 def notes return @notes end |
#notes=(value) ⇒ Object
Sets the notes property value. Optional match notes.
372 373 374 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 372 def notes=(value) @notes = value end |
#platform ⇒ Object
Gets the platform property value. Platform (defaults to CROSSPLAY).
379 380 381 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 379 def platform return @platform end |
#platform=(value) ⇒ Object
Sets the platform property value. Platform (defaults to CROSSPLAY).
387 388 389 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 387 def platform=(value) @platform = value end |
#publish_status ⇒ Object
Gets the publishStatus property value. Publish status (defaults to DRAFT).
394 395 396 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 394 def publish_status return @publish_status end |
#publish_status=(value) ⇒ Object
Sets the publishStatus property value. Publish status (defaults to DRAFT).
402 403 404 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 402 def publish_status=(value) @publish_status = value end |
#region ⇒ Object
Gets the region property value. Region (defaults to NONE).
409 410 411 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 409 def region return @region end |
#region=(value) ⇒ Object
Sets the region property value. Region (defaults to NONE).
417 418 419 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 417 def region=(value) @region = value end |
#scheduled_at ⇒ Object
Gets the scheduledAt property value. Scheduled start (epoch ms).
424 425 426 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 424 def scheduled_at return @scheduled_at end |
#scheduled_at=(value) ⇒ Object
Sets the scheduledAt property value. Scheduled start (epoch ms).
432 433 434 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 432 def scheduled_at=(value) @scheduled_at = value end |
#selected_maps ⇒ Object
Gets the selectedMaps property value. Selected map IDs.
439 440 441 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 439 def selected_maps return @selected_maps end |
#selected_maps=(value) ⇒ Object
Sets the selectedMaps property value. Selected map IDs.
447 448 449 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 447 def selected_maps=(value) @selected_maps = value end |
#selected_objectives ⇒ Object
Gets the selectedObjectives property value. Selected objective IDs.
454 455 456 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 454 def selected_objectives return @selected_objectives end |
#selected_objectives=(value) ⇒ Object
Sets the selectedObjectives property value. Selected objective IDs.
462 463 464 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 462 def selected_objectives=(value) @selected_objectives = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 470 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_collection_of_primitive_values("activeRoster", @active_roster) writer.write_collection_of_object_values("benchRoster", @bench_roster) writer.write_number_value("bestOf", @best_of) writer.write_string_value("challengedTeamId", @challenged_team_id) writer.write_string_value("gameId", @game_id) writer.write_string_value("gameModeId", @game_mode_id) writer.write_object_value("gameSpecificOptions", @game_specific_options) writer.write_enum_value("inputDevice", @input_device) writer.write_boolean_value("isChallenge", @is_challenge) writer.write_string_value("leagueId", @league_id) writer.write_object_value("lockedRules", @locked_rules) writer.write_enum_value("mapPreferenceMode", @map_preference_mode) writer.write_enum_value("mapSelectionType", @map_selection_type) writer.write_enum_value("matchType", @match_type) writer.write_string_value("notes", @notes) writer.write_enum_value("platform", @platform) writer.write_enum_value("publishStatus", @publish_status) writer.write_enum_value("region", @region) writer.write_object_value("scheduledAt", @scheduled_at) writer.write_collection_of_primitive_values("selectedMaps", @selected_maps) writer.write_collection_of_primitive_values("selectedObjectives", @selected_objectives) writer.write_string_value("teamId", @team_id) writer.write_number_value("teamSize", @team_size) writer.write_object_value("wagerAmount", @wager_amount) writer.write_additional_data(@additional_data) end |
#team_id ⇒ Object
Gets the teamId property value. Creator team ID. The owner must captain it.
502 503 504 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 502 def team_id return @team_id end |
#team_id=(value) ⇒ Object
Sets the teamId property value. Creator team ID. The owner must captain it.
510 511 512 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 510 def team_id=(value) @team_id = value end |
#team_size ⇒ Object
Gets the teamSize property value. Players per team.
517 518 519 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 517 def team_size return @team_size end |
#team_size=(value) ⇒ Object
Sets the teamSize property value. Players per team.
525 526 527 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 525 def team_size=(value) @team_size = value end |
#wager_amount ⇒ Object
Gets the wagerAmount property value. Wager amount (WAGER matches only).
532 533 534 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 532 def wager_amount return @wager_amount end |
#wager_amount=(value) ⇒ Object
Sets the wagerAmount property value. Wager amount (WAGER matches only).
540 541 542 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body.rb', line 540 def wager_amount=(value) @wager_amount = value end |