Class: TeamBattlesSdk::Generated::Models::CreateMatchRequestBodyBenchRoster
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::CreateMatchRequestBodyBenchRoster
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/create_match_request_body_bench_roster.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#id ⇒ Object
Gets the id property value.
-
#id=(value) ⇒ Object
Sets the id property value.
-
#initialize ⇒ Object
constructor
Instantiates a new CreateMatchRequestBodyBenchRoster and sets the default values.
-
#priority ⇒ Object
Gets the priority property value.
-
#priority=(value) ⇒ Object
Sets the priority property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new CreateMatchRequestBodyBenchRoster and sets the default values.
38 39 40 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body_bench_roster.rb', line 38 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
46 47 48 49 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body_bench_roster.rb', line 46 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return CreateMatchRequestBodyBenchRoster.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
23 24 25 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body_bench_roster.rb', line 23 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
31 32 33 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body_bench_roster.rb', line 31 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
54 55 56 57 58 59 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body_bench_roster.rb', line 54 def get_field_deserializers() return { "id" => lambda {|n| @id = n.get_string_value() }, "priority" => lambda {|n| @priority = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) }, } end |
#id ⇒ Object
Gets the id property value. Bench user ID.
64 65 66 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body_bench_roster.rb', line 64 def id return @id end |
#id=(value) ⇒ Object
Sets the id property value. Bench user ID.
72 73 74 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body_bench_roster.rb', line 72 def id=(value) @id = value end |
#priority ⇒ Object
Gets the priority property value. Bench priority.
79 80 81 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body_bench_roster.rb', line 79 def priority return @priority end |
#priority=(value) ⇒ Object
Sets the priority property value. Bench priority.
87 88 89 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body_bench_roster.rb', line 87 def priority=(value) @priority = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
95 96 97 98 99 100 |
# File 'lib/teambattles_sdk/generated/models/create_match_request_body_bench_roster.rb', line 95 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("id", @id) writer.write_object_value("priority", @priority) writer.write_additional_data(@additional_data) end |