Class: TeamBattlesSdk::Generated::Models::GameBatchScoresBody
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::GameBatchScoresBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/game_batch_scores_body.rb
Overview
Request body for submitting one or more map scores in a single call.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new GameBatchScoresBody and sets the default values.
-
#maps ⇒ Object
Gets the maps property value.
-
#maps=(value) ⇒ Object
Sets the maps property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new GameBatchScoresBody and sets the default values.
37 38 39 |
# File 'lib/teambattles_sdk/generated/models/game_batch_scores_body.rb', line 37 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
45 46 47 48 |
# File 'lib/teambattles_sdk/generated/models/game_batch_scores_body.rb', line 45 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return GameBatchScoresBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
22 23 24 |
# File 'lib/teambattles_sdk/generated/models/game_batch_scores_body.rb', line 22 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
30 31 32 |
# File 'lib/teambattles_sdk/generated/models/game_batch_scores_body.rb', line 30 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
53 54 55 56 57 |
# File 'lib/teambattles_sdk/generated/models/game_batch_scores_body.rb', line 53 def get_field_deserializers() return { "maps" => lambda {|n| @maps = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::GameMapScoreInput.create_from_discriminator_value(pn) }) }, } end |
#maps ⇒ Object
Gets the maps property value. Map scores to submit. Must contain at least one entry.
62 63 64 |
# File 'lib/teambattles_sdk/generated/models/game_batch_scores_body.rb', line 62 def maps return @maps end |
#maps=(value) ⇒ Object
Sets the maps property value. Map scores to submit. Must contain at least one entry.
70 71 72 |
# File 'lib/teambattles_sdk/generated/models/game_batch_scores_body.rb', line 70 def maps=(value) @maps = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
78 79 80 81 82 |
# File 'lib/teambattles_sdk/generated/models/game_batch_scores_body.rb', line 78 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_collection_of_object_values("maps", @maps) writer.write_additional_data(@additional_data) end |