Class: TeamBattlesSdk::Generated::Models::GameCreateMatchResponse

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/teambattles_sdk/generated/models/game_create_match_response.rb

Overview

Result of a successful game-originated match creation.

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a game_create_match_response

Raises:

  • (StandardError)


26
27
28
29
# File 'lib/teambattles_sdk/generated/models/game_create_match_response.rb', line 26

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return GameCreateMatchResponse.new
end

Instance Method Details

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



34
35
36
37
38
39
40
# File 'lib/teambattles_sdk/generated/models/game_create_match_response.rb', line 34

def get_field_deserializers()
    return {
        "matchId" => lambda {|n| @match_id = n.get_string_value() },
        "success" => lambda {|n| @success = n.get_boolean_value() },
        "timestamp" => lambda {|n| @timestamp = n.get_string_value() },
    }
end

#match_idObject

Gets the matchId property value. ID of the newly created match.

Returns:

  • a string



45
46
47
# File 'lib/teambattles_sdk/generated/models/game_create_match_response.rb', line 45

def match_id
    return @match_id
end

#match_id=(value) ⇒ Object

Sets the matchId property value. ID of the newly created match.

Parameters:

  • value

    Value to set for the matchId property.

Returns:

  • a void



53
54
55
# File 'lib/teambattles_sdk/generated/models/game_create_match_response.rb', line 53

def match_id=(value)
    @match_id = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


61
62
63
64
65
66
# File 'lib/teambattles_sdk/generated/models/game_create_match_response.rb', line 61

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("matchId", @match_id)
    writer.write_boolean_value("success", @success)
    writer.write_string_value("timestamp", @timestamp)
end

#successObject

Gets the success property value. The success property

Returns:

  • a boolean



71
72
73
# File 'lib/teambattles_sdk/generated/models/game_create_match_response.rb', line 71

def success
    return @success
end

#success=(value) ⇒ Object

Sets the success property value. The success property

Parameters:

  • value

    Value to set for the success property.

Returns:

  • a void



79
80
81
# File 'lib/teambattles_sdk/generated/models/game_create_match_response.rb', line 79

def success=(value)
    @success = value
end

#timestampObject

Gets the timestamp property value. Server response time (ISO 8601).

Returns:

  • a string



86
87
88
# File 'lib/teambattles_sdk/generated/models/game_create_match_response.rb', line 86

def timestamp
    return @timestamp
end

#timestamp=(value) ⇒ Object

Sets the timestamp property value. Server response time (ISO 8601).

Parameters:

  • value

    Value to set for the timestamp property.

Returns:

  • a void



94
95
96
# File 'lib/teambattles_sdk/generated/models/game_create_match_response.rb', line 94

def timestamp=(value)
    @timestamp = value
end