Class: TeamBattlesSdk::Generated::Models::GameDetailTeam
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::GameDetailTeam
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/game_detail_team.rb
Overview
A team as embedded in the game-developer match-detail response ({ _id, name, tag }).
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#id ⇒ Object
Gets the _id property value.
-
#id=(value) ⇒ Object
Sets the _id property value.
-
#name ⇒ Object
Gets the name property value.
-
#name=(value) ⇒ Object
Sets the name property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#tag ⇒ Object
Gets the tag property value.
-
#tag=(value) ⇒ Object
Sets the tag property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
26 27 28 29 |
# File 'lib/teambattles_sdk/generated/models/game_detail_team.rb', line 26 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return GameDetailTeam.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
34 35 36 37 38 39 40 |
# File 'lib/teambattles_sdk/generated/models/game_detail_team.rb', line 34 def get_field_deserializers() return { "_id" => lambda {|n| @id = n.get_string_value() }, "name" => lambda {|n| @name = n.get_string_value() }, "tag" => lambda {|n| @tag = n.get_string_value() }, } end |
#id ⇒ Object
Gets the _id property value. Team ID.
45 46 47 |
# File 'lib/teambattles_sdk/generated/models/game_detail_team.rb', line 45 def id return @id end |
#id=(value) ⇒ Object
Sets the _id property value. Team ID.
53 54 55 |
# File 'lib/teambattles_sdk/generated/models/game_detail_team.rb', line 53 def id=(value) @id = value end |
#name ⇒ Object
Gets the name property value. Team name.
60 61 62 |
# File 'lib/teambattles_sdk/generated/models/game_detail_team.rb', line 60 def name return @name end |
#name=(value) ⇒ Object
Sets the name property value. Team name.
68 69 70 |
# File 'lib/teambattles_sdk/generated/models/game_detail_team.rb', line 68 def name=(value) @name = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
76 77 78 79 80 81 |
# File 'lib/teambattles_sdk/generated/models/game_detail_team.rb', line 76 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("_id", @id) writer.write_string_value("name", @name) writer.write_string_value("tag", @tag) end |
#tag ⇒ Object
Gets the tag property value. Team tag (short identifier).
86 87 88 |
# File 'lib/teambattles_sdk/generated/models/game_detail_team.rb', line 86 def tag return @tag end |
#tag=(value) ⇒ Object
Sets the tag property value. Team tag (short identifier).
94 95 96 |
# File 'lib/teambattles_sdk/generated/models/game_detail_team.rb', line 94 def tag=(value) @tag = value end |