Class: TeamBattlesSdk::Generated::Models::GameForfeitResponse

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/teambattles_sdk/generated/models/game_forfeit_response.rb

Overview

Result of a successful match forfeit.

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a game_forfeit_response

Raises:

  • (StandardError)


29
30
31
32
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 29

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return GameForfeitResponse.new
end

Instance Method Details

#forfeited_by_team_idObject

Gets the forfeitedByTeamId property value. ID of the team that forfeited.

Returns:

  • a string



37
38
39
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 37

def forfeited_by_team_id
    return @forfeited_by_team_id
end

#forfeited_by_team_id=(value) ⇒ Object

Sets the forfeitedByTeamId property value. ID of the team that forfeited.

Parameters:

  • value

    Value to set for the forfeitedByTeamId property.

Returns:

  • a void



45
46
47
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 45

def forfeited_by_team_id=(value)
    @forfeited_by_team_id = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



52
53
54
55
56
57
58
59
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 52

def get_field_deserializers()
    return {
        "forfeitedByTeamId" => lambda {|n| @forfeited_by_team_id = n.get_string_value() },
        "matchId" => lambda {|n| @match_id = n.get_string_value() },
        "success" => lambda {|n| @success = n.get_boolean_value() },
        "timestamp" => lambda {|n| @timestamp = n.get_string_value() },
    }
end

#match_idObject

Gets the matchId property value. ID of the forfeited match.

Returns:

  • a string



64
65
66
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 64

def match_id
    return @match_id
end

#match_id=(value) ⇒ Object

Sets the matchId property value. ID of the forfeited match.

Parameters:

  • value

    Value to set for the matchId property.

Returns:

  • a void



72
73
74
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 72

def match_id=(value)
    @match_id = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


80
81
82
83
84
85
86
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 80

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("forfeitedByTeamId", @forfeited_by_team_id)
    writer.write_string_value("matchId", @match_id)
    writer.write_boolean_value("success", @success)
    writer.write_string_value("timestamp", @timestamp)
end

#successObject

Gets the success property value. The success property

Returns:

  • a boolean



91
92
93
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 91

def success
    return @success
end

#success=(value) ⇒ Object

Sets the success property value. The success property

Parameters:

  • value

    Value to set for the success property.

Returns:

  • a void



99
100
101
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 99

def success=(value)
    @success = value
end

#timestampObject

Gets the timestamp property value. Server response time (ISO 8601).

Returns:

  • a string



106
107
108
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 106

def timestamp
    return @timestamp
end

#timestamp=(value) ⇒ Object

Sets the timestamp property value. Server response time (ISO 8601).

Parameters:

  • value

    Value to set for the timestamp property.

Returns:

  • a void



114
115
116
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 114

def timestamp=(value)
    @timestamp = value
end