Class: TeamBattlesSdk::Generated::Models::GameMatchDetail::GameMatchDetailCompletedAt
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::GameMatchDetail::GameMatchDetailCompletedAt
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/game_match_detail.rb
Overview
Composed type wrapper for classes GameMatchDetailCompletedAtMember1, string
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#game_match_detail_completed_at_member1 ⇒ Object
Gets the GameMatchDetail_completedAtMember1 property value.
-
#game_match_detail_completed_at_member1=(value) ⇒ Object
Sets the GameMatchDetail_completedAtMember1 property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#string ⇒ Object
Gets the string property value.
-
#string=(value) ⇒ Object
Sets the string property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
464 465 466 467 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 464 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return GameMatchDetailCompletedAt.new end |
Instance Method Details
#game_match_detail_completed_at_member1 ⇒ Object
Gets the GameMatchDetail_completedAtMember1 property value. Composed type representation for type GameMatchDetailCompletedAtMember1
472 473 474 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 472 def game_match_detail_completed_at_member1 return @game_match_detail_completed_at_member1 end |
#game_match_detail_completed_at_member1=(value) ⇒ Object
Sets the GameMatchDetail_completedAtMember1 property value. Composed type representation for type GameMatchDetailCompletedAtMember1
480 481 482 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 480 def game_match_detail_completed_at_member1=(value) @game_match_detail_completed_at_member1 = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
487 488 489 490 491 492 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 487 def get_field_deserializers() return { "GameMatchDetail_completedAtMember1" => lambda {|n| @game_match_detail_completed_at_member1 = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::GameMatchDetailCompletedAtMember1.create_from_discriminator_value(pn) }) }, "string" => lambda {|n| @string = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
498 499 500 501 502 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 498 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("GameMatchDetail_completedAtMember1", @game_match_detail_completed_at_member1) writer.write_string_value("string", @string) end |
#string ⇒ Object
Gets the string property value. Composed type representation for type string
507 508 509 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 507 def string return @string end |
#string=(value) ⇒ Object
Sets the string property value. Composed type representation for type string
515 516 517 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 515 def string=(value) @string = value end |