Class: TeamBattlesSdk::Generated::Models::GameMatchDetail::GameMatchDetailLeagueId
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::GameMatchDetail::GameMatchDetailLeagueId
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/game_match_detail.rb
Overview
Composed type wrapper for classes GameMatchDetailLeagueIdMember1, string
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#game_match_detail_league_id_member1 ⇒ Object
Gets the GameMatchDetail_leagueIdMember1 property value.
-
#game_match_detail_league_id_member1=(value) ⇒ Object
Sets the GameMatchDetail_leagueIdMember1 property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#string ⇒ Object
Gets the string property value.
-
#string=(value) ⇒ Object
Sets the string property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
677 678 679 680 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 677 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return GameMatchDetailLeagueId.new end |
Instance Method Details
#game_match_detail_league_id_member1 ⇒ Object
Gets the GameMatchDetail_leagueIdMember1 property value. Composed type representation for type GameMatchDetailLeagueIdMember1
685 686 687 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 685 def game_match_detail_league_id_member1 return @game_match_detail_league_id_member1 end |
#game_match_detail_league_id_member1=(value) ⇒ Object
Sets the GameMatchDetail_leagueIdMember1 property value. Composed type representation for type GameMatchDetailLeagueIdMember1
693 694 695 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 693 def game_match_detail_league_id_member1=(value) @game_match_detail_league_id_member1 = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
700 701 702 703 704 705 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 700 def get_field_deserializers() return { "GameMatchDetail_leagueIdMember1" => lambda {|n| @game_match_detail_league_id_member1 = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::GameMatchDetailLeagueIdMember1.create_from_discriminator_value(pn) }) }, "string" => lambda {|n| @string = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
711 712 713 714 715 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 711 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("GameMatchDetail_leagueIdMember1", @game_match_detail_league_id_member1) writer.write_string_value("string", @string) end |
#string ⇒ Object
Gets the string property value. Composed type representation for type string
720 721 722 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 720 def string return @string end |
#string=(value) ⇒ Object
Sets the string property value. Composed type representation for type string
728 729 730 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 728 def string=(value) @string = value end |