Class: TeamBattlesSdk::Generated::Models::GameMatchDetail::GameMatchDetailStartedAt
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::GameMatchDetail::GameMatchDetailStartedAt
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/game_match_detail.rb
Overview
Composed type wrapper for classes GameMatchDetailStartedAtMember1, string
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#game_match_detail_started_at_member1 ⇒ Object
Gets the GameMatchDetail_startedAtMember1 property value.
-
#game_match_detail_started_at_member1=(value) ⇒ Object
Sets the GameMatchDetail_startedAtMember1 property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#string ⇒ Object
Gets the string property value.
-
#string=(value) ⇒ Object
Sets the string property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
961 962 963 964 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 961 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return GameMatchDetailStartedAt.new end |
Instance Method Details
#game_match_detail_started_at_member1 ⇒ Object
Gets the GameMatchDetail_startedAtMember1 property value. Composed type representation for type GameMatchDetailStartedAtMember1
969 970 971 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 969 def game_match_detail_started_at_member1 return @game_match_detail_started_at_member1 end |
#game_match_detail_started_at_member1=(value) ⇒ Object
Sets the GameMatchDetail_startedAtMember1 property value. Composed type representation for type GameMatchDetailStartedAtMember1
977 978 979 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 977 def game_match_detail_started_at_member1=(value) @game_match_detail_started_at_member1 = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
984 985 986 987 988 989 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 984 def get_field_deserializers() return { "GameMatchDetail_startedAtMember1" => lambda {|n| @game_match_detail_started_at_member1 = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::GameMatchDetailStartedAtMember1.create_from_discriminator_value(pn) }) }, "string" => lambda {|n| @string = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
995 996 997 998 999 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 995 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("GameMatchDetail_startedAtMember1", @game_match_detail_started_at_member1) writer.write_string_value("string", @string) end |
#string ⇒ Object
Gets the string property value. Composed type representation for type string
1004 1005 1006 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 1004 def string return @string end |
#string=(value) ⇒ Object
Sets the string property value. Composed type representation for type string
1012 1013 1014 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 1012 def string=(value) @string = value end |