Class: TeamBattlesSdk::Generated::Models::GamePlayerStatsResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::GamePlayerStatsResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/game_player_stats_response.rb
Overview
Result of a successful player-stats update.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#action ⇒ Object
Gets the action property value.
-
#action=(value) ⇒ Object
Sets the action property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#map_index ⇒ Object
Gets the mapIndex property value.
-
#map_index=(value) ⇒ Object
Sets the mapIndex property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#success ⇒ Object
Gets the success property value.
-
#success=(value) ⇒ Object
Sets the success property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
41 42 43 44 |
# File 'lib/teambattles_sdk/generated/models/game_player_stats_response.rb', line 41 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return GamePlayerStatsResponse.new end |
Instance Method Details
#action ⇒ Object
Gets the action property value. Operation performed, always “updated” on success.
25 26 27 |
# File 'lib/teambattles_sdk/generated/models/game_player_stats_response.rb', line 25 def action return @action end |
#action=(value) ⇒ Object
Sets the action property value. Operation performed, always “updated” on success.
33 34 35 |
# File 'lib/teambattles_sdk/generated/models/game_player_stats_response.rb', line 33 def action=(value) @action = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
49 50 51 52 53 54 55 |
# File 'lib/teambattles_sdk/generated/models/game_player_stats_response.rb', line 49 def get_field_deserializers() return { "action" => lambda {|n| @action = n.get_string_value() }, "mapIndex" => lambda {|n| @map_index = n.get_number_value() }, "success" => lambda {|n| @success = n.get_boolean_value() }, } end |
#map_index ⇒ Object
Gets the mapIndex property value. Index of the map whose stats were updated.
60 61 62 |
# File 'lib/teambattles_sdk/generated/models/game_player_stats_response.rb', line 60 def map_index return @map_index end |
#map_index=(value) ⇒ Object
Sets the mapIndex property value. Index of the map whose stats were updated.
68 69 70 |
# File 'lib/teambattles_sdk/generated/models/game_player_stats_response.rb', line 68 def map_index=(value) @map_index = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
76 77 78 79 80 81 |
# File 'lib/teambattles_sdk/generated/models/game_player_stats_response.rb', line 76 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("action", @action) writer.write_number_value("mapIndex", @map_index) writer.write_boolean_value("success", @success) end |
#success ⇒ Object
Gets the success property value. The success property
86 87 88 |
# File 'lib/teambattles_sdk/generated/models/game_player_stats_response.rb', line 86 def success return @success end |
#success=(value) ⇒ Object
Sets the success property value. The success property
94 95 96 |
# File 'lib/teambattles_sdk/generated/models/game_player_stats_response.rb', line 94 def success=(value) @success = value end |