Class: TeamBattlesSdk::Generated::Models::GameScore::GameScoreSubmittedAt

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/teambattles_sdk/generated/models/game_score.rb

Overview

Composed type wrapper for classes GameScoreSubmittedAtMember1, string

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a game_score_submitted_at

Raises:

  • (StandardError)


264
265
266
267
# File 'lib/teambattles_sdk/generated/models/game_score.rb', line 264

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return GameScoreSubmittedAt.new
end

Instance Method Details

#game_score_submitted_at_member1Object

Gets the GameScore_submittedAtMember1 property value. Composed type representation for type GameScoreSubmittedAtMember1

Returns:

  • a game_score_submitted_at_member1



272
273
274
# File 'lib/teambattles_sdk/generated/models/game_score.rb', line 272

def 
    return @game_score_submitted_at_member1
end

#game_score_submitted_at_member1=(value) ⇒ Object

Sets the GameScore_submittedAtMember1 property value. Composed type representation for type GameScoreSubmittedAtMember1

Parameters:

  • value

    Value to set for the GameScore_submittedAtMember1 property.

Returns:

  • a void



280
281
282
# File 'lib/teambattles_sdk/generated/models/game_score.rb', line 280

def (value)
    @game_score_submitted_at_member1 = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



287
288
289
290
291
292
# File 'lib/teambattles_sdk/generated/models/game_score.rb', line 287

def get_field_deserializers()
    return {
        "GameScore_submittedAtMember1" => lambda {|n| @game_score_submitted_at_member1 = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::GameScoreSubmittedAtMember1.create_from_discriminator_value(pn) }) },
        "string" => lambda {|n| @string = n.get_string_value() },
    }
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


298
299
300
301
302
# File 'lib/teambattles_sdk/generated/models/game_score.rb', line 298

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_object_value("GameScore_submittedAtMember1", @game_score_submitted_at_member1)
    writer.write_string_value("string", @string)
end

#stringObject

Gets the string property value. Composed type representation for type string

Returns:

  • a string



307
308
309
# File 'lib/teambattles_sdk/generated/models/game_score.rb', line 307

def string
    return @string
end

#string=(value) ⇒ Object

Sets the string property value. Composed type representation for type string

Parameters:

  • value

    Value to set for the string property.

Returns:

  • a void



315
316
317
# File 'lib/teambattles_sdk/generated/models/game_score.rb', line 315

def string=(value)
    @string = value
end