Class: TeamBattlesSdk::Generated::Models::GameSeriesScore
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::GameSeriesScore
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/game_series_score.rb
Overview
Aggregate map-win tally across the series.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#creator_map_wins ⇒ Object
Gets the creatorMapWins property value.
-
#creator_map_wins=(value) ⇒ Object
Sets the creatorMapWins property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#opponent_map_wins ⇒ Object
Gets the opponentMapWins property value.
-
#opponent_map_wins=(value) ⇒ Object
Sets the opponentMapWins property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
23 24 25 26 |
# File 'lib/teambattles_sdk/generated/models/game_series_score.rb', line 23 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return GameSeriesScore.new end |
Instance Method Details
#creator_map_wins ⇒ Object
Gets the creatorMapWins property value. Confirmed map wins for the creator team.
31 32 33 |
# File 'lib/teambattles_sdk/generated/models/game_series_score.rb', line 31 def creator_map_wins return @creator_map_wins end |
#creator_map_wins=(value) ⇒ Object
Sets the creatorMapWins property value. Confirmed map wins for the creator team.
39 40 41 |
# File 'lib/teambattles_sdk/generated/models/game_series_score.rb', line 39 def creator_map_wins=(value) @creator_map_wins = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
46 47 48 49 50 51 |
# File 'lib/teambattles_sdk/generated/models/game_series_score.rb', line 46 def get_field_deserializers() return { "creatorMapWins" => lambda {|n| @creator_map_wins = n.get_number_value() }, "opponentMapWins" => lambda {|n| @opponent_map_wins = n.get_number_value() }, } end |
#opponent_map_wins ⇒ Object
Gets the opponentMapWins property value. Confirmed map wins for the opponent team.
56 57 58 |
# File 'lib/teambattles_sdk/generated/models/game_series_score.rb', line 56 def opponent_map_wins return @opponent_map_wins end |
#opponent_map_wins=(value) ⇒ Object
Sets the opponentMapWins property value. Confirmed map wins for the opponent team.
64 65 66 |
# File 'lib/teambattles_sdk/generated/models/game_series_score.rb', line 64 def opponent_map_wins=(value) @opponent_map_wins = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
72 73 74 75 76 |
# File 'lib/teambattles_sdk/generated/models/game_series_score.rb', line 72 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("creatorMapWins", @creator_map_wins) writer.write_number_value("opponentMapWins", @opponent_map_wins) end |