Class: TeamBattlesSdk::Generated::Models::GameStatusUpdateResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::GameStatusUpdateResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/game_status_update_response.rb
Overview
Result of a successful match status transition.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#match_id ⇒ Object
Gets the matchId property value.
-
#match_id=(value) ⇒ Object
Sets the matchId property value.
-
#new_status ⇒ Object
Gets the newStatus property value.
-
#new_status=(value) ⇒ Object
Sets the newStatus property value.
-
#previous_status ⇒ Object
Gets the previousStatus property value.
-
#previous_status=(value) ⇒ Object
Sets the previousStatus property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#success ⇒ Object
Gets the success property value.
-
#success=(value) ⇒ Object
Sets the success property value.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
32 33 34 35 |
# File 'lib/teambattles_sdk/generated/models/game_status_update_response.rb', line 32 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return GameStatusUpdateResponse.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
40 41 42 43 44 45 46 47 48 |
# File 'lib/teambattles_sdk/generated/models/game_status_update_response.rb', line 40 def get_field_deserializers() return { "matchId" => lambda {|n| @match_id = n.get_string_value() }, "newStatus" => lambda {|n| @new_status = n.get_string_value() }, "previousStatus" => lambda {|n| @previous_status = n.get_string_value() }, "success" => lambda {|n| @success = n.get_boolean_value() }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, } end |
#match_id ⇒ Object
Gets the matchId property value. ID of the updated match.
53 54 55 |
# File 'lib/teambattles_sdk/generated/models/game_status_update_response.rb', line 53 def match_id return @match_id end |
#match_id=(value) ⇒ Object
Sets the matchId property value. ID of the updated match.
61 62 63 |
# File 'lib/teambattles_sdk/generated/models/game_status_update_response.rb', line 61 def match_id=(value) @match_id = value end |
#new_status ⇒ Object
Gets the newStatus property value. Match status after the transition.
68 69 70 |
# File 'lib/teambattles_sdk/generated/models/game_status_update_response.rb', line 68 def new_status return @new_status end |
#new_status=(value) ⇒ Object
Sets the newStatus property value. Match status after the transition.
76 77 78 |
# File 'lib/teambattles_sdk/generated/models/game_status_update_response.rb', line 76 def new_status=(value) @new_status = value end |
#previous_status ⇒ Object
Gets the previousStatus property value. Match status before the transition.
83 84 85 |
# File 'lib/teambattles_sdk/generated/models/game_status_update_response.rb', line 83 def previous_status return @previous_status end |
#previous_status=(value) ⇒ Object
Sets the previousStatus property value. Match status before the transition.
91 92 93 |
# File 'lib/teambattles_sdk/generated/models/game_status_update_response.rb', line 91 def previous_status=(value) @previous_status = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
99 100 101 102 103 104 105 106 |
# File 'lib/teambattles_sdk/generated/models/game_status_update_response.rb', line 99 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("matchId", @match_id) writer.write_string_value("newStatus", @new_status) writer.write_string_value("previousStatus", @previous_status) writer.write_boolean_value("success", @success) writer.write_string_value("timestamp", @timestamp) end |
#success ⇒ Object
Gets the success property value. The success property
111 112 113 |
# File 'lib/teambattles_sdk/generated/models/game_status_update_response.rb', line 111 def success return @success end |
#success=(value) ⇒ Object
Sets the success property value. The success property
119 120 121 |
# File 'lib/teambattles_sdk/generated/models/game_status_update_response.rb', line 119 def success=(value) @success = value end |
#timestamp ⇒ Object
Gets the timestamp property value. Server response time (ISO 8601).
126 127 128 |
# File 'lib/teambattles_sdk/generated/models/game_status_update_response.rb', line 126 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. Server response time (ISO 8601).
134 135 136 |
# File 'lib/teambattles_sdk/generated/models/game_status_update_response.rb', line 134 def (value) @timestamp = value end |