Class: TeamBattlesSdk::Generated::Models::LeagueApplyEligibilityEligibility
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::LeagueApplyEligibilityEligibility
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/league_apply_eligibility_eligibility.rb
Overview
API key owner’s apply-to-join eligibility.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#eligible_teams ⇒ Object
Gets the eligibleTeams property value.
-
#eligible_teams=(value) ⇒ Object
Sets the eligibleTeams property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#has_approved_team_here ⇒ Object
Gets the hasApprovedTeamHere property value.
-
#has_approved_team_here=(value) ⇒ Object
Sets the hasApprovedTeamHere property value.
-
#is_authed ⇒ Object
Gets the isAuthed property value.
-
#is_authed=(value) ⇒ Object
Sets the isAuthed property value.
-
#pending_teams ⇒ Object
Gets the pendingTeams property value.
-
#pending_teams=(value) ⇒ Object
Sets the pendingTeams property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
29 30 31 32 |
# File 'lib/teambattles_sdk/generated/models/league_apply_eligibility_eligibility.rb', line 29 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return LeagueApplyEligibilityEligibility.new end |
Instance Method Details
#eligible_teams ⇒ Object
Gets the eligibleTeams property value. The eligibleTeams property
37 38 39 |
# File 'lib/teambattles_sdk/generated/models/league_apply_eligibility_eligibility.rb', line 37 def eligible_teams return @eligible_teams end |
#eligible_teams=(value) ⇒ Object
Sets the eligibleTeams property value. The eligibleTeams property
45 46 47 |
# File 'lib/teambattles_sdk/generated/models/league_apply_eligibility_eligibility.rb', line 45 def eligible_teams=(value) @eligible_teams = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
52 53 54 55 56 57 58 59 |
# File 'lib/teambattles_sdk/generated/models/league_apply_eligibility_eligibility.rb', line 52 def get_field_deserializers() return { "eligibleTeams" => lambda {|n| @eligible_teams = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::LeagueApplyEligibilityEligibilityEligibleTeams.create_from_discriminator_value(pn) }) }, "hasApprovedTeamHere" => lambda {|n| @has_approved_team_here = n.get_boolean_value() }, "isAuthed" => lambda {|n| @is_authed = n.get_boolean_value() }, "pendingTeams" => lambda {|n| @pending_teams = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::LeagueApplyEligibilityEligibilityPendingTeams.create_from_discriminator_value(pn) }) }, } end |
#has_approved_team_here ⇒ Object
Gets the hasApprovedTeamHere property value. The hasApprovedTeamHere property
64 65 66 |
# File 'lib/teambattles_sdk/generated/models/league_apply_eligibility_eligibility.rb', line 64 def has_approved_team_here return @has_approved_team_here end |
#has_approved_team_here=(value) ⇒ Object
Sets the hasApprovedTeamHere property value. The hasApprovedTeamHere property
72 73 74 |
# File 'lib/teambattles_sdk/generated/models/league_apply_eligibility_eligibility.rb', line 72 def has_approved_team_here=(value) @has_approved_team_here = value end |
#is_authed ⇒ Object
Gets the isAuthed property value. The isAuthed property
79 80 81 |
# File 'lib/teambattles_sdk/generated/models/league_apply_eligibility_eligibility.rb', line 79 def is_authed return @is_authed end |
#is_authed=(value) ⇒ Object
Sets the isAuthed property value. The isAuthed property
87 88 89 |
# File 'lib/teambattles_sdk/generated/models/league_apply_eligibility_eligibility.rb', line 87 def is_authed=(value) @is_authed = value end |
#pending_teams ⇒ Object
Gets the pendingTeams property value. The pendingTeams property
94 95 96 |
# File 'lib/teambattles_sdk/generated/models/league_apply_eligibility_eligibility.rb', line 94 def pending_teams return @pending_teams end |
#pending_teams=(value) ⇒ Object
Sets the pendingTeams property value. The pendingTeams property
102 103 104 |
# File 'lib/teambattles_sdk/generated/models/league_apply_eligibility_eligibility.rb', line 102 def pending_teams=(value) @pending_teams = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
110 111 112 113 114 115 116 |
# File 'lib/teambattles_sdk/generated/models/league_apply_eligibility_eligibility.rb', line 110 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_collection_of_object_values("eligibleTeams", @eligible_teams) writer.write_boolean_value("hasApprovedTeamHere", @has_approved_team_here) writer.write_boolean_value("isAuthed", @is_authed) writer.write_collection_of_object_values("pendingTeams", @pending_teams) end |