Class: TeamBattlesSdk::Generated::Models::LeagueProfile
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::LeagueProfile
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/league_profile.rb
Overview
Public profile for a single league.
Defined Under Namespace
Classes: LeagueProfileAvatarUrl, LeagueProfileBannerUrl
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#active_seasons ⇒ Object
Gets the activeSeasons property value.
-
#active_seasons=(value) ⇒ Object
Sets the activeSeasons property value.
-
#avatar_url ⇒ Object
Gets the avatarUrl property value.
-
#avatar_url=(value) ⇒ Object
Sets the avatarUrl property value.
-
#banner_url ⇒ Object
Gets the bannerUrl property value.
-
#banner_url=(value) ⇒ Object
Sets the bannerUrl property value.
-
#created_at ⇒ Object
Gets the createdAt property value.
-
#created_at=(value) ⇒ Object
Sets the createdAt property value.
-
#description ⇒ Object
Gets the description property value.
-
#description=(value) ⇒ Object
Sets the description property value.
-
#games ⇒ Object
Gets the games property value.
-
#games=(value) ⇒ Object
Sets the games property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#id ⇒ Object
Gets the id property value.
-
#id=(value) ⇒ Object
Sets the id property value.
-
#is_featured ⇒ Object
Gets the isFeatured property value.
-
#is_featured=(value) ⇒ Object
Sets the isFeatured property value.
-
#is_verified ⇒ Object
Gets the isVerified property value.
-
#is_verified=(value) ⇒ Object
Sets the isVerified property value.
-
#name ⇒ Object
Gets the name property value.
-
#name=(value) ⇒ Object
Sets the name property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#slug ⇒ Object
Gets the slug property value.
-
#slug=(value) ⇒ Object
Sets the slug property value.
-
#staff_count ⇒ Object
Gets the staffCount property value.
-
#staff_count=(value) ⇒ Object
Sets the staffCount property value.
-
#status ⇒ Object
Gets the status property value.
-
#status=(value) ⇒ Object
Sets the status property value.
-
#team_count ⇒ Object
Gets the teamCount property value.
-
#team_count=(value) ⇒ Object
Sets the teamCount property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
119 120 121 122 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 119 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return LeagueProfile.new end |
Instance Method Details
#active_seasons ⇒ Object
Gets the activeSeasons property value. Currently active seasons.
58 59 60 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 58 def active_seasons return @active_seasons end |
#active_seasons=(value) ⇒ Object
Sets the activeSeasons property value. Currently active seasons.
66 67 68 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 66 def active_seasons=(value) @active_seasons = value end |
#avatar_url ⇒ Object
Gets the avatarUrl property value. League avatar image URL.
73 74 75 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 73 def avatar_url return @avatar_url end |
#avatar_url=(value) ⇒ Object
Sets the avatarUrl property value. League avatar image URL.
81 82 83 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 81 def avatar_url=(value) @avatar_url = value end |
#banner_url ⇒ Object
Gets the bannerUrl property value. League banner image URL.
88 89 90 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 88 def return @banner_url end |
#banner_url=(value) ⇒ Object
Sets the bannerUrl property value. League banner image URL.
96 97 98 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 96 def (value) @banner_url = value end |
#created_at ⇒ Object
Gets the createdAt property value. Creation timestamp (epoch milliseconds).
103 104 105 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 103 def created_at return @created_at end |
#created_at=(value) ⇒ Object
Sets the createdAt property value. Creation timestamp (epoch milliseconds).
111 112 113 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 111 def created_at=(value) @created_at = value end |
#description ⇒ Object
Gets the description property value. League description.
127 128 129 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 127 def description return @description end |
#description=(value) ⇒ Object
Sets the description property value. League description.
135 136 137 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 135 def description=(value) @description = value end |
#games ⇒ Object
Gets the games property value. Games associated with the league.
142 143 144 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 142 def games return @games end |
#games=(value) ⇒ Object
Sets the games property value. Games associated with the league.
150 151 152 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 150 def games=(value) @games = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 157 def get_field_deserializers() return { "activeSeasons" => lambda {|n| @active_seasons = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::LeagueProfileActiveSeasons.create_from_discriminator_value(pn) }) }, "avatarUrl" => lambda {|n| @avatar_url = n.get_object_value(lambda {|pn| LeagueProfile::LeagueProfileAvatarUrl.create_from_discriminator_value(pn) }) }, "bannerUrl" => lambda {|n| @banner_url = n.get_object_value(lambda {|pn| LeagueProfile::LeagueProfileBannerUrl.create_from_discriminator_value(pn) }) }, "createdAt" => lambda {|n| @created_at = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) }, "description" => lambda {|n| @description = n.get_string_value() }, "games" => lambda {|n| @games = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::LeagueProfileGames.create_from_discriminator_value(pn) }) }, "id" => lambda {|n| @id = n.get_string_value() }, "isFeatured" => lambda {|n| @is_featured = n.get_boolean_value() }, "isVerified" => lambda {|n| @is_verified = n.get_boolean_value() }, "name" => lambda {|n| @name = n.get_string_value() }, "slug" => lambda {|n| @slug = n.get_string_value() }, "staffCount" => lambda {|n| @staff_count = n.get_number_value() }, "status" => lambda {|n| @status = n.get_string_value() }, "teamCount" => lambda {|n| @team_count = n.get_number_value() }, } end |
#id ⇒ Object
Gets the id property value. League ID.
179 180 181 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 179 def id return @id end |
#id=(value) ⇒ Object
Sets the id property value. League ID.
187 188 189 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 187 def id=(value) @id = value end |
#is_featured ⇒ Object
Gets the isFeatured property value. Whether the league is featured.
194 195 196 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 194 def is_featured return @is_featured end |
#is_featured=(value) ⇒ Object
Sets the isFeatured property value. Whether the league is featured.
202 203 204 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 202 def is_featured=(value) @is_featured = value end |
#is_verified ⇒ Object
Gets the isVerified property value. Whether the league is verified.
209 210 211 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 209 def is_verified return @is_verified end |
#is_verified=(value) ⇒ Object
Sets the isVerified property value. Whether the league is verified.
217 218 219 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 217 def is_verified=(value) @is_verified = value end |
#name ⇒ Object
Gets the name property value. League display name.
224 225 226 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 224 def name return @name end |
#name=(value) ⇒ Object
Sets the name property value. League display name.
232 233 234 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 232 def name=(value) @name = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 240 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_collection_of_object_values("activeSeasons", @active_seasons) writer.write_object_value("avatarUrl", @avatar_url) writer.write_object_value("bannerUrl", @banner_url) writer.write_object_value("createdAt", @created_at) writer.write_string_value("description", @description) writer.write_collection_of_object_values("games", @games) writer.write_string_value("id", @id) writer.write_boolean_value("isFeatured", @is_featured) writer.write_boolean_value("isVerified", @is_verified) writer.write_string_value("name", @name) writer.write_string_value("slug", @slug) writer.write_number_value("staffCount", @staff_count) writer.write_string_value("status", @status) writer.write_number_value("teamCount", @team_count) end |
#slug ⇒ Object
Gets the slug property value. URL-friendly league identifier.
261 262 263 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 261 def slug return @slug end |
#slug=(value) ⇒ Object
Sets the slug property value. URL-friendly league identifier.
269 270 271 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 269 def slug=(value) @slug = value end |
#staff_count ⇒ Object
Gets the staffCount property value. Number of staff members.
276 277 278 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 276 def staff_count return @staff_count end |
#staff_count=(value) ⇒ Object
Sets the staffCount property value. Number of staff members.
284 285 286 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 284 def staff_count=(value) @staff_count = value end |
#status ⇒ Object
Gets the status property value. League status (e.g. active, inactive).
291 292 293 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 291 def status return @status end |
#status=(value) ⇒ Object
Sets the status property value. League status (e.g. active, inactive).
299 300 301 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 299 def status=(value) @status = value end |
#team_count ⇒ Object
Gets the teamCount property value. Number of teams in the league.
306 307 308 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 306 def team_count return @team_count end |
#team_count=(value) ⇒ Object
Sets the teamCount property value. Number of teams in the league.
314 315 316 |
# File 'lib/teambattles_sdk/generated/models/league_profile.rb', line 314 def team_count=(value) @team_count = value end |