Class: TeamBattlesSdk::Generated::Models::LeagueProfileResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::LeagueProfileResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/league_profile_response.rb
Overview
League profile response envelope.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#league ⇒ Object
Gets the league property value.
-
#league=(value) ⇒ Object
Sets the league property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
23 24 25 26 |
# File 'lib/teambattles_sdk/generated/models/league_profile_response.rb', line 23 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return LeagueProfileResponse.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
31 32 33 34 35 36 |
# File 'lib/teambattles_sdk/generated/models/league_profile_response.rb', line 31 def get_field_deserializers() return { "league" => lambda {|n| @league = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::LeagueProfile.create_from_discriminator_value(pn) }) }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, } end |
#league ⇒ Object
Gets the league property value. Public profile for a single league.
41 42 43 |
# File 'lib/teambattles_sdk/generated/models/league_profile_response.rb', line 41 def league return @league end |
#league=(value) ⇒ Object
Sets the league property value. Public profile for a single league.
49 50 51 |
# File 'lib/teambattles_sdk/generated/models/league_profile_response.rb', line 49 def league=(value) @league = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
57 58 59 60 61 |
# File 'lib/teambattles_sdk/generated/models/league_profile_response.rb', line 57 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("league", @league) writer.write_string_value("timestamp", @timestamp) end |
#timestamp ⇒ Object
Gets the timestamp property value. Response generation time (ISO 8601).
66 67 68 |
# File 'lib/teambattles_sdk/generated/models/league_profile_response.rb', line 66 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. Response generation time (ISO 8601).
74 75 76 |
# File 'lib/teambattles_sdk/generated/models/league_profile_response.rb', line 74 def (value) @timestamp = value end |