Class: TeamBattlesSdk::Generated::Models::LeagueStandings
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::LeagueStandings
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/league_standings.rb
Overview
League standings for a season.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#count ⇒ Object
Gets the count property value.
-
#count=(value) ⇒ Object
Sets the count property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#standings ⇒ Object
Gets the standings property value.
-
#standings=(value) ⇒ Object
Sets the standings property value.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
41 42 43 44 |
# File 'lib/teambattles_sdk/generated/models/league_standings.rb', line 41 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return LeagueStandings.new end |
Instance Method Details
#count ⇒ Object
Gets the count property value. Number of teams returned.
25 26 27 |
# File 'lib/teambattles_sdk/generated/models/league_standings.rb', line 25 def count return @count end |
#count=(value) ⇒ Object
Sets the count property value. Number of teams returned.
33 34 35 |
# File 'lib/teambattles_sdk/generated/models/league_standings.rb', line 33 def count=(value) @count = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
49 50 51 52 53 54 55 |
# File 'lib/teambattles_sdk/generated/models/league_standings.rb', line 49 def get_field_deserializers() return { "count" => lambda {|n| @count = n.get_number_value() }, "standings" => lambda {|n| @standings = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::LeagueStandingsStandings.create_from_discriminator_value(pn) }) }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
61 62 63 64 65 66 |
# File 'lib/teambattles_sdk/generated/models/league_standings.rb', line 61 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("count", @count) writer.write_collection_of_object_values("standings", @standings) writer.write_string_value("timestamp", @timestamp) end |
#standings ⇒ Object
Gets the standings property value. Approved teams with season stats, ordered by standings position. Each item is a team-with-stats document plus a computed rank.
71 72 73 |
# File 'lib/teambattles_sdk/generated/models/league_standings.rb', line 71 def standings return @standings end |
#standings=(value) ⇒ Object
Sets the standings property value. Approved teams with season stats, ordered by standings position. Each item is a team-with-stats document plus a computed rank.
79 80 81 |
# File 'lib/teambattles_sdk/generated/models/league_standings.rb', line 79 def standings=(value) @standings = value end |
#timestamp ⇒ Object
Gets the timestamp property value. Response generation time (ISO 8601).
86 87 88 |
# File 'lib/teambattles_sdk/generated/models/league_standings.rb', line 86 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. Response generation time (ISO 8601).
94 95 96 |
# File 'lib/teambattles_sdk/generated/models/league_standings.rb', line 94 def (value) @timestamp = value end |