Class: TeamBattlesSdk::Generated::Models::MapScoreItem
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::MapScoreItem
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/map_score_item.rb
Overview
A single map’s score entry.
Defined Under Namespace
Classes: MapScoreItemCreatedAt
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#confirmed_by ⇒ Object
Gets the confirmedBy property value.
-
#confirmed_by=(value) ⇒ Object
Sets the confirmedBy property value.
-
#created_at ⇒ Object
Gets the createdAt property value.
-
#created_at=(value) ⇒ Object
Sets the createdAt property value.
-
#creator_team_score ⇒ Object
Gets the creatorTeamScore property value.
-
#creator_team_score=(value) ⇒ Object
Sets the creatorTeamScore property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#map_id ⇒ Object
Gets the mapId property value.
-
#map_id=(value) ⇒ Object
Sets the mapId property value.
-
#map_index ⇒ Object
Gets the mapIndex property value.
-
#map_index=(value) ⇒ Object
Sets the mapIndex property value.
-
#opponent_team_score ⇒ Object
Gets the opponentTeamScore property value.
-
#opponent_team_score=(value) ⇒ Object
Sets the opponentTeamScore property value.
-
#score_status ⇒ Object
Gets the scoreStatus property value.
-
#score_status=(value) ⇒ Object
Sets the scoreStatus property value.
-
#screenshot_urls ⇒ Object
Gets the screenshotUrls property value.
-
#screenshot_urls=(value) ⇒ Object
Sets the screenshotUrls property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#submitted_by ⇒ Object
Gets the submittedBy property value.
-
#submitted_by=(value) ⇒ Object
Sets the submittedBy property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
74 75 76 77 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 74 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return MapScoreItem.new end |
Instance Method Details
#confirmed_by ⇒ Object
Gets the confirmedBy property value. The confirmedBy property
43 44 45 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 43 def confirmed_by return @confirmed_by end |
#confirmed_by=(value) ⇒ Object
Sets the confirmedBy property value. The confirmedBy property
51 52 53 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 51 def confirmed_by=(value) @confirmed_by = value end |
#created_at ⇒ Object
Gets the createdAt property value. Creation time (ISO 8601).
58 59 60 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 58 def created_at return @created_at end |
#created_at=(value) ⇒ Object
Sets the createdAt property value. Creation time (ISO 8601).
66 67 68 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 66 def created_at=(value) @created_at = value end |
#creator_team_score ⇒ Object
Gets the creatorTeamScore property value. The creatorTeamScore property
82 83 84 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 82 def creator_team_score return @creator_team_score end |
#creator_team_score=(value) ⇒ Object
Sets the creatorTeamScore property value. The creatorTeamScore property
90 91 92 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 90 def creator_team_score=(value) @creator_team_score = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 97 def get_field_deserializers() return { "confirmedBy" => lambda {|n| @confirmed_by = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::ScoreConfirmer.create_from_discriminator_value(pn) }) }, "createdAt" => lambda {|n| @created_at = n.get_object_value(lambda {|pn| MapScoreItem::MapScoreItemCreatedAt.create_from_discriminator_value(pn) }) }, "creatorTeamScore" => lambda {|n| @creator_team_score = n.get_number_value() }, "mapId" => lambda {|n| @map_id = n.get_string_value() }, "mapIndex" => lambda {|n| @map_index = n.get_number_value() }, "opponentTeamScore" => lambda {|n| @opponent_team_score = n.get_number_value() }, "scoreStatus" => lambda {|n| @score_status = n.get_string_value() }, "screenshotUrls" => lambda {|n| @screenshot_urls = n.get_collection_of_primitive_values(String) }, "submittedBy" => lambda {|n| @submitted_by = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::ScoreSubmitter.create_from_discriminator_value(pn) }) }, } end |
#map_id ⇒ Object
Gets the mapId property value. The mapId property
114 115 116 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 114 def map_id return @map_id end |
#map_id=(value) ⇒ Object
Sets the mapId property value. The mapId property
122 123 124 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 122 def map_id=(value) @map_id = value end |
#map_index ⇒ Object
Gets the mapIndex property value. The mapIndex property
129 130 131 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 129 def map_index return @map_index end |
#map_index=(value) ⇒ Object
Sets the mapIndex property value. The mapIndex property
137 138 139 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 137 def map_index=(value) @map_index = value end |
#opponent_team_score ⇒ Object
Gets the opponentTeamScore property value. The opponentTeamScore property
144 145 146 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 144 def opponent_team_score return @opponent_team_score end |
#opponent_team_score=(value) ⇒ Object
Sets the opponentTeamScore property value. The opponentTeamScore property
152 153 154 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 152 def opponent_team_score=(value) @opponent_team_score = value end |
#score_status ⇒ Object
Gets the scoreStatus property value. CONFIRMED or PENDING.
159 160 161 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 159 def score_status return @score_status end |
#score_status=(value) ⇒ Object
Sets the scoreStatus property value. CONFIRMED or PENDING.
167 168 169 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 167 def score_status=(value) @score_status = value end |
#screenshot_urls ⇒ Object
Gets the screenshotUrls property value. The screenshotUrls property
174 175 176 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 174 def screenshot_urls return @screenshot_urls end |
#screenshot_urls=(value) ⇒ Object
Sets the screenshotUrls property value. The screenshotUrls property
182 183 184 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 182 def screenshot_urls=(value) @screenshot_urls = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 190 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("confirmedBy", @confirmed_by) writer.write_object_value("createdAt", @created_at) writer.write_number_value("creatorTeamScore", @creator_team_score) writer.write_string_value("mapId", @map_id) writer.write_number_value("mapIndex", @map_index) writer.write_number_value("opponentTeamScore", @opponent_team_score) writer.write_string_value("scoreStatus", @score_status) writer.write_collection_of_primitive_values("screenshotUrls", @screenshot_urls) writer.write_object_value("submittedBy", @submitted_by) end |
#submitted_by ⇒ Object
Gets the submittedBy property value. The submittedBy property
206 207 208 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 206 def submitted_by return @submitted_by end |
#submitted_by=(value) ⇒ Object
Sets the submittedBy property value. The submittedBy property
214 215 216 |
# File 'lib/teambattles_sdk/generated/models/map_score_item.rb', line 214 def submitted_by=(value) @submitted_by = value end |