Class: TeamBattlesSdk::Generated::Models::MatchDiscoverBody
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::MatchDiscoverBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/match_discover_body.rb
Overview
Filters and cursor pagination for public open-match discovery.
Defined Under Namespace
Classes: MatchDiscoverBodyCursor
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#cursor ⇒ Object
Gets the cursor property value.
-
#cursor=(value) ⇒ Object
Sets the cursor property value.
-
#game_id ⇒ Object
Gets the gameId property value.
-
#game_id=(value) ⇒ Object
Sets the gameId property value.
-
#game_slug ⇒ Object
Gets the gameSlug property value.
-
#game_slug=(value) ⇒ Object
Sets the gameSlug property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new MatchDiscoverBody and sets the default values.
-
#league_id ⇒ Object
Gets the leagueId property value.
-
#league_id=(value) ⇒ Object
Sets the leagueId property value.
-
#league_season_id ⇒ Object
Gets the leagueSeasonId property value.
-
#league_season_id=(value) ⇒ Object
Sets the leagueSeasonId property value.
-
#limit ⇒ Object
Gets the limit property value.
-
#limit=(value) ⇒ Object
Sets the limit property value.
-
#match_type ⇒ Object
Gets the matchType property value.
-
#match_type=(value) ⇒ Object
Sets the matchType property value.
-
#platform ⇒ Object
Gets the platform property value.
-
#platform=(value) ⇒ Object
Sets the platform property value.
-
#region ⇒ Object
Gets the region property value.
-
#region=(value) ⇒ Object
Sets the region property value.
-
#scheduled_after ⇒ Object
Gets the scheduledAfter property value.
-
#scheduled_after=(value) ⇒ Object
Sets the scheduledAfter property value.
-
#scheduled_before ⇒ Object
Gets the scheduledBefore property value.
-
#scheduled_before=(value) ⇒ Object
Sets the scheduledBefore property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new MatchDiscoverBody and sets the default values.
67 68 69 70 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 67 def initialize() @additional_data = Hash.new @limit = 50 end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
76 77 78 79 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 76 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return MatchDiscoverBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
52 53 54 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 52 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
60 61 62 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 60 def additional_data=(value) @additional_data = value end |
#cursor ⇒ Object
Gets the cursor property value. The cursor property
84 85 86 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 84 def cursor return @cursor end |
#cursor=(value) ⇒ Object
Sets the cursor property value. The cursor property
92 93 94 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 92 def cursor=(value) @cursor = value end |
#game_id ⇒ Object
Gets the gameId property value. The gameId property
99 100 101 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 99 def game_id return @game_id end |
#game_id=(value) ⇒ Object
Sets the gameId property value. The gameId property
107 108 109 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 107 def game_id=(value) @game_id = value end |
#game_slug ⇒ Object
Gets the gameSlug property value. The gameSlug property
114 115 116 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 114 def game_slug return @game_slug end |
#game_slug=(value) ⇒ Object
Sets the gameSlug property value. The gameSlug property
122 123 124 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 122 def game_slug=(value) @game_slug = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 129 def get_field_deserializers() return { "cursor" => lambda {|n| @cursor = n.get_object_value(lambda {|pn| MatchDiscoverBody::MatchDiscoverBodyCursor.create_from_discriminator_value(pn) }) }, "gameId" => lambda {|n| @game_id = n.get_string_value() }, "gameSlug" => lambda {|n| @game_slug = n.get_string_value() }, "leagueId" => lambda {|n| @league_id = n.get_string_value() }, "leagueSeasonId" => lambda {|n| @league_season_id = n.get_string_value() }, "limit" => lambda {|n| @limit = n.get_number_value() }, "matchType" => lambda {|n| @match_type = n.get_enum_value(TeamBattlesSdk::Generated::Models::MatchDiscoverBodyMatchType) }, "platform" => lambda {|n| @platform = n.get_enum_value(TeamBattlesSdk::Generated::Models::MatchDiscoverBodyPlatform) }, "region" => lambda {|n| @region = n.get_enum_value(TeamBattlesSdk::Generated::Models::MatchDiscoverBodyRegion) }, "scheduledAfter" => lambda {|n| @scheduled_after = n.get_string_value() }, "scheduledBefore" => lambda {|n| @scheduled_before = n.get_string_value() }, } end |
#league_id ⇒ Object
Gets the leagueId property value. The leagueId property
148 149 150 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 148 def league_id return @league_id end |
#league_id=(value) ⇒ Object
Sets the leagueId property value. The leagueId property
156 157 158 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 156 def league_id=(value) @league_id = value end |
#league_season_id ⇒ Object
Gets the leagueSeasonId property value. The leagueSeasonId property
163 164 165 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 163 def league_season_id return @league_season_id end |
#league_season_id=(value) ⇒ Object
Sets the leagueSeasonId property value. The leagueSeasonId property
171 172 173 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 171 def league_season_id=(value) @league_season_id = value end |
#limit ⇒ Object
Gets the limit property value. The limit property
178 179 180 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 178 def limit return @limit end |
#limit=(value) ⇒ Object
Sets the limit property value. The limit property
186 187 188 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 186 def limit=(value) @limit = value end |
#match_type ⇒ Object
Gets the matchType property value. The matchType property
193 194 195 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 193 def match_type return @match_type end |
#match_type=(value) ⇒ Object
Sets the matchType property value. The matchType property
201 202 203 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 201 def match_type=(value) @match_type = value end |
#platform ⇒ Object
Gets the platform property value. The platform property
208 209 210 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 208 def platform return @platform end |
#platform=(value) ⇒ Object
Sets the platform property value. The platform property
216 217 218 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 216 def platform=(value) @platform = value end |
#region ⇒ Object
Gets the region property value. The region property
223 224 225 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 223 def region return @region end |
#region=(value) ⇒ Object
Sets the region property value. The region property
231 232 233 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 231 def region=(value) @region = value end |
#scheduled_after ⇒ Object
Gets the scheduledAfter property value. The scheduledAfter property
238 239 240 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 238 def scheduled_after return @scheduled_after end |
#scheduled_after=(value) ⇒ Object
Sets the scheduledAfter property value. The scheduledAfter property
246 247 248 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 246 def scheduled_after=(value) @scheduled_after = value end |
#scheduled_before ⇒ Object
Gets the scheduledBefore property value. The scheduledBefore property
253 254 255 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 253 def scheduled_before return @scheduled_before end |
#scheduled_before=(value) ⇒ Object
Sets the scheduledBefore property value. The scheduledBefore property
261 262 263 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 261 def scheduled_before=(value) @scheduled_before = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/teambattles_sdk/generated/models/match_discover_body.rb', line 269 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("cursor", @cursor) writer.write_string_value("gameId", @game_id) writer.write_string_value("gameSlug", @game_slug) writer.write_string_value("leagueId", @league_id) writer.write_string_value("leagueSeasonId", @league_season_id) writer.write_number_value("limit", @limit) writer.write_enum_value("matchType", @match_type) writer.write_enum_value("platform", @platform) writer.write_enum_value("region", @region) writer.write_string_value("scheduledAfter", @scheduled_after) writer.write_string_value("scheduledBefore", @scheduled_before) writer.write_additional_data(@additional_data) end |