Class: TeamBattlesSdk::Generated::Models::MatchesRequestBody
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::MatchesRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/matches_request_body.rb
Overview
Filters and cursor pagination for listing matches.
Defined Under Namespace
Classes: MatchesRequestBodyCursor
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#created_after ⇒ Object
Gets the createdAfter property value.
-
#created_after=(value) ⇒ Object
Sets the createdAfter property value.
-
#created_before ⇒ Object
Gets the createdBefore property value.
-
#created_before=(value) ⇒ Object
Sets the createdBefore property value.
-
#cursor ⇒ Object
Gets the cursor property value.
-
#cursor=(value) ⇒ Object
Sets the cursor property value.
-
#exclude_statuses ⇒ Object
Gets the excludeStatuses property value.
-
#exclude_statuses=(value) ⇒ Object
Sets the excludeStatuses property value.
-
#game_id ⇒ Object
Gets the gameId property value.
-
#game_id=(value) ⇒ Object
Sets the gameId property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#include_statuses ⇒ Object
Gets the includeStatuses property value.
-
#include_statuses=(value) ⇒ Object
Sets the includeStatuses property value.
-
#initialize ⇒ Object
constructor
Instantiates a new MatchesRequestBody and sets the default values.
-
#num_items ⇒ Object
Gets the numItems property value.
-
#num_items=(value) ⇒ Object
Sets the numItems property value.
-
#opponent_id ⇒ Object
Gets the opponentId property value.
-
#opponent_id=(value) ⇒ Object
Sets the opponentId property value.
-
#scheduled_after ⇒ Object
Gets the scheduledAfter property value.
-
#scheduled_after=(value) ⇒ Object
Sets the scheduledAfter property value.
-
#scheduled_before ⇒ Object
Gets the scheduledBefore property value.
-
#scheduled_before=(value) ⇒ Object
Sets the scheduledBefore property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new MatchesRequestBody and sets the default values.
64 65 66 67 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 64 def initialize() @additional_data = Hash.new @num_items = 25 end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
103 104 105 106 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 103 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return MatchesRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
49 50 51 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 49 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
57 58 59 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 57 def additional_data=(value) @additional_data = value end |
#created_after ⇒ Object
Gets the createdAfter property value. ISO 8601; only matches created at or after this time.
72 73 74 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 72 def created_after return @created_after end |
#created_after=(value) ⇒ Object
Sets the createdAfter property value. ISO 8601; only matches created at or after this time.
80 81 82 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 80 def created_after=(value) @created_after = value end |
#created_before ⇒ Object
Gets the createdBefore property value. ISO 8601; only matches created at or before this time.
87 88 89 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 87 def created_before return @created_before end |
#created_before=(value) ⇒ Object
Sets the createdBefore property value. ISO 8601; only matches created at or before this time.
95 96 97 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 95 def created_before=(value) @created_before = value end |
#cursor ⇒ Object
Gets the cursor property value. Opaque continuation cursor from a prior page’s continueCursor.
111 112 113 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 111 def cursor return @cursor end |
#cursor=(value) ⇒ Object
Sets the cursor property value. Opaque continuation cursor from a prior page’s continueCursor.
119 120 121 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 119 def cursor=(value) @cursor = value end |
#exclude_statuses ⇒ Object
Gets the excludeStatuses property value. Exclude matches with these MatchStatus codes; unknown values are ignored.
126 127 128 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 126 def exclude_statuses return @exclude_statuses end |
#exclude_statuses=(value) ⇒ Object
Sets the excludeStatuses property value. Exclude matches with these MatchStatus codes; unknown values are ignored.
134 135 136 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 134 def exclude_statuses=(value) @exclude_statuses = value end |
#game_id ⇒ Object
Gets the gameId property value. Filter to a single game by id.
141 142 143 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 141 def game_id return @game_id end |
#game_id=(value) ⇒ Object
Sets the gameId property value. Filter to a single game by id.
149 150 151 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 149 def game_id=(value) @game_id = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 156 def get_field_deserializers() return { "createdAfter" => lambda {|n| @created_after = n.get_string_value() }, "createdBefore" => lambda {|n| @created_before = n.get_string_value() }, "cursor" => lambda {|n| @cursor = n.get_object_value(lambda {|pn| MatchesRequestBody::MatchesRequestBodyCursor.create_from_discriminator_value(pn) }) }, "excludeStatuses" => lambda {|n| @exclude_statuses = n.get_collection_of_primitive_values(String) }, "gameId" => lambda {|n| @game_id = n.get_string_value() }, "includeStatuses" => lambda {|n| @include_statuses = n.get_collection_of_primitive_values(String) }, "numItems" => lambda {|n| @num_items = n.get_number_value() }, "opponentId" => lambda {|n| @opponent_id = n.get_string_value() }, "scheduledAfter" => lambda {|n| @scheduled_after = n.get_string_value() }, "scheduledBefore" => lambda {|n| @scheduled_before = n.get_string_value() }, } end |
#include_statuses ⇒ Object
Gets the includeStatuses property value. Only include matches with these MatchStatus codes; unknown values are ignored.
174 175 176 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 174 def include_statuses return @include_statuses end |
#include_statuses=(value) ⇒ Object
Sets the includeStatuses property value. Only include matches with these MatchStatus codes; unknown values are ignored.
182 183 184 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 182 def include_statuses=(value) @include_statuses = value end |
#num_items ⇒ Object
Gets the numItems property value. Page size (1-100). Defaults to 25.
189 190 191 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 189 def num_items return @num_items end |
#num_items=(value) ⇒ Object
Sets the numItems property value. Page size (1-100). Defaults to 25.
197 198 199 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 197 def num_items=(value) @num_items = value end |
#opponent_id ⇒ Object
Gets the opponentId property value. Filter to matches against this opponent team (team id or slug).
204 205 206 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 204 def opponent_id return @opponent_id end |
#opponent_id=(value) ⇒ Object
Sets the opponentId property value. Filter to matches against this opponent team (team id or slug).
212 213 214 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 212 def opponent_id=(value) @opponent_id = value end |
#scheduled_after ⇒ Object
Gets the scheduledAfter property value. ISO 8601; only matches scheduled at or after this time.
219 220 221 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 219 def scheduled_after return @scheduled_after end |
#scheduled_after=(value) ⇒ Object
Sets the scheduledAfter property value. ISO 8601; only matches scheduled at or after this time.
227 228 229 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 227 def scheduled_after=(value) @scheduled_after = value end |
#scheduled_before ⇒ Object
Gets the scheduledBefore property value. ISO 8601; only matches scheduled at or before this time.
234 235 236 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 234 def scheduled_before return @scheduled_before end |
#scheduled_before=(value) ⇒ Object
Sets the scheduledBefore property value. ISO 8601; only matches scheduled at or before this time.
242 243 244 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 242 def scheduled_before=(value) @scheduled_before = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/teambattles_sdk/generated/models/matches_request_body.rb', line 250 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("createdAfter", @created_after) writer.write_string_value("createdBefore", @created_before) writer.write_object_value("cursor", @cursor) writer.write_collection_of_primitive_values("excludeStatuses", @exclude_statuses) writer.write_string_value("gameId", @game_id) writer.write_collection_of_primitive_values("includeStatuses", @include_statuses) writer.write_number_value("numItems", @num_items) writer.write_string_value("opponentId", @opponent_id) writer.write_string_value("scheduledAfter", @scheduled_after) writer.write_string_value("scheduledBefore", @scheduled_before) writer.write_additional_data(@additional_data) end |