Class: TeamBattlesSdk::Generated::Models::ReportChatMessageResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::ReportChatMessageResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/report_chat_message_response.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#already_reported ⇒ Object
Gets the alreadyReported property value.
-
#already_reported=(value) ⇒ Object
Sets the alreadyReported property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#report_id ⇒ Object
Gets the reportId property value.
-
#report_id=(value) ⇒ Object
Sets the reportId property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#success ⇒ Object
Gets the success property value.
-
#success=(value) ⇒ Object
Sets the success property value.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
42 43 44 45 |
# File 'lib/teambattles_sdk/generated/models/report_chat_message_response.rb', line 42 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ReportChatMessageResponse.new end |
Instance Method Details
#already_reported ⇒ Object
Gets the alreadyReported property value. True if the owner had already reported this message.
26 27 28 |
# File 'lib/teambattles_sdk/generated/models/report_chat_message_response.rb', line 26 def already_reported return @already_reported end |
#already_reported=(value) ⇒ Object
Sets the alreadyReported property value. True if the owner had already reported this message.
34 35 36 |
# File 'lib/teambattles_sdk/generated/models/report_chat_message_response.rb', line 34 def already_reported=(value) @already_reported = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
50 51 52 53 54 55 56 57 |
# File 'lib/teambattles_sdk/generated/models/report_chat_message_response.rb', line 50 def get_field_deserializers() return { "alreadyReported" => lambda {|n| @already_reported = n.get_boolean_value() }, "reportId" => lambda {|n| @report_id = n.get_string_value() }, "success" => lambda {|n| @success = n.get_boolean_value() }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, } end |
#report_id ⇒ Object
Gets the reportId property value. Report ID (existing one if already reported).
62 63 64 |
# File 'lib/teambattles_sdk/generated/models/report_chat_message_response.rb', line 62 def report_id return @report_id end |
#report_id=(value) ⇒ Object
Sets the reportId property value. Report ID (existing one if already reported).
70 71 72 |
# File 'lib/teambattles_sdk/generated/models/report_chat_message_response.rb', line 70 def report_id=(value) @report_id = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
78 79 80 81 82 83 84 |
# File 'lib/teambattles_sdk/generated/models/report_chat_message_response.rb', line 78 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_boolean_value("alreadyReported", @already_reported) writer.write_string_value("reportId", @report_id) writer.write_boolean_value("success", @success) writer.write_string_value("timestamp", @timestamp) end |
#success ⇒ Object
Gets the success property value. The success property
89 90 91 |
# File 'lib/teambattles_sdk/generated/models/report_chat_message_response.rb', line 89 def success return @success end |
#success=(value) ⇒ Object
Sets the success property value. The success property
97 98 99 |
# File 'lib/teambattles_sdk/generated/models/report_chat_message_response.rb', line 97 def success=(value) @success = value end |
#timestamp ⇒ Object
Gets the timestamp property value. Response generation time (ISO 8601).
104 105 106 |
# File 'lib/teambattles_sdk/generated/models/report_chat_message_response.rb', line 104 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. Response generation time (ISO 8601).
112 113 114 |
# File 'lib/teambattles_sdk/generated/models/report_chat_message_response.rb', line 112 def (value) @timestamp = value end |