Class: TeamBattlesSdk::Generated::Models::SeasonsRequestBody
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::SeasonsRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/seasons_request_body.rb
Overview
Game and status filters for league seasons.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#game_id ⇒ Object
Gets the gameId property value.
-
#game_id=(value) ⇒ Object
Sets the gameId property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new SeasonsRequestBody and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#status ⇒ Object
Gets the status property value.
-
#status=(value) ⇒ Object
Sets the status property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new SeasonsRequestBody and sets the default values.
40 41 42 |
# File 'lib/teambattles_sdk/generated/models/seasons_request_body.rb', line 40 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
48 49 50 51 |
# File 'lib/teambattles_sdk/generated/models/seasons_request_body.rb', line 48 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return SeasonsRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
25 26 27 |
# File 'lib/teambattles_sdk/generated/models/seasons_request_body.rb', line 25 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
33 34 35 |
# File 'lib/teambattles_sdk/generated/models/seasons_request_body.rb', line 33 def additional_data=(value) @additional_data = value end |
#game_id ⇒ Object
Gets the gameId property value. Filter seasons to a specific game id.
56 57 58 |
# File 'lib/teambattles_sdk/generated/models/seasons_request_body.rb', line 56 def game_id return @game_id end |
#game_id=(value) ⇒ Object
Sets the gameId property value. Filter seasons to a specific game id.
64 65 66 |
# File 'lib/teambattles_sdk/generated/models/seasons_request_body.rb', line 64 def game_id=(value) @game_id = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
71 72 73 74 75 76 |
# File 'lib/teambattles_sdk/generated/models/seasons_request_body.rb', line 71 def get_field_deserializers() return { "gameId" => lambda {|n| @game_id = n.get_string_value() }, "status" => lambda {|n| @status = n.get_enum_value(TeamBattlesSdk::Generated::Models::SeasonsRequestBodyStatus) }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
82 83 84 85 86 87 |
# File 'lib/teambattles_sdk/generated/models/seasons_request_body.rb', line 82 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("gameId", @game_id) writer.write_enum_value("status", @status) writer.write_additional_data(@additional_data) end |
#status ⇒ Object
Gets the status property value. Filter seasons by lifecycle status.
92 93 94 |
# File 'lib/teambattles_sdk/generated/models/seasons_request_body.rb', line 92 def status return @status end |
#status=(value) ⇒ Object
Sets the status property value. Filter seasons by lifecycle status.
100 101 102 |
# File 'lib/teambattles_sdk/generated/models/seasons_request_body.rb', line 100 def status=(value) @status = value end |