Class: TeamBattlesSdk::Generated::Models::StandingsRequestBody
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::StandingsRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/standings_request_body.rb
Overview
Season and game filters for league standings.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#game_id ⇒ Object
Gets the gameId property value.
-
#game_id=(value) ⇒ Object
Sets the gameId property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new StandingsRequestBody and sets the default values.
-
#limit ⇒ Object
Gets the limit property value.
-
#limit=(value) ⇒ Object
Sets the limit property value.
-
#season_id ⇒ Object
Gets the seasonId property value.
-
#season_id=(value) ⇒ Object
Sets the seasonId property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new StandingsRequestBody and sets the default values.
43 44 45 46 |
# File 'lib/teambattles_sdk/generated/models/standings_request_body.rb', line 43 def initialize() @additional_data = Hash.new @limit = 50 end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
52 53 54 55 |
# File 'lib/teambattles_sdk/generated/models/standings_request_body.rb', line 52 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return StandingsRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
28 29 30 |
# File 'lib/teambattles_sdk/generated/models/standings_request_body.rb', line 28 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
36 37 38 |
# File 'lib/teambattles_sdk/generated/models/standings_request_body.rb', line 36 def additional_data=(value) @additional_data = value end |
#game_id ⇒ Object
Gets the gameId property value. Filter standings to a specific game id.
60 61 62 |
# File 'lib/teambattles_sdk/generated/models/standings_request_body.rb', line 60 def game_id return @game_id end |
#game_id=(value) ⇒ Object
Sets the gameId property value. Filter standings to a specific game id.
68 69 70 |
# File 'lib/teambattles_sdk/generated/models/standings_request_body.rb', line 68 def game_id=(value) @game_id = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
75 76 77 78 79 80 81 |
# File 'lib/teambattles_sdk/generated/models/standings_request_body.rb', line 75 def get_field_deserializers() return { "gameId" => lambda {|n| @game_id = n.get_string_value() }, "limit" => lambda {|n| @limit = n.get_number_value() }, "seasonId" => lambda {|n| @season_id = n.get_string_value() }, } end |
#limit ⇒ Object
Gets the limit property value. Maximum number of teams to return (1-100). Defaults to 50.
86 87 88 |
# File 'lib/teambattles_sdk/generated/models/standings_request_body.rb', line 86 def limit return @limit end |
#limit=(value) ⇒ Object
Sets the limit property value. Maximum number of teams to return (1-100). Defaults to 50.
94 95 96 |
# File 'lib/teambattles_sdk/generated/models/standings_request_body.rb', line 94 def limit=(value) @limit = value end |
#season_id ⇒ Object
Gets the seasonId property value. Filter standings to a specific season id.
101 102 103 |
# File 'lib/teambattles_sdk/generated/models/standings_request_body.rb', line 101 def season_id return @season_id end |
#season_id=(value) ⇒ Object
Sets the seasonId property value. Filter standings to a specific season id.
109 110 111 |
# File 'lib/teambattles_sdk/generated/models/standings_request_body.rb', line 109 def season_id=(value) @season_id = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
117 118 119 120 121 122 123 |
# File 'lib/teambattles_sdk/generated/models/standings_request_body.rb', line 117 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("gameId", @game_id) writer.write_number_value("limit", @limit) writer.write_string_value("seasonId", @season_id) writer.write_additional_data(@additional_data) end |