Class: TeamBattlesSdk::Generated::Models::SubmitScoreBody

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/teambattles_sdk/generated/models/submit_score_body.rb

Overview

Map score submission payload for a single map.

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new SubmitScoreBody and sets the default values.



52
53
54
# File 'lib/teambattles_sdk/generated/models/submit_score_body.rb', line 52

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a submit_score_body

Raises:

  • (StandardError)


60
61
62
63
# File 'lib/teambattles_sdk/generated/models/submit_score_body.rb', line 60

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return SubmitScoreBody.new
end

Instance Method Details

#additional_dataObject

Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



37
38
39
# File 'lib/teambattles_sdk/generated/models/submit_score_body.rb', line 37

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the AdditionalData property.

Returns:

  • a void



45
46
47
# File 'lib/teambattles_sdk/generated/models/submit_score_body.rb', line 45

def additional_data=(value)
    @additional_data = value
end

#creator_team_scoreObject

Gets the creatorTeamScore property value. Creator team score (integer, 0-1000).

Returns:

  • a integer



68
69
70
# File 'lib/teambattles_sdk/generated/models/submit_score_body.rb', line 68

def creator_team_score
    return @creator_team_score
end

#creator_team_score=(value) ⇒ Object

Sets the creatorTeamScore property value. Creator team score (integer, 0-1000).

Parameters:

  • value

    Value to set for the creatorTeamScore property.

Returns:

  • a void



76
77
78
# File 'lib/teambattles_sdk/generated/models/submit_score_body.rb', line 76

def creator_team_score=(value)
    @creator_team_score = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



83
84
85
86
87
88
89
90
91
92
# File 'lib/teambattles_sdk/generated/models/submit_score_body.rb', line 83

def get_field_deserializers()
    return {
        "creatorTeamScore" => lambda {|n| @creator_team_score = n.get_number_value() },
        "mapId" => lambda {|n| @map_id = n.get_string_value() },
        "mapIndex" => lambda {|n| @map_index = n.get_number_value() },
        "opponentTeamScore" => lambda {|n| @opponent_team_score = n.get_number_value() },
        "screenshotStorageIds" => lambda {|n| @screenshot_storage_ids = n.get_collection_of_primitive_values(String) },
        "screenshotUrls" => lambda {|n| @screenshot_urls = n.get_collection_of_primitive_values(String) },
    }
end

#map_idObject

Gets the mapId property value. Map identifier string (e.g. dust2).

Returns:

  • a string



97
98
99
# File 'lib/teambattles_sdk/generated/models/submit_score_body.rb', line 97

def map_id
    return @map_id
end

#map_id=(value) ⇒ Object

Sets the mapId property value. Map identifier string (e.g. dust2).

Parameters:

  • value

    Value to set for the mapId property.

Returns:

  • a void



105
106
107
# File 'lib/teambattles_sdk/generated/models/submit_score_body.rb', line 105

def map_id=(value)
    @map_id = value
end

#map_indexObject

Gets the mapIndex property value. Zero-based map index. Must be a non-negative integer.

Returns:

  • a integer



112
113
114
# File 'lib/teambattles_sdk/generated/models/submit_score_body.rb', line 112

def map_index
    return @map_index
end

#map_index=(value) ⇒ Object

Sets the mapIndex property value. Zero-based map index. Must be a non-negative integer.

Parameters:

  • value

    Value to set for the mapIndex property.

Returns:

  • a void



120
121
122
# File 'lib/teambattles_sdk/generated/models/submit_score_body.rb', line 120

def map_index=(value)
    @map_index = value
end

#opponent_team_scoreObject

Gets the opponentTeamScore property value. Accepted/opponent team score (integer, 0-1000).

Returns:

  • a integer



127
128
129
# File 'lib/teambattles_sdk/generated/models/submit_score_body.rb', line 127

def opponent_team_score
    return @opponent_team_score
end

#opponent_team_score=(value) ⇒ Object

Sets the opponentTeamScore property value. Accepted/opponent team score (integer, 0-1000).

Parameters:

  • value

    Value to set for the opponentTeamScore property.

Returns:

  • a void



135
136
137
# File 'lib/teambattles_sdk/generated/models/submit_score_body.rb', line 135

def opponent_team_score=(value)
    @opponent_team_score = value
end

#screenshot_storage_idsObject

Gets the screenshotStorageIds property value. Optional Convex storage ids from POST /api/v1/uploads/image-url (validated for size + content-type, max 10; preferred over screenshotUrls).

Returns:

  • a string



142
143
144
# File 'lib/teambattles_sdk/generated/models/submit_score_body.rb', line 142

def screenshot_storage_ids
    return @screenshot_storage_ids
end

#screenshot_storage_ids=(value) ⇒ Object

Sets the screenshotStorageIds property value. Optional Convex storage ids from POST /api/v1/uploads/image-url (validated for size + content-type, max 10; preferred over screenshotUrls).

Parameters:

  • value

    Value to set for the screenshotStorageIds property.

Returns:

  • a void



150
151
152
# File 'lib/teambattles_sdk/generated/models/submit_score_body.rb', line 150

def screenshot_storage_ids=(value)
    @screenshot_storage_ids = value
end

#screenshot_urlsObject

Gets the screenshotUrls property value. Optional external screenshot URLs (validated as public https server-side, max 10). Prefer screenshotStorageIds for validated blobs.

Returns:

  • a string



157
158
159
# File 'lib/teambattles_sdk/generated/models/submit_score_body.rb', line 157

def screenshot_urls
    return @screenshot_urls
end

#screenshot_urls=(value) ⇒ Object

Sets the screenshotUrls property value. Optional external screenshot URLs (validated as public https server-side, max 10). Prefer screenshotStorageIds for validated blobs.

Parameters:

  • value

    Value to set for the screenshotUrls property.

Returns:

  • a void



165
166
167
# File 'lib/teambattles_sdk/generated/models/submit_score_body.rb', line 165

def screenshot_urls=(value)
    @screenshot_urls = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


173
174
175
176
177
178
179
180
181
182
# File 'lib/teambattles_sdk/generated/models/submit_score_body.rb', line 173

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_number_value("creatorTeamScore", @creator_team_score)
    writer.write_string_value("mapId", @map_id)
    writer.write_number_value("mapIndex", @map_index)
    writer.write_number_value("opponentTeamScore", @opponent_team_score)
    writer.write_collection_of_primitive_values("screenshotStorageIds", @screenshot_storage_ids)
    writer.write_collection_of_primitive_values("screenshotUrls", @screenshot_urls)
    writer.write_additional_data(@additional_data)
end