Class: TeamBattlesSdk::Generated::Models::TwitchBadgeVersion
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::TwitchBadgeVersion
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/twitch_badge_version.rb
Overview
A single version of a Twitch chat badge.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#click_action ⇒ Object
Gets the click_action property value.
-
#click_action=(value) ⇒ Object
Sets the click_action property value.
-
#click_url ⇒ Object
Gets the click_url property value.
-
#click_url=(value) ⇒ Object
Sets the click_url property value.
-
#description ⇒ Object
Gets the description property value.
-
#description=(value) ⇒ Object
Sets the description property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#id ⇒ Object
Gets the id property value.
-
#id=(value) ⇒ Object
Sets the id property value.
-
#image_url_1x ⇒ Object
Gets the image_url_1x property value.
-
#image_url_1x=(value) ⇒ Object
Sets the image_url_1x property value.
-
#image_url_2x ⇒ Object
Gets the image_url_2x property value.
-
#image_url_2x=(value) ⇒ Object
Sets the image_url_2x property value.
-
#image_url_4x ⇒ Object
Gets the image_url_4x property value.
-
#image_url_4x=(value) ⇒ Object
Sets the image_url_4x property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#title ⇒ Object
Gets the title property value.
-
#title=(value) ⇒ Object
Sets the title property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
71 72 73 74 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 71 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return TwitchBadgeVersion.new end |
Instance Method Details
#click_action ⇒ Object
Gets the click_action property value. Optional click action identifier.
40 41 42 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 40 def click_action return @click_action end |
#click_action=(value) ⇒ Object
Sets the click_action property value. Optional click action identifier.
48 49 50 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 48 def click_action=(value) @click_action = value end |
#click_url ⇒ Object
Gets the click_url property value. Optional URL opened when the badge is clicked.
55 56 57 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 55 def click_url return @click_url end |
#click_url=(value) ⇒ Object
Sets the click_url property value. Optional URL opened when the badge is clicked.
63 64 65 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 63 def click_url=(value) @click_url = value end |
#description ⇒ Object
Gets the description property value. Human-readable badge description.
79 80 81 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 79 def description return @description end |
#description=(value) ⇒ Object
Sets the description property value. Human-readable badge description.
87 88 89 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 87 def description=(value) @description = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 94 def get_field_deserializers() return { "click_action" => lambda {|n| @click_action = n.get_string_value() }, "click_url" => lambda {|n| @click_url = n.get_string_value() }, "description" => lambda {|n| @description = n.get_string_value() }, "id" => lambda {|n| @id = n.get_string_value() }, "image_url_1x" => lambda {|n| @image_url_1x = n.get_string_value() }, "image_url_2x" => lambda {|n| @image_url_2x = n.get_string_value() }, "image_url_4x" => lambda {|n| @image_url_4x = n.get_string_value() }, "title" => lambda {|n| @title = n.get_string_value() }, } end |
#id ⇒ Object
Gets the id property value. Badge version id (e.g. tier level or numeric id).
110 111 112 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 110 def id return @id end |
#id=(value) ⇒ Object
Sets the id property value. Badge version id (e.g. tier level or numeric id).
118 119 120 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 118 def id=(value) @id = value end |
#image_url_1x ⇒ Object
Gets the image_url_1x property value. Badge image URL at 1x resolution.
125 126 127 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 125 def image_url_1x return @image_url_1x end |
#image_url_1x=(value) ⇒ Object
Sets the image_url_1x property value. Badge image URL at 1x resolution.
133 134 135 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 133 def image_url_1x=(value) @image_url_1x = value end |
#image_url_2x ⇒ Object
Gets the image_url_2x property value. Badge image URL at 2x resolution.
140 141 142 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 140 def image_url_2x return @image_url_2x end |
#image_url_2x=(value) ⇒ Object
Sets the image_url_2x property value. Badge image URL at 2x resolution.
148 149 150 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 148 def image_url_2x=(value) @image_url_2x = value end |
#image_url_4x ⇒ Object
Gets the image_url_4x property value. Badge image URL at 4x resolution.
155 156 157 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 155 def image_url_4x return @image_url_4x end |
#image_url_4x=(value) ⇒ Object
Sets the image_url_4x property value. Badge image URL at 4x resolution.
163 164 165 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 163 def image_url_4x=(value) @image_url_4x = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 171 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("click_action", @click_action) writer.write_string_value("click_url", @click_url) writer.write_string_value("description", @description) writer.write_string_value("id", @id) writer.write_string_value("image_url_1x", @image_url_1x) writer.write_string_value("image_url_2x", @image_url_2x) writer.write_string_value("image_url_4x", @image_url_4x) writer.write_string_value("title", @title) end |
#title ⇒ Object
Gets the title property value. Human-readable badge title.
186 187 188 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 186 def title return @title end |
#title=(value) ⇒ Object
Sets the title property value. Human-readable badge title.
194 195 196 |
# File 'lib/teambattles_sdk/generated/models/twitch_badge_version.rb', line 194 def title=(value) @title = value end |