Class: TeamBattlesSdk::Generated::Models::UpdateAttendanceResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::UpdateAttendanceResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/update_attendance_response.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#message ⇒ Object
Gets the message property value.
-
#message=(value) ⇒ Object
Sets the message property value.
-
#reclaimed_spot ⇒ Object
Gets the reclaimedSpot property value.
-
#reclaimed_spot=(value) ⇒ Object
Sets the reclaimedSpot property value.
-
#replaced_by ⇒ Object
Gets the replacedBy property value.
-
#replaced_by=(value) ⇒ Object
Sets the replacedBy property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#success ⇒ Object
Gets the success property value.
-
#success=(value) ⇒ Object
Sets the success property value.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
30 31 32 33 |
# File 'lib/teambattles_sdk/generated/models/update_attendance_response.rb', line 30 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return UpdateAttendanceResponse.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
38 39 40 41 42 43 44 45 46 |
# File 'lib/teambattles_sdk/generated/models/update_attendance_response.rb', line 38 def get_field_deserializers() return { "message" => lambda {|n| @message = n.get_string_value() }, "reclaimedSpot" => lambda {|n| @reclaimed_spot = n.get_boolean_value() }, "replacedBy" => lambda {|n| @replaced_by = n.get_string_value() }, "success" => lambda {|n| @success = n.get_boolean_value() }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, } end |
#message ⇒ Object
Gets the message property value. The message property
51 52 53 |
# File 'lib/teambattles_sdk/generated/models/update_attendance_response.rb', line 51 def return @message end |
#message=(value) ⇒ Object
Sets the message property value. The message property
59 60 61 |
# File 'lib/teambattles_sdk/generated/models/update_attendance_response.rb', line 59 def (value) @message = value end |
#reclaimed_spot ⇒ Object
Gets the reclaimedSpot property value. The reclaimedSpot property
66 67 68 |
# File 'lib/teambattles_sdk/generated/models/update_attendance_response.rb', line 66 def reclaimed_spot return @reclaimed_spot end |
#reclaimed_spot=(value) ⇒ Object
Sets the reclaimedSpot property value. The reclaimedSpot property
74 75 76 |
# File 'lib/teambattles_sdk/generated/models/update_attendance_response.rb', line 74 def reclaimed_spot=(value) @reclaimed_spot = value end |
#replaced_by ⇒ Object
Gets the replacedBy property value. The replacedBy property
81 82 83 |
# File 'lib/teambattles_sdk/generated/models/update_attendance_response.rb', line 81 def replaced_by return @replaced_by end |
#replaced_by=(value) ⇒ Object
Sets the replacedBy property value. The replacedBy property
89 90 91 |
# File 'lib/teambattles_sdk/generated/models/update_attendance_response.rb', line 89 def replaced_by=(value) @replaced_by = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
97 98 99 100 101 102 103 104 |
# File 'lib/teambattles_sdk/generated/models/update_attendance_response.rb', line 97 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("message", @message) writer.write_boolean_value("reclaimedSpot", @reclaimed_spot) writer.write_string_value("replacedBy", @replaced_by) writer.write_boolean_value("success", @success) writer.write_string_value("timestamp", @timestamp) end |
#success ⇒ Object
Gets the success property value. The success property
109 110 111 |
# File 'lib/teambattles_sdk/generated/models/update_attendance_response.rb', line 109 def success return @success end |
#success=(value) ⇒ Object
Sets the success property value. The success property
117 118 119 |
# File 'lib/teambattles_sdk/generated/models/update_attendance_response.rb', line 117 def success=(value) @success = value end |
#timestamp ⇒ Object
Gets the timestamp property value. The timestamp property
124 125 126 |
# File 'lib/teambattles_sdk/generated/models/update_attendance_response.rb', line 124 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. The timestamp property
132 133 134 |
# File 'lib/teambattles_sdk/generated/models/update_attendance_response.rb', line 132 def (value) @timestamp = value end |