Class: TeamBattlesSdk::Generated::Models::UpdateGameRulesRequestBody

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb

Overview

Updates league game rules.

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new UpdateGameRulesRequestBody and sets the default values.



214
215
216
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 214

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a update_game_rules_request_body

Raises:

  • (StandardError)


222
223
224
225
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 222

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return UpdateGameRulesRequestBody.new
end

Instance Method Details

#additional_dataObject

Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



94
95
96
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 94

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the AdditionalData property.

Returns:

  • a void



102
103
104
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 102

def additional_data=(value)
    @additional_data = value
end

#allowed_daysObject

Gets the allowedDays property value. The allowedDays property

Returns:

  • a string



109
110
111
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 109

def allowed_days
    return @allowed_days
end

#allowed_days=(value) ⇒ Object

Sets the allowedDays property value. The allowedDays property

Parameters:

  • value

    Value to set for the allowedDays property.

Returns:

  • a void



117
118
119
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 117

def allowed_days=(value)
    @allowed_days = value
end

#allowed_map_idsObject

Gets the allowedMapIds property value. The allowedMapIds property

Returns:

  • a string



124
125
126
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 124

def allowed_map_ids
    return @allowed_map_ids
end

#allowed_map_ids=(value) ⇒ Object

Sets the allowedMapIds property value. The allowedMapIds property

Parameters:

  • value

    Value to set for the allowedMapIds property.

Returns:

  • a void



132
133
134
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 132

def allowed_map_ids=(value)
    @allowed_map_ids = value
end

#allowed_playlist_idsObject

Gets the allowedPlaylistIds property value. The allowedPlaylistIds property

Returns:

  • a string



139
140
141
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 139

def allowed_playlist_ids
    return @allowed_playlist_ids
end

#allowed_playlist_ids=(value) ⇒ Object

Sets the allowedPlaylistIds property value. The allowedPlaylistIds property

Parameters:

  • value

    Value to set for the allowedPlaylistIds property.

Returns:

  • a void



147
148
149
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 147

def allowed_playlist_ids=(value)
    @allowed_playlist_ids = value
end

#allowed_time_rangeObject

Gets the allowedTimeRange property value. The allowedTimeRange property

Returns:

  • a update_game_rules_request_body_allowed_time_range



154
155
156
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 154

def allowed_time_range
    return @allowed_time_range
end

#allowed_time_range=(value) ⇒ Object

Sets the allowedTimeRange property value. The allowedTimeRange property

Parameters:

  • value

    Value to set for the allowedTimeRange property.

Returns:

  • a void



162
163
164
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 162

def allowed_time_range=(value)
    @allowed_time_range = value
end

#blocked_daysObject

Gets the blockedDays property value. The blockedDays property

Returns:

  • a string



169
170
171
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 169

def blocked_days
    return @blocked_days
end

#blocked_days=(value) ⇒ Object

Sets the blockedDays property value. The blockedDays property

Parameters:

  • value

    Value to set for the blockedDays property.

Returns:

  • a void



177
178
179
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 177

def blocked_days=(value)
    @blocked_days = value
end

#challenge_cooldown_minutesObject

Gets the challengeCooldownMinutes property value. The challengeCooldownMinutes property

Returns:

  • a double



184
185
186
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 184

def challenge_cooldown_minutes
    return @challenge_cooldown_minutes
end

#challenge_cooldown_minutes=(value) ⇒ Object

Sets the challengeCooldownMinutes property value. The challengeCooldownMinutes property

Parameters:

  • value

    Value to set for the challengeCooldownMinutes property.

Returns:

  • a void



192
193
194
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 192

def challenge_cooldown_minutes=(value)
    @challenge_cooldown_minutes = value
end

#challenges_enabledObject

Gets the challengesEnabled property value. The challengesEnabled property

Returns:

  • a boolean



199
200
201
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 199

def challenges_enabled
    return @challenges_enabled
end

#challenges_enabled=(value) ⇒ Object

Sets the challengesEnabled property value. The challengesEnabled property

Parameters:

  • value

    Value to set for the challengesEnabled property.

Returns:

  • a void



207
208
209
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 207

def challenges_enabled=(value)
    @challenges_enabled = value
end

#force_competitiveObject

Gets the forceCompetitive property value. The forceCompetitive property

Returns:

  • a boolean



230
231
232
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 230

def force_competitive
    return @force_competitive
end

#force_competitive=(value) ⇒ Object

Sets the forceCompetitive property value. The forceCompetitive property

Parameters:

  • value

    Value to set for the forceCompetitive property.

Returns:

  • a void



238
239
240
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 238

def force_competitive=(value)
    @force_competitive = value
end

#game_idObject

Gets the gameId property value. Game ID whose league rules should change.

Returns:

  • a string



245
246
247
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 245

def game_id
    return @game_id
end

#game_id=(value) ⇒ Object

Sets the gameId property value. Game ID whose league rules should change.

Parameters:

  • value

    Value to set for the gameId property.

Returns:

  • a void



253
254
255
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 253

def game_id=(value)
    @game_id = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 260

def get_field_deserializers()
    return {
        "allowedDays" => lambda {|n| @allowed_days = n.get_collection_of_primitive_values(String) },
        "allowedMapIds" => lambda {|n| @allowed_map_ids = n.get_collection_of_primitive_values(String) },
        "allowedPlaylistIds" => lambda {|n| @allowed_playlist_ids = n.get_collection_of_primitive_values(String) },
        "allowedTimeRange" => lambda {|n| @allowed_time_range = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::UpdateGameRulesRequestBodyAllowedTimeRange.create_from_discriminator_value(pn) }) },
        "blockedDays" => lambda {|n| @blocked_days = n.get_collection_of_primitive_values(String) },
        "challengeCooldownMinutes" => lambda {|n| @challenge_cooldown_minutes = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "challengesEnabled" => lambda {|n| @challenges_enabled = n.get_boolean_value() },
        "forceCompetitive" => lambda {|n| @force_competitive = n.get_boolean_value() },
        "gameId" => lambda {|n| @game_id = n.get_string_value() },
        "matchFormat" => lambda {|n| @match_format = n.get_enum_value(TeamBattlesSdk::Generated::Models::UpdateGameRulesRequestBodyMatchFormat) },
        "maxChallengesPerTeamPerSeason" => lambda {|n| @max_challenges_per_team_per_season = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "maxPendingChallengesPerOpponent" => lambda {|n| @max_pending_challenges_per_opponent = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "maxPendingChallengesTotal" => lambda {|n| @max_pending_challenges_total = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "maxPointsMatchesPerPairPer24h" => lambda {|n| @max_points_matches_per_pair_per24h = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "maxRosterChangesPerWeek" => lambda {|n| @max_roster_changes_per_week = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "maxRosterSize" => lambda {|n| @max_roster_size = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "maxWagerAmount" => lambda {|n| @max_wager_amount = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "minRosterSize" => lambda {|n| @min_roster_size = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "minWagerAmount" => lambda {|n| @min_wager_amount = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) },
        "rosterChangeWindowDays" => lambda {|n| @roster_change_window_days = n.get_collection_of_primitive_values(String) },
        "rosterChangeWindowTime" => lambda {|n| @roster_change_window_time = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::UpdateGameRulesRequestBodyRosterChangeWindowTime.create_from_discriminator_value(pn) }) },
        "rosterLockEnabled" => lambda {|n| @roster_lock_enabled = n.get_boolean_value() },
        "teamSize" => lambda {|n| @team_size = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::UpdateGameRulesRequestBodyTeamSize.create_from_discriminator_value(pn) }) },
        "timezone" => lambda {|n| @timezone = n.get_string_value() },
        "wagersAllowed" => lambda {|n| @wagers_allowed = n.get_boolean_value() },
    }
end

#match_formatObject

Gets the matchFormat property value. The matchFormat property

Returns:

  • a update_game_rules_request_body_match_format



293
294
295
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 293

def match_format
    return @match_format
end

#match_format=(value) ⇒ Object

Sets the matchFormat property value. The matchFormat property

Parameters:

  • value

    Value to set for the matchFormat property.

Returns:

  • a void



301
302
303
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 301

def match_format=(value)
    @match_format = value
end

#max_challenges_per_team_per_seasonObject

Gets the maxChallengesPerTeamPerSeason property value. The maxChallengesPerTeamPerSeason property

Returns:

  • a double



308
309
310
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 308

def max_challenges_per_team_per_season
    return @max_challenges_per_team_per_season
end

#max_challenges_per_team_per_season=(value) ⇒ Object

Sets the maxChallengesPerTeamPerSeason property value. The maxChallengesPerTeamPerSeason property

Parameters:

  • value

    Value to set for the maxChallengesPerTeamPerSeason property.

Returns:

  • a void



316
317
318
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 316

def max_challenges_per_team_per_season=(value)
    @max_challenges_per_team_per_season = value
end

#max_pending_challenges_per_opponentObject

Gets the maxPendingChallengesPerOpponent property value. The maxPendingChallengesPerOpponent property

Returns:

  • a double



323
324
325
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 323

def max_pending_challenges_per_opponent
    return @max_pending_challenges_per_opponent
end

#max_pending_challenges_per_opponent=(value) ⇒ Object

Sets the maxPendingChallengesPerOpponent property value. The maxPendingChallengesPerOpponent property

Parameters:

  • value

    Value to set for the maxPendingChallengesPerOpponent property.

Returns:

  • a void



331
332
333
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 331

def max_pending_challenges_per_opponent=(value)
    @max_pending_challenges_per_opponent = value
end

#max_pending_challenges_totalObject

Gets the maxPendingChallengesTotal property value. The maxPendingChallengesTotal property

Returns:

  • a double



338
339
340
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 338

def max_pending_challenges_total
    return @max_pending_challenges_total
end

#max_pending_challenges_total=(value) ⇒ Object

Sets the maxPendingChallengesTotal property value. The maxPendingChallengesTotal property

Parameters:

  • value

    Value to set for the maxPendingChallengesTotal property.

Returns:

  • a void



346
347
348
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 346

def max_pending_challenges_total=(value)
    @max_pending_challenges_total = value
end

#max_points_matches_per_pair_per24hObject

Gets the maxPointsMatchesPerPairPer24h property value. The maxPointsMatchesPerPairPer24h property

Returns:

  • a double



353
354
355
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 353

def max_points_matches_per_pair_per24h
    return @max_points_matches_per_pair_per24h
end

#max_points_matches_per_pair_per24h=(value) ⇒ Object

Sets the maxPointsMatchesPerPairPer24h property value. The maxPointsMatchesPerPairPer24h property

Parameters:

  • value

    Value to set for the maxPointsMatchesPerPairPer24h property.

Returns:

  • a void



361
362
363
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 361

def max_points_matches_per_pair_per24h=(value)
    @max_points_matches_per_pair_per24h = value
end

#max_roster_changes_per_weekObject

Gets the maxRosterChangesPerWeek property value. The maxRosterChangesPerWeek property

Returns:

  • a double



368
369
370
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 368

def max_roster_changes_per_week
    return @max_roster_changes_per_week
end

#max_roster_changes_per_week=(value) ⇒ Object

Sets the maxRosterChangesPerWeek property value. The maxRosterChangesPerWeek property

Parameters:

  • value

    Value to set for the maxRosterChangesPerWeek property.

Returns:

  • a void



376
377
378
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 376

def max_roster_changes_per_week=(value)
    @max_roster_changes_per_week = value
end

#max_roster_sizeObject

Gets the maxRosterSize property value. The maxRosterSize property

Returns:

  • a double



383
384
385
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 383

def max_roster_size
    return @max_roster_size
end

#max_roster_size=(value) ⇒ Object

Sets the maxRosterSize property value. The maxRosterSize property

Parameters:

  • value

    Value to set for the maxRosterSize property.

Returns:

  • a void



391
392
393
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 391

def max_roster_size=(value)
    @max_roster_size = value
end

#max_wager_amountObject

Gets the maxWagerAmount property value. The maxWagerAmount property

Returns:

  • a double



398
399
400
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 398

def max_wager_amount
    return @max_wager_amount
end

#max_wager_amount=(value) ⇒ Object

Sets the maxWagerAmount property value. The maxWagerAmount property

Parameters:

  • value

    Value to set for the maxWagerAmount property.

Returns:

  • a void



406
407
408
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 406

def max_wager_amount=(value)
    @max_wager_amount = value
end

#min_roster_sizeObject

Gets the minRosterSize property value. The minRosterSize property

Returns:

  • a double



413
414
415
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 413

def min_roster_size
    return @min_roster_size
end

#min_roster_size=(value) ⇒ Object

Sets the minRosterSize property value. The minRosterSize property

Parameters:

  • value

    Value to set for the minRosterSize property.

Returns:

  • a void



421
422
423
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 421

def min_roster_size=(value)
    @min_roster_size = value
end

#min_wager_amountObject

Gets the minWagerAmount property value. The minWagerAmount property

Returns:

  • a double



428
429
430
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 428

def min_wager_amount
    return @min_wager_amount
end

#min_wager_amount=(value) ⇒ Object

Sets the minWagerAmount property value. The minWagerAmount property

Parameters:

  • value

    Value to set for the minWagerAmount property.

Returns:

  • a void



436
437
438
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 436

def min_wager_amount=(value)
    @min_wager_amount = value
end

#roster_change_window_daysObject

Gets the rosterChangeWindowDays property value. The rosterChangeWindowDays property

Returns:

  • a string



443
444
445
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 443

def roster_change_window_days
    return @roster_change_window_days
end

#roster_change_window_days=(value) ⇒ Object

Sets the rosterChangeWindowDays property value. The rosterChangeWindowDays property

Parameters:

  • value

    Value to set for the rosterChangeWindowDays property.

Returns:

  • a void



451
452
453
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 451

def roster_change_window_days=(value)
    @roster_change_window_days = value
end

#roster_change_window_timeObject

Gets the rosterChangeWindowTime property value. The rosterChangeWindowTime property

Returns:

  • a update_game_rules_request_body_roster_change_window_time



458
459
460
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 458

def roster_change_window_time
    return @roster_change_window_time
end

#roster_change_window_time=(value) ⇒ Object

Sets the rosterChangeWindowTime property value. The rosterChangeWindowTime property

Parameters:

  • value

    Value to set for the rosterChangeWindowTime property.

Returns:

  • a void



466
467
468
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 466

def roster_change_window_time=(value)
    @roster_change_window_time = value
end

#roster_lock_enabledObject

Gets the rosterLockEnabled property value. The rosterLockEnabled property

Returns:

  • a boolean



473
474
475
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 473

def roster_lock_enabled
    return @roster_lock_enabled
end

#roster_lock_enabled=(value) ⇒ Object

Sets the rosterLockEnabled property value. The rosterLockEnabled property

Parameters:

  • value

    Value to set for the rosterLockEnabled property.

Returns:

  • a void



481
482
483
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 481

def roster_lock_enabled=(value)
    @roster_lock_enabled = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 489

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_collection_of_primitive_values("allowedDays", @allowed_days)
    writer.write_collection_of_primitive_values("allowedMapIds", @allowed_map_ids)
    writer.write_collection_of_primitive_values("allowedPlaylistIds", @allowed_playlist_ids)
    writer.write_object_value("allowedTimeRange", @allowed_time_range)
    writer.write_collection_of_primitive_values("blockedDays", @blocked_days)
    writer.write_object_value("challengeCooldownMinutes", @challenge_cooldown_minutes)
    writer.write_boolean_value("challengesEnabled", @challenges_enabled)
    writer.write_boolean_value("forceCompetitive", @force_competitive)
    writer.write_string_value("gameId", @game_id)
    writer.write_enum_value("matchFormat", @match_format)
    writer.write_object_value("maxChallengesPerTeamPerSeason", @max_challenges_per_team_per_season)
    writer.write_object_value("maxPendingChallengesPerOpponent", @max_pending_challenges_per_opponent)
    writer.write_object_value("maxPendingChallengesTotal", @max_pending_challenges_total)
    writer.write_object_value("maxPointsMatchesPerPairPer24h", @max_points_matches_per_pair_per24h)
    writer.write_object_value("maxRosterChangesPerWeek", @max_roster_changes_per_week)
    writer.write_object_value("maxRosterSize", @max_roster_size)
    writer.write_object_value("maxWagerAmount", @max_wager_amount)
    writer.write_object_value("minRosterSize", @min_roster_size)
    writer.write_object_value("minWagerAmount", @min_wager_amount)
    writer.write_collection_of_primitive_values("rosterChangeWindowDays", @roster_change_window_days)
    writer.write_object_value("rosterChangeWindowTime", @roster_change_window_time)
    writer.write_boolean_value("rosterLockEnabled", @roster_lock_enabled)
    writer.write_object_value("teamSize", @team_size)
    writer.write_string_value("timezone", @timezone)
    writer.write_boolean_value("wagersAllowed", @wagers_allowed)
    writer.write_additional_data(@additional_data)
end

#team_sizeObject

Gets the teamSize property value. The teamSize property

Returns:

  • a update_game_rules_request_body_team_size



522
523
524
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 522

def team_size
    return @team_size
end

#team_size=(value) ⇒ Object

Sets the teamSize property value. The teamSize property

Parameters:

  • value

    Value to set for the teamSize property.

Returns:

  • a void



530
531
532
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 530

def team_size=(value)
    @team_size = value
end

#timezoneObject

Gets the timezone property value. The timezone property

Returns:

  • a string



537
538
539
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 537

def timezone
    return @timezone
end

#timezone=(value) ⇒ Object

Sets the timezone property value. The timezone property

Parameters:

  • value

    Value to set for the timezone property.

Returns:

  • a void



545
546
547
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 545

def timezone=(value)
    @timezone = value
end

#wagers_allowedObject

Gets the wagersAllowed property value. The wagersAllowed property

Returns:

  • a boolean



552
553
554
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 552

def wagers_allowed
    return @wagers_allowed
end

#wagers_allowed=(value) ⇒ Object

Sets the wagersAllowed property value. The wagersAllowed property

Parameters:

  • value

    Value to set for the wagersAllowed property.

Returns:

  • a void



560
561
562
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body.rb', line 560

def wagers_allowed=(value)
    @wagers_allowed = value
end