Class: TeamBattlesSdk::Generated::Models::UpdateGameRulesRequestBodyTeamSize
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::UpdateGameRulesRequestBodyTeamSize
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/update_game_rules_request_body_team_size.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new UpdateGameRulesRequestBodyTeamSize and sets the default values.
-
#max ⇒ Object
Gets the max property value.
-
#max=(value) ⇒ Object
Sets the max property value.
-
#min ⇒ Object
Gets the min property value.
-
#min=(value) ⇒ Object
Sets the min property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new UpdateGameRulesRequestBodyTeamSize and sets the default values.
38 39 40 |
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body_team_size.rb', line 38 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
46 47 48 49 |
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body_team_size.rb', line 46 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return UpdateGameRulesRequestBodyTeamSize.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
23 24 25 |
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body_team_size.rb', line 23 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
31 32 33 |
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body_team_size.rb', line 31 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
54 55 56 57 58 59 |
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body_team_size.rb', line 54 def get_field_deserializers() return { "max" => lambda {|n| @max = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) }, "min" => lambda {|n| @min = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) }, } end |
#max ⇒ Object
Gets the max property value. The max property
64 65 66 |
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body_team_size.rb', line 64 def max return @max end |
#max=(value) ⇒ Object
Sets the max property value. The max property
72 73 74 |
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body_team_size.rb', line 72 def max=(value) @max = value end |
#min ⇒ Object
Gets the min property value. The min property
79 80 81 |
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body_team_size.rb', line 79 def min return @min end |
#min=(value) ⇒ Object
Sets the min property value. The min property
87 88 89 |
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body_team_size.rb', line 87 def min=(value) @min = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
95 96 97 98 99 100 |
# File 'lib/teambattles_sdk/generated/models/update_game_rules_request_body_team_size.rb', line 95 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("max", @max) writer.write_object_value("min", @min) writer.write_additional_data(@additional_data) end |