Class: TeamBattlesSdk::Generated::Models::UpdateLeagueBrandingRequestBody
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::UpdateLeagueBrandingRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb
Overview
Updates league profile branding and public metadata.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#avatar_storage_id ⇒ Object
Gets the avatarStorageId property value.
-
#avatar_storage_id=(value) ⇒ Object
Sets the avatarStorageId property value.
-
#banner_storage_id ⇒ Object
Gets the bannerStorageId property value.
-
#banner_storage_id=(value) ⇒ Object
Sets the bannerStorageId property value.
-
#description ⇒ Object
Gets the description property value.
-
#description=(value) ⇒ Object
Sets the description property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new UpdateLeagueBrandingRequestBody and sets the default values.
-
#name ⇒ Object
Gets the name property value.
-
#name=(value) ⇒ Object
Sets the name property value.
-
#profile_theme_id ⇒ Object
Gets the profileThemeId property value.
-
#profile_theme_id=(value) ⇒ Object
Sets the profileThemeId property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#socials ⇒ Object
Gets the socials property value.
-
#socials=(value) ⇒ Object
Sets the socials property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new UpdateLeagueBrandingRequestBody and sets the default values.
82 83 84 |
# File 'lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb', line 82 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
90 91 92 93 |
# File 'lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb', line 90 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return UpdateLeagueBrandingRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
37 38 39 |
# File 'lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb', line 37 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
45 46 47 |
# File 'lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb', line 45 def additional_data=(value) @additional_data = value end |
#avatar_storage_id ⇒ Object
Gets the avatarStorageId property value. Convex storage ID for the league avatar.
52 53 54 |
# File 'lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb', line 52 def avatar_storage_id return @avatar_storage_id end |
#avatar_storage_id=(value) ⇒ Object
Sets the avatarStorageId property value. Convex storage ID for the league avatar.
60 61 62 |
# File 'lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb', line 60 def avatar_storage_id=(value) @avatar_storage_id = value end |
#banner_storage_id ⇒ Object
Gets the bannerStorageId property value. Convex storage ID for the league banner.
67 68 69 |
# File 'lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb', line 67 def return @banner_storage_id end |
#banner_storage_id=(value) ⇒ Object
Sets the bannerStorageId property value. Convex storage ID for the league banner.
75 76 77 |
# File 'lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb', line 75 def (value) @banner_storage_id = value end |
#description ⇒ Object
Gets the description property value. The description property
98 99 100 |
# File 'lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb', line 98 def description return @description end |
#description=(value) ⇒ Object
Sets the description property value. The description property
106 107 108 |
# File 'lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb', line 106 def description=(value) @description = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
113 114 115 116 117 118 119 120 121 122 |
# File 'lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb', line 113 def get_field_deserializers() return { "avatarStorageId" => lambda {|n| @avatar_storage_id = n.get_string_value() }, "bannerStorageId" => lambda {|n| @banner_storage_id = n.get_string_value() }, "description" => lambda {|n| @description = n.get_string_value() }, "name" => lambda {|n| @name = n.get_string_value() }, "profileThemeId" => lambda {|n| @profile_theme_id = n.get_string_value() }, "socials" => lambda {|n| @socials = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::LeagueBrandingSocials.create_from_discriminator_value(pn) }) }, } end |
#name ⇒ Object
Gets the name property value. The name property
127 128 129 |
# File 'lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb', line 127 def name return @name end |
#name=(value) ⇒ Object
Sets the name property value. The name property
135 136 137 |
# File 'lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb', line 135 def name=(value) @name = value end |
#profile_theme_id ⇒ Object
Gets the profileThemeId property value. The profileThemeId property
142 143 144 |
# File 'lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb', line 142 def profile_theme_id return @profile_theme_id end |
#profile_theme_id=(value) ⇒ Object
Sets the profileThemeId property value. The profileThemeId property
150 151 152 |
# File 'lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb', line 150 def profile_theme_id=(value) @profile_theme_id = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
158 159 160 161 162 163 164 165 166 167 |
# File 'lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb', line 158 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("avatarStorageId", @avatar_storage_id) writer.write_string_value("bannerStorageId", @banner_storage_id) writer.write_string_value("description", @description) writer.write_string_value("name", @name) writer.write_string_value("profileThemeId", @profile_theme_id) writer.write_object_value("socials", @socials) writer.write_additional_data(@additional_data) end |
#socials ⇒ Object
Gets the socials property value. The socials property
172 173 174 |
# File 'lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb', line 172 def return @socials end |
#socials=(value) ⇒ Object
Sets the socials property value. The socials property
180 181 182 |
# File 'lib/teambattles_sdk/generated/models/update_league_branding_request_body.rb', line 180 def (value) @socials = value end |