Class: TeamBattlesSdk::Generated::Models::UpdateLobbyCodeRequestBody
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::UpdateLobbyCodeRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/update_lobby_code_request_body.rb
Overview
Sets or updates the match lobby code as the API key owner.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new UpdateLobbyCodeRequestBody and sets the default values.
-
#lobby_code ⇒ Object
Gets the lobbyCode property value.
-
#lobby_code=(value) ⇒ Object
Sets the lobbyCode property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new UpdateLobbyCodeRequestBody and sets the default values.
37 38 39 |
# File 'lib/teambattles_sdk/generated/models/update_lobby_code_request_body.rb', line 37 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
45 46 47 48 |
# File 'lib/teambattles_sdk/generated/models/update_lobby_code_request_body.rb', line 45 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return UpdateLobbyCodeRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
22 23 24 |
# File 'lib/teambattles_sdk/generated/models/update_lobby_code_request_body.rb', line 22 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
30 31 32 |
# File 'lib/teambattles_sdk/generated/models/update_lobby_code_request_body.rb', line 30 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
53 54 55 56 57 |
# File 'lib/teambattles_sdk/generated/models/update_lobby_code_request_body.rb', line 53 def get_field_deserializers() return { "lobbyCode" => lambda {|n| @lobby_code = n.get_string_value() }, } end |
#lobby_code ⇒ Object
Gets the lobbyCode property value. Lobby code to set for the match.
62 63 64 |
# File 'lib/teambattles_sdk/generated/models/update_lobby_code_request_body.rb', line 62 def lobby_code return @lobby_code end |
#lobby_code=(value) ⇒ Object
Sets the lobbyCode property value. Lobby code to set for the match.
70 71 72 |
# File 'lib/teambattles_sdk/generated/models/update_lobby_code_request_body.rb', line 70 def lobby_code=(value) @lobby_code = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
78 79 80 81 82 |
# File 'lib/teambattles_sdk/generated/models/update_lobby_code_request_body.rb', line 78 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("lobbyCode", @lobby_code) writer.write_additional_data(@additional_data) end |