Class: TeamBattlesSdk::Generated::Models::UpdateOrgBody

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/teambattles_sdk/generated/models/update_org_body.rb

Overview

Fields to update on the organization. All optional.

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new UpdateOrgBody and sets the default values.



49
50
51
# File 'lib/teambattles_sdk/generated/models/update_org_body.rb', line 49

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a update_org_body

Raises:

  • (StandardError)


57
58
59
60
# File 'lib/teambattles_sdk/generated/models/update_org_body.rb', line 57

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return UpdateOrgBody.new
end

Instance Method Details

#additional_dataObject

Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



34
35
36
# File 'lib/teambattles_sdk/generated/models/update_org_body.rb', line 34

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the AdditionalData property.

Returns:

  • a void



42
43
44
# File 'lib/teambattles_sdk/generated/models/update_org_body.rb', line 42

def additional_data=(value)
    @additional_data = value
end

#descriptionObject

Gets the description property value. The description property

Returns:

  • a string



65
66
67
# File 'lib/teambattles_sdk/generated/models/update_org_body.rb', line 65

def description
    return @description
end

#description=(value) ⇒ Object

Sets the description property value. The description property

Parameters:

  • value

    Value to set for the description property.

Returns:

  • a void



73
74
75
# File 'lib/teambattles_sdk/generated/models/update_org_body.rb', line 73

def description=(value)
    @description = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



80
81
82
83
84
85
86
87
88
# File 'lib/teambattles_sdk/generated/models/update_org_body.rb', line 80

def get_field_deserializers()
    return {
        "description" => lambda {|n| @description = n.get_string_value() },
        "isPublic" => lambda {|n| @is_public = n.get_boolean_value() },
        "name" => lambda {|n| @name = n.get_string_value() },
        "profileVisibility" => lambda {|n| @profile_visibility = n.get_enum_value(TeamBattlesSdk::Generated::Models::UpdateOrgBodyProfileVisibility) },
        "tag" => lambda {|n| @tag = n.get_string_value() },
    }
end

#is_publicObject

Gets the isPublic property value. The isPublic property

Returns:

  • a boolean



93
94
95
# File 'lib/teambattles_sdk/generated/models/update_org_body.rb', line 93

def is_public
    return @is_public
end

#is_public=(value) ⇒ Object

Sets the isPublic property value. The isPublic property

Parameters:

  • value

    Value to set for the isPublic property.

Returns:

  • a void



101
102
103
# File 'lib/teambattles_sdk/generated/models/update_org_body.rb', line 101

def is_public=(value)
    @is_public = value
end

#nameObject

Gets the name property value. The name property

Returns:

  • a string



108
109
110
# File 'lib/teambattles_sdk/generated/models/update_org_body.rb', line 108

def name
    return @name
end

#name=(value) ⇒ Object

Sets the name property value. The name property

Parameters:

  • value

    Value to set for the name property.

Returns:

  • a void



116
117
118
# File 'lib/teambattles_sdk/generated/models/update_org_body.rb', line 116

def name=(value)
    @name = value
end

#profile_visibilityObject

Gets the profileVisibility property value. The profileVisibility property

Returns:

  • a update_org_body_profile_visibility



123
124
125
# File 'lib/teambattles_sdk/generated/models/update_org_body.rb', line 123

def profile_visibility
    return @profile_visibility
end

#profile_visibility=(value) ⇒ Object

Sets the profileVisibility property value. The profileVisibility property

Parameters:

  • value

    Value to set for the profileVisibility property.

Returns:

  • a void



131
132
133
# File 'lib/teambattles_sdk/generated/models/update_org_body.rb', line 131

def profile_visibility=(value)
    @profile_visibility = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


139
140
141
142
143
144
145
146
147
# File 'lib/teambattles_sdk/generated/models/update_org_body.rb', line 139

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("description", @description)
    writer.write_boolean_value("isPublic", @is_public)
    writer.write_string_value("name", @name)
    writer.write_enum_value("profileVisibility", @profile_visibility)
    writer.write_string_value("tag", @tag)
    writer.write_additional_data(@additional_data)
end

#tagObject

Gets the tag property value. The tag property

Returns:

  • a string



152
153
154
# File 'lib/teambattles_sdk/generated/models/update_org_body.rb', line 152

def tag
    return @tag
end

#tag=(value) ⇒ Object

Sets the tag property value. The tag property

Parameters:

  • value

    Value to set for the tag property.

Returns:

  • a void



160
161
162
# File 'lib/teambattles_sdk/generated/models/update_org_body.rb', line 160

def tag=(value)
    @tag = value
end