Class: TeamBattlesSdk::Generated::Models::UpdatePointsConfigResponse

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/teambattles_sdk/generated/models/update_points_config_response.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a update_points_config_response

Raises:

  • (StandardError)


39
40
41
42
# File 'lib/teambattles_sdk/generated/models/update_points_config_response.rb', line 39

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return UpdatePointsConfigResponse.new
end

Instance Method Details

#config_idObject

Gets the configId property value. The configId property

Returns:

  • a string



23
24
25
# File 'lib/teambattles_sdk/generated/models/update_points_config_response.rb', line 23

def config_id
    return @config_id
end

#config_id=(value) ⇒ Object

Sets the configId property value. The configId property

Parameters:

  • value

    Value to set for the configId property.

Returns:

  • a void



31
32
33
# File 'lib/teambattles_sdk/generated/models/update_points_config_response.rb', line 31

def config_id=(value)
    @config_id = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



47
48
49
50
51
52
53
# File 'lib/teambattles_sdk/generated/models/update_points_config_response.rb', line 47

def get_field_deserializers()
    return {
        "configId" => lambda {|n| @config_id = n.get_string_value() },
        "success" => lambda {|n| @success = n.get_boolean_value() },
        "timestamp" => lambda {|n| @timestamp = n.get_string_value() },
    }
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


59
60
61
62
63
64
# File 'lib/teambattles_sdk/generated/models/update_points_config_response.rb', line 59

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("configId", @config_id)
    writer.write_boolean_value("success", @success)
    writer.write_string_value("timestamp", @timestamp)
end

#successObject

Gets the success property value. The success property

Returns:

  • a boolean



69
70
71
# File 'lib/teambattles_sdk/generated/models/update_points_config_response.rb', line 69

def success
    return @success
end

#success=(value) ⇒ Object

Sets the success property value. The success property

Parameters:

  • value

    Value to set for the success property.

Returns:

  • a void



77
78
79
# File 'lib/teambattles_sdk/generated/models/update_points_config_response.rb', line 77

def success=(value)
    @success = value
end

#timestampObject

Gets the timestamp property value. The timestamp property

Returns:

  • a string



84
85
86
# File 'lib/teambattles_sdk/generated/models/update_points_config_response.rb', line 84

def timestamp
    return @timestamp
end

#timestamp=(value) ⇒ Object

Sets the timestamp property value. The timestamp property

Parameters:

  • value

    Value to set for the timestamp property.

Returns:

  • a void



92
93
94
# File 'lib/teambattles_sdk/generated/models/update_points_config_response.rb', line 92

def timestamp=(value)
    @timestamp = value
end