Class: TeamBattlesSdk::Generated::Models::UpdateTeamBody

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/teambattles_sdk/generated/models/update_team_body.rb

Overview

Fields to update on the team. All optional.

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeObject

Instantiates a new UpdateTeamBody and sets the default values.



52
53
54
# File 'lib/teambattles_sdk/generated/models/update_team_body.rb', line 52

def initialize()
    @additional_data = Hash.new
end

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a update_team_body

Raises:

  • (StandardError)


60
61
62
63
# File 'lib/teambattles_sdk/generated/models/update_team_body.rb', line 60

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return UpdateTeamBody.new
end

Instance Method Details

#additional_dataObject

Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Returns:

  • a i_dictionary



37
38
39
# File 'lib/teambattles_sdk/generated/models/update_team_body.rb', line 37

def additional_data
    return @additional_data
end

#additional_data=(value) ⇒ Object

Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.

Parameters:

  • value

    Value to set for the AdditionalData property.

Returns:

  • a void



45
46
47
# File 'lib/teambattles_sdk/generated/models/update_team_body.rb', line 45

def additional_data=(value)
    @additional_data = value
end

#descriptionObject

Gets the description property value. The description property

Returns:

  • a string



68
69
70
# File 'lib/teambattles_sdk/generated/models/update_team_body.rb', line 68

def description
    return @description
end

#description=(value) ⇒ Object

Sets the description property value. The description property

Parameters:

  • value

    Value to set for the description property.

Returns:

  • a void



76
77
78
# File 'lib/teambattles_sdk/generated/models/update_team_body.rb', line 76

def description=(value)
    @description = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



83
84
85
86
87
88
89
90
91
92
# File 'lib/teambattles_sdk/generated/models/update_team_body.rb', line 83

def get_field_deserializers()
    return {
        "description" => lambda {|n| @description = n.get_string_value() },
        "name" => lambda {|n| @name = n.get_string_value() },
        "platform" => lambda {|n| @platform = n.get_string_value() },
        "profileVisibility" => lambda {|n| @profile_visibility = n.get_enum_value(TeamBattlesSdk::Generated::Models::UpdateTeamBodyProfileVisibility) },
        "region" => lambda {|n| @region = n.get_enum_value(TeamBattlesSdk::Generated::Models::UpdateTeamBodyRegion) },
        "tag" => lambda {|n| @tag = n.get_string_value() },
    }
end

#nameObject

Gets the name property value. The name property

Returns:

  • a string



97
98
99
# File 'lib/teambattles_sdk/generated/models/update_team_body.rb', line 97

def name
    return @name
end

#name=(value) ⇒ Object

Sets the name property value. The name property

Parameters:

  • value

    Value to set for the name property.

Returns:

  • a void



105
106
107
# File 'lib/teambattles_sdk/generated/models/update_team_body.rb', line 105

def name=(value)
    @name = value
end

#platformObject

Gets the platform property value. The platform property

Returns:

  • a string



112
113
114
# File 'lib/teambattles_sdk/generated/models/update_team_body.rb', line 112

def platform
    return @platform
end

#platform=(value) ⇒ Object

Sets the platform property value. The platform property

Parameters:

  • value

    Value to set for the platform property.

Returns:

  • a void



120
121
122
# File 'lib/teambattles_sdk/generated/models/update_team_body.rb', line 120

def platform=(value)
    @platform = value
end

#profile_visibilityObject

Gets the profileVisibility property value. The profileVisibility property

Returns:

  • a update_team_body_profile_visibility



127
128
129
# File 'lib/teambattles_sdk/generated/models/update_team_body.rb', line 127

def profile_visibility
    return @profile_visibility
end

#profile_visibility=(value) ⇒ Object

Sets the profileVisibility property value. The profileVisibility property

Parameters:

  • value

    Value to set for the profileVisibility property.

Returns:

  • a void



135
136
137
# File 'lib/teambattles_sdk/generated/models/update_team_body.rb', line 135

def profile_visibility=(value)
    @profile_visibility = value
end

#regionObject

Gets the region property value. The region property

Returns:

  • a update_team_body_region



142
143
144
# File 'lib/teambattles_sdk/generated/models/update_team_body.rb', line 142

def region
    return @region
end

#region=(value) ⇒ Object

Sets the region property value. The region property

Parameters:

  • value

    Value to set for the region property.

Returns:

  • a void



150
151
152
# File 'lib/teambattles_sdk/generated/models/update_team_body.rb', line 150

def region=(value)
    @region = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


158
159
160
161
162
163
164
165
166
167
# File 'lib/teambattles_sdk/generated/models/update_team_body.rb', line 158

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("description", @description)
    writer.write_string_value("name", @name)
    writer.write_string_value("platform", @platform)
    writer.write_enum_value("profileVisibility", @profile_visibility)
    writer.write_enum_value("region", @region)
    writer.write_string_value("tag", @tag)
    writer.write_additional_data(@additional_data)
end

#tagObject

Gets the tag property value. The tag property

Returns:

  • a string



172
173
174
# File 'lib/teambattles_sdk/generated/models/update_team_body.rb', line 172

def tag
    return @tag
end

#tag=(value) ⇒ Object

Sets the tag property value. The tag property

Parameters:

  • value

    Value to set for the tag property.

Returns:

  • a void



180
181
182
# File 'lib/teambattles_sdk/generated/models/update_team_body.rb', line 180

def tag=(value)
    @tag = value
end