Class: TeamBattlesSdk::Generated::Models::UpdateWebhookBody
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::UpdateWebhookBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/update_webhook_body.rb
Overview
Partial update of a webhook endpoint.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#events ⇒ Object
Gets the events property value.
-
#events=(value) ⇒ Object
Sets the events property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new UpdateWebhookBody and sets the default values.
-
#is_active ⇒ Object
Gets the isActive property value.
-
#is_active=(value) ⇒ Object
Sets the isActive property value.
-
#label ⇒ Object
Gets the label property value.
-
#label=(value) ⇒ Object
Sets the label property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#url ⇒ Object
Gets the url property value.
-
#url=(value) ⇒ Object
Sets the url property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new UpdateWebhookBody and sets the default values.
46 47 48 |
# File 'lib/teambattles_sdk/generated/models/update_webhook_body.rb', line 46 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
54 55 56 57 |
# File 'lib/teambattles_sdk/generated/models/update_webhook_body.rb', line 54 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return UpdateWebhookBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
31 32 33 |
# File 'lib/teambattles_sdk/generated/models/update_webhook_body.rb', line 31 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
39 40 41 |
# File 'lib/teambattles_sdk/generated/models/update_webhook_body.rb', line 39 def additional_data=(value) @additional_data = value end |
#events ⇒ Object
Gets the events property value. Replacement event token list (at least one when present).
62 63 64 |
# File 'lib/teambattles_sdk/generated/models/update_webhook_body.rb', line 62 def events return @events end |
#events=(value) ⇒ Object
Sets the events property value. Replacement event token list (at least one when present).
70 71 72 |
# File 'lib/teambattles_sdk/generated/models/update_webhook_body.rb', line 70 def events=(value) @events = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
77 78 79 80 81 82 83 84 |
# File 'lib/teambattles_sdk/generated/models/update_webhook_body.rb', line 77 def get_field_deserializers() return { "events" => lambda {|n| @events = n.get_collection_of_primitive_values(String) }, "isActive" => lambda {|n| @is_active = n.get_boolean_value() }, "label" => lambda {|n| @label = n.get_string_value() }, "url" => lambda {|n| @url = n.get_string_value() }, } end |
#is_active ⇒ Object
Gets the isActive property value. Enable/disable the endpoint. Re-enabling resets the failure count.
89 90 91 |
# File 'lib/teambattles_sdk/generated/models/update_webhook_body.rb', line 89 def is_active return @is_active end |
#is_active=(value) ⇒ Object
Sets the isActive property value. Enable/disable the endpoint. Re-enabling resets the failure count.
97 98 99 |
# File 'lib/teambattles_sdk/generated/models/update_webhook_body.rb', line 97 def is_active=(value) @is_active = value end |
#label ⇒ Object
Gets the label property value. New human label.
104 105 106 |
# File 'lib/teambattles_sdk/generated/models/update_webhook_body.rb', line 104 def label return @label end |
#label=(value) ⇒ Object
Sets the label property value. New human label.
112 113 114 |
# File 'lib/teambattles_sdk/generated/models/update_webhook_body.rb', line 112 def label=(value) @label = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
120 121 122 123 124 125 126 127 |
# File 'lib/teambattles_sdk/generated/models/update_webhook_body.rb', line 120 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_collection_of_primitive_values("events", @events) writer.write_boolean_value("isActive", @is_active) writer.write_string_value("label", @label) writer.write_string_value("url", @url) writer.write_additional_data(@additional_data) end |
#url ⇒ Object
Gets the url property value. New HTTPS endpoint URL.
132 133 134 |
# File 'lib/teambattles_sdk/generated/models/update_webhook_body.rb', line 132 def url return @url end |
#url=(value) ⇒ Object
Sets the url property value. New HTTPS endpoint URL.
140 141 142 |
# File 'lib/teambattles_sdk/generated/models/update_webhook_body.rb', line 140 def url=(value) @url = value end |