Class: TeamBattlesSdk::Generated::Models::UpsertDisplayRuleRequestBody
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::UpsertDisplayRuleRequestBody
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb
Overview
Creates or updates a display rule.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#category ⇒ Object
Gets the category property value.
-
#category=(value) ⇒ Object
Sets the category property value.
-
#category_icon ⇒ Object
Gets the categoryIcon property value.
-
#category_icon=(value) ⇒ Object
Sets the categoryIcon property value.
-
#category_order ⇒ Object
Gets the categoryOrder property value.
-
#category_order=(value) ⇒ Object
Sets the categoryOrder property value.
-
#content ⇒ Object
Gets the content property value.
-
#content=(value) ⇒ Object
Sets the content property value.
-
#game_id ⇒ Object
Gets the gameId property value.
-
#game_id=(value) ⇒ Object
Sets the gameId property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new UpsertDisplayRuleRequestBody and sets the default values.
-
#is_custom_category ⇒ Object
Gets the isCustomCategory property value.
-
#is_custom_category=(value) ⇒ Object
Sets the isCustomCategory property value.
-
#is_override ⇒ Object
Gets the isOverride property value.
-
#is_override=(value) ⇒ Object
Sets the isOverride property value.
-
#scope ⇒ Object
Gets the scope property value.
-
#scope=(value) ⇒ Object
Sets the scope property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new UpsertDisplayRuleRequestBody and sets the default values.
103 104 105 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 103 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
126 127 128 129 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 126 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return UpsertDisplayRuleRequestBody.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
43 44 45 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 43 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
51 52 53 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 51 def additional_data=(value) @additional_data = value end |
#category ⇒ Object
Gets the category property value. Display rule category.
58 59 60 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 58 def category return @category end |
#category=(value) ⇒ Object
Sets the category property value. Display rule category.
66 67 68 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 66 def category=(value) @category = value end |
#category_icon ⇒ Object
Gets the categoryIcon property value. The categoryIcon property
73 74 75 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 73 def category_icon return @category_icon end |
#category_icon=(value) ⇒ Object
Sets the categoryIcon property value. The categoryIcon property
81 82 83 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 81 def category_icon=(value) @category_icon = value end |
#category_order ⇒ Object
Gets the categoryOrder property value. The categoryOrder property
88 89 90 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 88 def category_order return @category_order end |
#category_order=(value) ⇒ Object
Sets the categoryOrder property value. The categoryOrder property
96 97 98 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 96 def category_order=(value) @category_order = value end |
#content ⇒ Object
Gets the content property value. The content property
110 111 112 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 110 def content return @content end |
#content=(value) ⇒ Object
Sets the content property value. The content property
118 119 120 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 118 def content=(value) @content = value end |
#game_id ⇒ Object
Gets the gameId property value. Game ID whose display rule should change.
134 135 136 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 134 def game_id return @game_id end |
#game_id=(value) ⇒ Object
Sets the gameId property value. Game ID whose display rule should change.
142 143 144 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 142 def game_id=(value) @game_id = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 149 def get_field_deserializers() return { "category" => lambda {|n| @category = n.get_string_value() }, "categoryIcon" => lambda {|n| @category_icon = n.get_string_value() }, "categoryOrder" => lambda {|n| @category_order = n.get_object_value(lambda {|pn| Double.create_from_discriminator_value(pn) }) }, "content" => lambda {|n| @content = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::UpsertDisplayRuleRequestBodyContent.create_from_discriminator_value(pn) }) }, "gameId" => lambda {|n| @game_id = n.get_string_value() }, "isCustomCategory" => lambda {|n| @is_custom_category = n.get_boolean_value() }, "isOverride" => lambda {|n| @is_override = n.get_boolean_value() }, "scope" => lambda {|n| @scope = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::UpsertDisplayRuleRequestBodyScope.create_from_discriminator_value(pn) }) }, } end |
#is_custom_category ⇒ Object
Gets the isCustomCategory property value. The isCustomCategory property
165 166 167 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 165 def is_custom_category return @is_custom_category end |
#is_custom_category=(value) ⇒ Object
Sets the isCustomCategory property value. The isCustomCategory property
173 174 175 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 173 def is_custom_category=(value) @is_custom_category = value end |
#is_override ⇒ Object
Gets the isOverride property value. The isOverride property
180 181 182 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 180 def is_override return @is_override end |
#is_override=(value) ⇒ Object
Sets the isOverride property value. The isOverride property
188 189 190 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 188 def is_override=(value) @is_override = value end |
#scope ⇒ Object
Gets the scope property value. The scope property
195 196 197 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 195 def scope return @scope end |
#scope=(value) ⇒ Object
Sets the scope property value. The scope property
203 204 205 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 203 def scope=(value) @scope = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body.rb', line 211 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("category", @category) writer.write_string_value("categoryIcon", @category_icon) writer.write_object_value("categoryOrder", @category_order) writer.write_object_value("content", @content) writer.write_string_value("gameId", @game_id) writer.write_boolean_value("isCustomCategory", @is_custom_category) writer.write_boolean_value("isOverride", @is_override) writer.write_object_value("scope", @scope) writer.write_additional_data(@additional_data) end |