Class: TeamBattlesSdk::Generated::Models::UpsertDisplayRuleRequestBodyContentSections
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::UpsertDisplayRuleRequestBodyContentSections
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/upsert_display_rule_request_body_content_sections.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#heading ⇒ Object
Gets the heading property value.
-
#heading=(value) ⇒ Object
Sets the heading property value.
-
#initialize ⇒ Object
constructor
Instantiates a new UpsertDisplayRuleRequestBodyContentSections and sets the default values.
-
#items ⇒ Object
Gets the items property value.
-
#items=(value) ⇒ Object
Sets the items property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new UpsertDisplayRuleRequestBodyContentSections and sets the default values.
38 39 40 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body_content_sections.rb', line 38 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
46 47 48 49 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body_content_sections.rb', line 46 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return UpsertDisplayRuleRequestBodyContentSections.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
23 24 25 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body_content_sections.rb', line 23 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
31 32 33 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body_content_sections.rb', line 31 def additional_data=(value) @additional_data = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
54 55 56 57 58 59 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body_content_sections.rb', line 54 def get_field_deserializers() return { "heading" => lambda {|n| @heading = n.get_string_value() }, "items" => lambda {|n| @items = n.get_collection_of_primitive_values(String) }, } end |
#heading ⇒ Object
Gets the heading property value. The heading property
64 65 66 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body_content_sections.rb', line 64 def heading return @heading end |
#heading=(value) ⇒ Object
Sets the heading property value. The heading property
72 73 74 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body_content_sections.rb', line 72 def heading=(value) @heading = value end |
#items ⇒ Object
Gets the items property value. The items property
79 80 81 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body_content_sections.rb', line 79 def items return @items end |
#items=(value) ⇒ Object
Sets the items property value. The items property
87 88 89 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body_content_sections.rb', line 87 def items=(value) @items = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
95 96 97 98 99 100 |
# File 'lib/teambattles_sdk/generated/models/upsert_display_rule_request_body_content_sections.rb', line 95 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("heading", @heading) writer.write_collection_of_primitive_values("items", @items) writer.write_additional_data(@additional_data) end |