Class: TeamBattlesSdk::Generated::Models::UserMatch
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::UserMatch
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/user_match.rb
Overview
Match as returned by the user/team/org match-listing endpoints.
Defined Under Namespace
Classes: UserMatchCompletedAt, UserMatchScheduledAt, UserMatchStartedAt
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#accepted_team ⇒ Object
Gets the acceptedTeam property value.
-
#accepted_team=(value) ⇒ Object
Sets the acceptedTeam property value.
-
#best_of ⇒ Object
Gets the bestOf property value.
-
#best_of=(value) ⇒ Object
Sets the bestOf property value.
-
#completed_at ⇒ Object
Gets the completedAt property value.
-
#completed_at=(value) ⇒ Object
Sets the completedAt property value.
-
#creator_team ⇒ Object
Gets the creatorTeam property value.
-
#creator_team=(value) ⇒ Object
Sets the creatorTeam property value.
-
#game ⇒ Object
Gets the game property value.
-
#game=(value) ⇒ Object
Sets the game property value.
-
#game_mode ⇒ Object
Gets the gameMode property value.
-
#game_mode=(value) ⇒ Object
Sets the gameMode property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#id ⇒ Object
Gets the id property value.
-
#id=(value) ⇒ Object
Sets the id property value.
-
#scheduled_at ⇒ Object
Gets the scheduledAt property value.
-
#scheduled_at=(value) ⇒ Object
Sets the scheduledAt property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#started_at ⇒ Object
Gets the startedAt property value.
-
#started_at=(value) ⇒ Object
Sets the startedAt property value.
-
#status ⇒ Object
Gets the status property value.
-
#status=(value) ⇒ Object
Sets the status property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
92 93 94 95 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 92 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return UserMatch.new end |
Instance Method Details
#accepted_team ⇒ Object
Gets the acceptedTeam property value. The acceptedTeam property
46 47 48 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 46 def accepted_team return @accepted_team end |
#accepted_team=(value) ⇒ Object
Sets the acceptedTeam property value. The acceptedTeam property
54 55 56 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 54 def accepted_team=(value) @accepted_team = value end |
#best_of ⇒ Object
Gets the bestOf property value. Number of maps in the series (1, 3, 5, or 7).
61 62 63 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 61 def best_of return @best_of end |
#best_of=(value) ⇒ Object
Sets the bestOf property value. Number of maps in the series (1, 3, 5, or 7).
69 70 71 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 69 def best_of=(value) @best_of = value end |
#completed_at ⇒ Object
Gets the completedAt property value. Completion time (ISO 8601).
76 77 78 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 76 def completed_at return @completed_at end |
#completed_at=(value) ⇒ Object
Sets the completedAt property value. Completion time (ISO 8601).
84 85 86 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 84 def completed_at=(value) @completed_at = value end |
#creator_team ⇒ Object
Gets the creatorTeam property value. The creatorTeam property
100 101 102 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 100 def creator_team return @creator_team end |
#creator_team=(value) ⇒ Object
Sets the creatorTeam property value. The creatorTeam property
108 109 110 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 108 def creator_team=(value) @creator_team = value end |
#game ⇒ Object
Gets the game property value. Game definition.
115 116 117 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 115 def game return @game end |
#game=(value) ⇒ Object
Sets the game property value. Game definition.
123 124 125 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 123 def game=(value) @game = value end |
#game_mode ⇒ Object
Gets the gameMode property value. Game mode (e.g. HARDPOINT, SEARCH_AND_DESTROY).
130 131 132 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 130 def game_mode return @game_mode end |
#game_mode=(value) ⇒ Object
Sets the gameMode property value. Game mode (e.g. HARDPOINT, SEARCH_AND_DESTROY).
138 139 140 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 138 def game_mode=(value) @game_mode = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 145 def get_field_deserializers() return { "acceptedTeam" => lambda {|n| @accepted_team = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::Team.create_from_discriminator_value(pn) }) }, "bestOf" => lambda {|n| @best_of = n.get_number_value() }, "completedAt" => lambda {|n| @completed_at = n.get_object_value(lambda {|pn| UserMatch::UserMatchCompletedAt.create_from_discriminator_value(pn) }) }, "creatorTeam" => lambda {|n| @creator_team = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::Team.create_from_discriminator_value(pn) }) }, "game" => lambda {|n| @game = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::Game.create_from_discriminator_value(pn) }) }, "gameMode" => lambda {|n| @game_mode = n.get_string_value() }, "id" => lambda {|n| @id = n.get_string_value() }, "scheduledAt" => lambda {|n| @scheduled_at = n.get_object_value(lambda {|pn| UserMatch::UserMatchScheduledAt.create_from_discriminator_value(pn) }) }, "startedAt" => lambda {|n| @started_at = n.get_object_value(lambda {|pn| UserMatch::UserMatchStartedAt.create_from_discriminator_value(pn) }) }, "status" => lambda {|n| @status = n.get_enum_value(TeamBattlesSdk::Generated::Models::MatchStatus) }, } end |
#id ⇒ Object
Gets the id property value. The id property
163 164 165 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 163 def id return @id end |
#id=(value) ⇒ Object
Sets the id property value. The id property
171 172 173 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 171 def id=(value) @id = value end |
#scheduled_at ⇒ Object
Gets the scheduledAt property value. Scheduled start time (ISO 8601).
178 179 180 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 178 def scheduled_at return @scheduled_at end |
#scheduled_at=(value) ⇒ Object
Sets the scheduledAt property value. Scheduled start time (ISO 8601).
186 187 188 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 186 def scheduled_at=(value) @scheduled_at = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 194 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("acceptedTeam", @accepted_team) writer.write_number_value("bestOf", @best_of) writer.write_object_value("completedAt", @completed_at) writer.write_object_value("creatorTeam", @creator_team) writer.write_object_value("game", @game) writer.write_string_value("gameMode", @game_mode) writer.write_string_value("id", @id) writer.write_object_value("scheduledAt", @scheduled_at) writer.write_object_value("startedAt", @started_at) writer.write_enum_value("status", @status) end |
#started_at ⇒ Object
Gets the startedAt property value. Actual start time (ISO 8601).
211 212 213 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 211 def started_at return @started_at end |
#started_at=(value) ⇒ Object
Sets the startedAt property value. Actual start time (ISO 8601).
219 220 221 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 219 def started_at=(value) @started_at = value end |
#status ⇒ Object
Gets the status property value. Lifecycle status of a match.
226 227 228 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 226 def status return @status end |
#status=(value) ⇒ Object
Sets the status property value. Lifecycle status of a match.
234 235 236 |
# File 'lib/teambattles_sdk/generated/models/user_match.rb', line 234 def status=(value) @status = value end |