Class: TeamBattlesSdk::Generated::Models::WebhookListResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::WebhookListResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/webhook_list_response.rb
Overview
List of the caller’s webhook endpoints.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#count ⇒ Object
Gets the count property value.
-
#count=(value) ⇒ Object
Sets the count property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
-
#webhooks ⇒ Object
Gets the webhooks property value.
-
#webhooks=(value) ⇒ Object
Sets the webhooks property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
41 42 43 44 |
# File 'lib/teambattles_sdk/generated/models/webhook_list_response.rb', line 41 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return WebhookListResponse.new end |
Instance Method Details
#count ⇒ Object
Gets the count property value. The count property
25 26 27 |
# File 'lib/teambattles_sdk/generated/models/webhook_list_response.rb', line 25 def count return @count end |
#count=(value) ⇒ Object
Sets the count property value. The count property
33 34 35 |
# File 'lib/teambattles_sdk/generated/models/webhook_list_response.rb', line 33 def count=(value) @count = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
49 50 51 52 53 54 55 |
# File 'lib/teambattles_sdk/generated/models/webhook_list_response.rb', line 49 def get_field_deserializers() return { "count" => lambda {|n| @count = n.get_number_value() }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, "webhooks" => lambda {|n| @webhooks = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::WebhookEndpoint.create_from_discriminator_value(pn) }) }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
61 62 63 64 65 66 |
# File 'lib/teambattles_sdk/generated/models/webhook_list_response.rb', line 61 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("count", @count) writer.write_string_value("timestamp", @timestamp) writer.write_collection_of_object_values("webhooks", @webhooks) end |
#timestamp ⇒ Object
Gets the timestamp property value. The timestamp property
71 72 73 |
# File 'lib/teambattles_sdk/generated/models/webhook_list_response.rb', line 71 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. The timestamp property
79 80 81 |
# File 'lib/teambattles_sdk/generated/models/webhook_list_response.rb', line 79 def (value) @timestamp = value end |
#webhooks ⇒ Object
Gets the webhooks property value. The webhooks property
86 87 88 |
# File 'lib/teambattles_sdk/generated/models/webhook_list_response.rb', line 86 def webhooks return @webhooks end |
#webhooks=(value) ⇒ Object
Sets the webhooks property value. The webhooks property
94 95 96 |
# File 'lib/teambattles_sdk/generated/models/webhook_list_response.rb', line 94 def webhooks=(value) @webhooks = value end |