Class: TeamBattlesSdk::Generated::Orgs::Discover::DiscoverGetResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Orgs::Discover::DiscoverGetResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/orgs/discover/discover_get_response.rb
Overview
Envelope containing organizations, count, and a response timestamp.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#count ⇒ Object
Gets the count property value.
-
#count=(value) ⇒ Object
Sets the count property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#organizations ⇒ Object
Gets the organizations property value.
-
#organizations=(value) ⇒ Object
Sets the organizations property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
44 45 46 47 |
# File 'lib/teambattles_sdk/generated/orgs/discover/discover_get_response.rb', line 44 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return DiscoverGetResponse.new end |
Instance Method Details
#count ⇒ Object
Gets the count property value. The count property
28 29 30 |
# File 'lib/teambattles_sdk/generated/orgs/discover/discover_get_response.rb', line 28 def count return @count end |
#count=(value) ⇒ Object
Sets the count property value. The count property
36 37 38 |
# File 'lib/teambattles_sdk/generated/orgs/discover/discover_get_response.rb', line 36 def count=(value) @count = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
52 53 54 55 56 57 58 |
# File 'lib/teambattles_sdk/generated/orgs/discover/discover_get_response.rb', line 52 def get_field_deserializers() return { "count" => lambda {|n| @count = n.get_number_value() }, "organizations" => lambda {|n| @organizations = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiOrganizationSummary.create_from_discriminator_value(pn) }) }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, } end |
#organizations ⇒ Object
Gets the organizations property value. The organizations property
63 64 65 |
# File 'lib/teambattles_sdk/generated/orgs/discover/discover_get_response.rb', line 63 def organizations return @organizations end |
#organizations=(value) ⇒ Object
Sets the organizations property value. The organizations property
71 72 73 |
# File 'lib/teambattles_sdk/generated/orgs/discover/discover_get_response.rb', line 71 def organizations=(value) @organizations = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
79 80 81 82 83 84 |
# File 'lib/teambattles_sdk/generated/orgs/discover/discover_get_response.rb', line 79 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("count", @count) writer.write_collection_of_object_values("organizations", @organizations) writer.write_string_value("timestamp", @timestamp) end |
#timestamp ⇒ Object
Gets the timestamp property value. ISO 8601 timestamp.
89 90 91 |
# File 'lib/teambattles_sdk/generated/orgs/discover/discover_get_response.rb', line 89 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. ISO 8601 timestamp.
97 98 99 |
# File 'lib/teambattles_sdk/generated/orgs/discover/discover_get_response.rb', line 97 def (value) @timestamp = value end |