Class: TeamBattlesSdk::Generated::Orgs::Discover::DiscoverRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- TeamBattlesSdk::Generated::Orgs::Discover::DiscoverRequestBuilder
- Defined in:
- lib/teambattles_sdk/generated/orgs/discover/discover_request_builder.rb
Overview
Builds and executes requests for operations under #orgs#discover
Defined Under Namespace
Classes: DiscoverRequestBuilderGetQueryParameters
Instance Method Summary collapse
-
#get(request_configuration = nil) ⇒ Object
Returns a neutral, ranked discovery list of active, public, non-disabled organizations.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new DiscoverRequestBuilder and sets the default values.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Returns a neutral, ranked discovery list of active, public, non-disabled organizations.
-
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new DiscoverRequestBuilder and sets the default values.
21 22 23 |
# File 'lib/teambattles_sdk/generated/orgs/discover/discover_request_builder.rb', line 21 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/orgs/discover{?limit*,search*}") end |
Instance Method Details
#get(request_configuration = nil) ⇒ Object
Returns a neutral, ranked discovery list of active, public, non-disabled organizations. Each result is a small summary (id, slug, name, tag, avatarUrl, visibility); ‘count` is the size of the returned page, not a total. Results are sorted featured organizations first, then by most wins, then newest. `limit` is 1-100 (default 50); ranking is computed over at most the first 1000 candidate organizations and there is no cursor pagination, so the response is a single ranked page. `search` filters by case-insensitive name substring and is only applied when it is at least 2 characters (shorter values are ignored). Unlike an in-app feed, results do not exclude organizations the API key owner belongs to and do not include membership or join-request flags. Requires orgs.profile:read.
29 30 31 32 33 34 35 36 37 38 39 40 |
# File 'lib/teambattles_sdk/generated/orgs/discover/discover_request_builder.rb', line 29 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["400"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["401"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["403"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["429"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["500"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| TeamBattlesSdk::Generated::Orgs::Discover::DiscoverGetResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Returns a neutral, ranked discovery list of active, public, non-disabled organizations. Each result is a small summary (id, slug, name, tag, avatarUrl, visibility); ‘count` is the size of the returned page, not a total. Results are sorted featured organizations first, then by most wins, then newest. `limit` is 1-100 (default 50); ranking is computed over at most the first 1000 candidate organizations and there is no cursor pagination, so the response is a single ranked page. `search` filters by case-insensitive name substring and is only applied when it is at least 2 characters (shorter values are ignored). Unlike an in-app feed, results do not exclude organizations the API key owner belongs to and do not include membership or join-request flags. Requires orgs.profile:read.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/teambattles_sdk/generated/orgs/discover/discover_request_builder.rb', line 46 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.set_query_string_parameters_from_raw_object(request_configuration.query_parameters) request_info.(request_configuration.) end request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.try_add('Accept', 'application/json') return request_info end |
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
64 65 66 67 |
# File 'lib/teambattles_sdk/generated/orgs/discover/discover_request_builder.rb', line 64 def with_url(raw_url) raise StandardError, 'raw_url cannot be null' if raw_url.nil? return DiscoverRequestBuilder.new(raw_url, @request_adapter) end |