Class: TeamBattlesSdk::Generated::Orgs::Item::WithIdentifierGetResponse

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/teambattles_sdk/generated/orgs/item/with_identifier_get_response.rb

Overview

Envelope containing organization plus a response timestamp.

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a with_identifier_get_response

Raises:

  • (StandardError)


26
27
28
29
# File 'lib/teambattles_sdk/generated/orgs/item/with_identifier_get_response.rb', line 26

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return WithIdentifierGetResponse.new
end

Instance Method Details

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



34
35
36
37
38
39
# File 'lib/teambattles_sdk/generated/orgs/item/with_identifier_get_response.rb', line 34

def get_field_deserializers()
    return {
        "organization" => lambda {|n| @organization = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiOrganizationProfile.create_from_discriminator_value(pn) }) },
        "timestamp" => lambda {|n| @timestamp = n.get_string_value() },
    }
end

#organizationObject

Gets the organization property value. API-safe organization profile.

Returns:

  • a api_organization_profile



44
45
46
# File 'lib/teambattles_sdk/generated/orgs/item/with_identifier_get_response.rb', line 44

def organization
    return @organization
end

#organization=(value) ⇒ Object

Sets the organization property value. API-safe organization profile.

Parameters:

  • value

    Value to set for the organization property.

Returns:

  • a void



52
53
54
# File 'lib/teambattles_sdk/generated/orgs/item/with_identifier_get_response.rb', line 52

def organization=(value)
    @organization = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


60
61
62
63
64
# File 'lib/teambattles_sdk/generated/orgs/item/with_identifier_get_response.rb', line 60

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_object_value("organization", @organization)
    writer.write_string_value("timestamp", @timestamp)
end

#timestampObject

Gets the timestamp property value. ISO 8601 timestamp.

Returns:

  • a string



69
70
71
# File 'lib/teambattles_sdk/generated/orgs/item/with_identifier_get_response.rb', line 69

def timestamp
    return @timestamp
end

#timestamp=(value) ⇒ Object

Sets the timestamp property value. ISO 8601 timestamp.

Parameters:

  • value

    Value to set for the timestamp property.

Returns:

  • a void



77
78
79
# File 'lib/teambattles_sdk/generated/orgs/item/with_identifier_get_response.rb', line 77

def timestamp=(value)
    @timestamp = value
end