Class: TeamBattlesSdk::Generated::Teams::Item::Matches::MatchesPostResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Teams::Item::Matches::MatchesPostResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/teams/item/matches/matches_post_response.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#continue_cursor ⇒ Object
Gets the continueCursor property value.
-
#continue_cursor=(value) ⇒ Object
Sets the continueCursor property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#is_done ⇒ Object
Gets the isDone property value.
-
#is_done=(value) ⇒ Object
Sets the isDone property value.
-
#page ⇒ Object
Gets the page property value.
-
#page=(value) ⇒ Object
Sets the page property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
44 45 46 47 |
# File 'lib/teambattles_sdk/generated/teams/item/matches/matches_post_response.rb', line 44 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return MatchesPostResponse.new end |
Instance Method Details
#continue_cursor ⇒ Object
Gets the continueCursor property value. The continueCursor property
28 29 30 |
# File 'lib/teambattles_sdk/generated/teams/item/matches/matches_post_response.rb', line 28 def continue_cursor return @continue_cursor end |
#continue_cursor=(value) ⇒ Object
Sets the continueCursor property value. The continueCursor property
36 37 38 |
# File 'lib/teambattles_sdk/generated/teams/item/matches/matches_post_response.rb', line 36 def continue_cursor=(value) @continue_cursor = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
52 53 54 55 56 57 58 |
# File 'lib/teambattles_sdk/generated/teams/item/matches/matches_post_response.rb', line 52 def get_field_deserializers() return { "continueCursor" => lambda {|n| @continue_cursor = n.get_string_value() }, "isDone" => lambda {|n| @is_done = n.get_boolean_value() }, "page" => lambda {|n| @page = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::UserMatch.create_from_discriminator_value(pn) }) }, } end |
#is_done ⇒ Object
Gets the isDone property value. The isDone property
63 64 65 |
# File 'lib/teambattles_sdk/generated/teams/item/matches/matches_post_response.rb', line 63 def is_done return @is_done end |
#is_done=(value) ⇒ Object
Sets the isDone property value. The isDone property
71 72 73 |
# File 'lib/teambattles_sdk/generated/teams/item/matches/matches_post_response.rb', line 71 def is_done=(value) @is_done = value end |
#page ⇒ Object
Gets the page property value. The page property
78 79 80 |
# File 'lib/teambattles_sdk/generated/teams/item/matches/matches_post_response.rb', line 78 def page return @page end |
#page=(value) ⇒ Object
Sets the page property value. The page property
86 87 88 |
# File 'lib/teambattles_sdk/generated/teams/item/matches/matches_post_response.rb', line 86 def page=(value) @page = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
94 95 96 97 98 99 |
# File 'lib/teambattles_sdk/generated/teams/item/matches/matches_post_response.rb', line 94 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("continueCursor", @continue_cursor) writer.write_boolean_value("isDone", @is_done) writer.write_collection_of_object_values("page", @page) end |