Class: TeamBattlesSdk::Generated::Twitch::Badges::Channel::ChannelRequestBuilder::ChannelRequestBuilderGetQueryParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/teambattles_sdk/generated/twitch/badges/channel/channel_request_builder.rb

Overview

Returns a Twitch channel’s chat badge sets. Provide exactly one of the username or id query parameters. The API key owner must have a linked Twitch connection. Requires the connections.twitch permission.

Instance Attribute Summary collapse

Instance Attribute Details

#idObject

Broadcaster id (e.g. 123456789). Provide exactly one of username or id.



77
78
79
# File 'lib/teambattles_sdk/generated/twitch/badges/channel/channel_request_builder.rb', line 77

def id
  @id
end

#usernameObject

Channel login name (e.g. ninja). Provide exactly one of username or id.



80
81
82
# File 'lib/teambattles_sdk/generated/twitch/badges/channel/channel_request_builder.rb', line 80

def username
  @username
end