Class: TeamBattlesSdk::Generated::User::Connections::ConnectionsGetResponse

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/teambattles_sdk/generated/user/connections/connections_get_response.rb

Overview

Envelope containing connections, count, and a response timestamp.

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a connections_get_response

Raises:

  • (StandardError)


59
60
61
62
# File 'lib/teambattles_sdk/generated/user/connections/connections_get_response.rb', line 59

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return ConnectionsGetResponse.new
end

Instance Method Details

#connectionsObject

Gets the connections property value. The connections property

Returns:

  • a api_own_connection



28
29
30
# File 'lib/teambattles_sdk/generated/user/connections/connections_get_response.rb', line 28

def connections
    return @connections
end

#connections=(value) ⇒ Object

Sets the connections property value. The connections property

Parameters:

  • value

    Value to set for the connections property.

Returns:

  • a void



36
37
38
# File 'lib/teambattles_sdk/generated/user/connections/connections_get_response.rb', line 36

def connections=(value)
    @connections = value
end

#countObject

Gets the count property value. The count property

Returns:

  • a integer



43
44
45
# File 'lib/teambattles_sdk/generated/user/connections/connections_get_response.rb', line 43

def count
    return @count
end

#count=(value) ⇒ Object

Sets the count property value. The count property

Parameters:

  • value

    Value to set for the count property.

Returns:

  • a void



51
52
53
# File 'lib/teambattles_sdk/generated/user/connections/connections_get_response.rb', line 51

def count=(value)
    @count = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



67
68
69
70
71
72
73
# File 'lib/teambattles_sdk/generated/user/connections/connections_get_response.rb', line 67

def get_field_deserializers()
    return {
        "connections" => lambda {|n| @connections = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiOwnConnection.create_from_discriminator_value(pn) }) },
        "count" => lambda {|n| @count = n.get_number_value() },
        "timestamp" => lambda {|n| @timestamp = n.get_string_value() },
    }
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


79
80
81
82
83
84
# File 'lib/teambattles_sdk/generated/user/connections/connections_get_response.rb', line 79

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_collection_of_object_values("connections", @connections)
    writer.write_number_value("count", @count)
    writer.write_string_value("timestamp", @timestamp)
end

#timestampObject

Gets the timestamp property value. ISO 8601 timestamp.

Returns:

  • a string



89
90
91
# File 'lib/teambattles_sdk/generated/user/connections/connections_get_response.rb', line 89

def timestamp
    return @timestamp
end

#timestamp=(value) ⇒ Object

Sets the timestamp property value. ISO 8601 timestamp.

Parameters:

  • value

    Value to set for the timestamp property.

Returns:

  • a void



97
98
99
# File 'lib/teambattles_sdk/generated/user/connections/connections_get_response.rb', line 97

def timestamp=(value)
    @timestamp = value
end