Class: TeamBattlesSdk::Generated::User::Matches::MatchesPostResponse

Inherits:
Object
  • Object
show all
Includes:
MicrosoftKiotaAbstractions::Parsable
Defined in:
lib/teambattles_sdk/generated/user/matches/matches_post_response.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create_from_discriminator_value(parse_node) ⇒ Object

Creates a new instance of the appropriate class based on discriminator value

Parameters:

  • parse_node

    The parse node to use to read the discriminator value and create the object

Returns:

  • a matches_post_response

Raises:

  • (StandardError)


42
43
44
45
# File 'lib/teambattles_sdk/generated/user/matches/matches_post_response.rb', line 42

def self.create_from_discriminator_value(parse_node)
    raise StandardError, 'parse_node cannot be null' if parse_node.nil?
    return MatchesPostResponse.new
end

Instance Method Details

#continue_cursorObject

Gets the continueCursor property value. The continueCursor property

Returns:

  • a string



26
27
28
# File 'lib/teambattles_sdk/generated/user/matches/matches_post_response.rb', line 26

def continue_cursor
    return @continue_cursor
end

#continue_cursor=(value) ⇒ Object

Sets the continueCursor property value. The continueCursor property

Parameters:

  • value

    Value to set for the continueCursor property.

Returns:

  • a void



34
35
36
# File 'lib/teambattles_sdk/generated/user/matches/matches_post_response.rb', line 34

def continue_cursor=(value)
    @continue_cursor = value
end

#get_field_deserializersObject

The deserialization information for the current model

Returns:

  • a i_dictionary



50
51
52
53
54
55
56
# File 'lib/teambattles_sdk/generated/user/matches/matches_post_response.rb', line 50

def get_field_deserializers()
    return {
        "continueCursor" => lambda {|n| @continue_cursor = n.get_string_value() },
        "isDone" => lambda {|n| @is_done = n.get_boolean_value() },
        "page" => lambda {|n| @page = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::UserMatch.create_from_discriminator_value(pn) }) },
    }
end

#is_doneObject

Gets the isDone property value. The isDone property

Returns:

  • a boolean



61
62
63
# File 'lib/teambattles_sdk/generated/user/matches/matches_post_response.rb', line 61

def is_done
    return @is_done
end

#is_done=(value) ⇒ Object

Sets the isDone property value. The isDone property

Parameters:

  • value

    Value to set for the isDone property.

Returns:

  • a void



69
70
71
# File 'lib/teambattles_sdk/generated/user/matches/matches_post_response.rb', line 69

def is_done=(value)
    @is_done = value
end

#pageObject

Gets the page property value. The page property

Returns:

  • a user_match



76
77
78
# File 'lib/teambattles_sdk/generated/user/matches/matches_post_response.rb', line 76

def page
    return @page
end

#page=(value) ⇒ Object

Sets the page property value. The page property

Parameters:

  • value

    Value to set for the page property.

Returns:

  • a void



84
85
86
# File 'lib/teambattles_sdk/generated/user/matches/matches_post_response.rb', line 84

def page=(value)
    @page = value
end

#serialize(writer) ⇒ Object

Serializes information the current object

Parameters:

  • writer

    Serialization writer to use to serialize this model

Returns:

  • a void

Raises:

  • (StandardError)


92
93
94
95
96
97
# File 'lib/teambattles_sdk/generated/user/matches/matches_post_response.rb', line 92

def serialize(writer)
    raise StandardError, 'writer cannot be null' if writer.nil?
    writer.write_string_value("continueCursor", @continue_cursor)
    writer.write_boolean_value("isDone", @is_done)
    writer.write_collection_of_object_values("page", @page)
end