Class: TeamBattlesSdk::Generated::User::Matches::MatchesRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- TeamBattlesSdk::Generated::User::Matches::MatchesRequestBuilder
- Defined in:
- lib/teambattles_sdk/generated/user/matches/matches_request_builder.rb
Overview
Builds and executes requests for operations under #user#matches
Instance Method Summary collapse
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new MatchesRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Returns matches the API key owner participates in, newest first, with cursor pagination.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Returns matches the API key owner participates in, newest first, with cursor pagination.
-
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new MatchesRequestBuilder and sets the default values.
22 23 24 |
# File 'lib/teambattles_sdk/generated/user/matches/matches_request_builder.rb', line 22 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/user/matches") end |
Instance Method Details
#post(body, request_configuration = nil) ⇒ Object
Returns matches the API key owner participates in, newest first, with cursor pagination. Requires the matches.user_matches:read permission.
31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/teambattles_sdk/generated/user/matches/matches_request_builder.rb', line 31 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["400"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["401"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["403"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| TeamBattlesSdk::Generated::User::Matches::MatchesPostResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Returns matches the API key owner participates in, newest first, with cursor pagination. Requires the matches.user_matches:read permission.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/teambattles_sdk/generated/user/matches/matches_request_builder.rb', line 48 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, 'application/json', body) request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.try_add('Accept', 'application/json') return request_info end |
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
67 68 69 70 |
# File 'lib/teambattles_sdk/generated/user/matches/matches_request_builder.rb', line 67 def with_url(raw_url) raise StandardError, 'raw_url cannot be null' if raw_url.nil? return MatchesRequestBuilder.new(raw_url, @request_adapter) end |