Class: TeamBattlesSdk::Generated::User::OngoingMatches::OngoingMatchesRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- TeamBattlesSdk::Generated::User::OngoingMatches::OngoingMatchesRequestBuilder
- Defined in:
- lib/teambattles_sdk/generated/user/ongoing_matches/ongoing_matches_request_builder.rb
Overview
Builds and executes requests for operations under #user#ongoing-matches
Instance Method Summary collapse
-
#get(request_configuration = nil) ⇒ Object
Returns published ACCEPTED, READY, and IN_PROGRESS matches for active teams the API key owner belongs to.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new OngoingMatchesRequestBuilder and sets the default values.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Returns published ACCEPTED, READY, and IN_PROGRESS matches for active teams the API key owner belongs to.
-
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new OngoingMatchesRequestBuilder and sets the default values.
22 23 24 |
# File 'lib/teambattles_sdk/generated/user/ongoing_matches/ongoing_matches_request_builder.rb', line 22 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/user/ongoing-matches") end |
Instance Method Details
#get(request_configuration = nil) ⇒ Object
Returns published ACCEPTED, READY, and IN_PROGRESS matches for active teams the API key owner belongs to. The user is always derived from the API key. Requires matches.user_matches:read.
30 31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/teambattles_sdk/generated/user/ongoing_matches/ongoing_matches_request_builder.rb', line 30 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["401"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["403"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["404"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["429"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["500"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| TeamBattlesSdk::Generated::Models::OngoingMatchesResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Returns published ACCEPTED, READY, and IN_PROGRESS matches for active teams the API key owner belongs to. The user is always derived from the API key. Requires matches.user_matches:read.
47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/teambattles_sdk/generated/user/ongoing_matches/ongoing_matches_request_builder.rb', line 47 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.try_add('Accept', 'application/json') return request_info end |
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
64 65 66 67 |
# File 'lib/teambattles_sdk/generated/user/ongoing_matches/ongoing_matches_request_builder.rb', line 64 def with_url(raw_url) raise StandardError, 'raw_url cannot be null' if raw_url.nil? return OngoingMatchesRequestBuilder.new(raw_url, @request_adapter) end |