Class: TeamBattlesSdk::Generated::Users::Item::Organizations::OrganizationsGetResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Users::Item::Organizations::OrganizationsGetResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/users/item/organizations/organizations_get_response.rb
Overview
Envelope containing organizations, count, and a response timestamp.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#count ⇒ Object
Gets the count property value.
-
#count=(value) ⇒ Object
Sets the count property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#organizations ⇒ Object
Gets the organizations property value.
-
#organizations=(value) ⇒ Object
Sets the organizations property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
46 47 48 49 |
# File 'lib/teambattles_sdk/generated/users/item/organizations/organizations_get_response.rb', line 46 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return OrganizationsGetResponse.new end |
Instance Method Details
#count ⇒ Object
Gets the count property value. The count property
30 31 32 |
# File 'lib/teambattles_sdk/generated/users/item/organizations/organizations_get_response.rb', line 30 def count return @count end |
#count=(value) ⇒ Object
Sets the count property value. The count property
38 39 40 |
# File 'lib/teambattles_sdk/generated/users/item/organizations/organizations_get_response.rb', line 38 def count=(value) @count = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
54 55 56 57 58 59 60 |
# File 'lib/teambattles_sdk/generated/users/item/organizations/organizations_get_response.rb', line 54 def get_field_deserializers() return { "count" => lambda {|n| @count = n.get_number_value() }, "organizations" => lambda {|n| @organizations = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiUserOrganizationMembership.create_from_discriminator_value(pn) }) }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, } end |
#organizations ⇒ Object
Gets the organizations property value. The organizations property
65 66 67 |
# File 'lib/teambattles_sdk/generated/users/item/organizations/organizations_get_response.rb', line 65 def organizations return @organizations end |
#organizations=(value) ⇒ Object
Sets the organizations property value. The organizations property
73 74 75 |
# File 'lib/teambattles_sdk/generated/users/item/organizations/organizations_get_response.rb', line 73 def organizations=(value) @organizations = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
81 82 83 84 85 86 |
# File 'lib/teambattles_sdk/generated/users/item/organizations/organizations_get_response.rb', line 81 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("count", @count) writer.write_collection_of_object_values("organizations", @organizations) writer.write_string_value("timestamp", @timestamp) end |
#timestamp ⇒ Object
Gets the timestamp property value. ISO 8601 timestamp.
91 92 93 |
# File 'lib/teambattles_sdk/generated/users/item/organizations/organizations_get_response.rb', line 91 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. ISO 8601 timestamp.
99 100 101 |
# File 'lib/teambattles_sdk/generated/users/item/organizations/organizations_get_response.rb', line 99 def (value) @timestamp = value end |