Class: TeamBattlesSdk::Generated::Users::Item::Trophies::TrophiesGetResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Users::Item::Trophies::TrophiesGetResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/users/item/trophies/trophies_get_response.rb
Overview
Envelope containing trophies, count, and a response timestamp.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#count ⇒ Object
Gets the count property value.
-
#count=(value) ⇒ Object
Sets the count property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
-
#trophies ⇒ Object
Gets the trophies property value.
-
#trophies=(value) ⇒ Object
Sets the trophies property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
46 47 48 49 |
# File 'lib/teambattles_sdk/generated/users/item/trophies/trophies_get_response.rb', line 46 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return TrophiesGetResponse.new end |
Instance Method Details
#count ⇒ Object
Gets the count property value. The count property
30 31 32 |
# File 'lib/teambattles_sdk/generated/users/item/trophies/trophies_get_response.rb', line 30 def count return @count end |
#count=(value) ⇒ Object
Sets the count property value. The count property
38 39 40 |
# File 'lib/teambattles_sdk/generated/users/item/trophies/trophies_get_response.rb', line 38 def count=(value) @count = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
54 55 56 57 58 59 60 |
# File 'lib/teambattles_sdk/generated/users/item/trophies/trophies_get_response.rb', line 54 def get_field_deserializers() return { "count" => lambda {|n| @count = n.get_number_value() }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, "trophies" => lambda {|n| @trophies = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiUserTrophy.create_from_discriminator_value(pn) }) }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
66 67 68 69 70 71 |
# File 'lib/teambattles_sdk/generated/users/item/trophies/trophies_get_response.rb', line 66 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("count", @count) writer.write_string_value("timestamp", @timestamp) writer.write_collection_of_object_values("trophies", @trophies) end |
#timestamp ⇒ Object
Gets the timestamp property value. ISO 8601 timestamp.
76 77 78 |
# File 'lib/teambattles_sdk/generated/users/item/trophies/trophies_get_response.rb', line 76 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. ISO 8601 timestamp.
84 85 86 |
# File 'lib/teambattles_sdk/generated/users/item/trophies/trophies_get_response.rb', line 84 def (value) @timestamp = value end |
#trophies ⇒ Object
Gets the trophies property value. The trophies property
91 92 93 |
# File 'lib/teambattles_sdk/generated/users/item/trophies/trophies_get_response.rb', line 91 def trophies return @trophies end |
#trophies=(value) ⇒ Object
Sets the trophies property value. The trophies property
99 100 101 |
# File 'lib/teambattles_sdk/generated/users/item/trophies/trophies_get_response.rb', line 99 def trophies=(value) @trophies = value end |