Class: TeamBattlesSdk::Generated::Webhooks::Item::RotateSecret::RotateSecretRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- TeamBattlesSdk::Generated::Webhooks::Item::RotateSecret::RotateSecretRequestBuilder
- Defined in:
- lib/teambattles_sdk/generated/webhooks/item/rotate_secret/rotate_secret_request_builder.rb
Overview
Builds and executes requests for operations under #webhooks#id#rotate-secret
Instance Method Summary collapse
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new RotateSecretRequestBuilder and sets the default values.
-
#post(request_configuration = nil) ⇒ Object
Rotates the endpoint’s signing secret.
-
#to_post_request_information(request_configuration = nil) ⇒ Object
Rotates the endpoint’s signing secret.
-
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new RotateSecretRequestBuilder and sets the default values.
24 25 26 |
# File 'lib/teambattles_sdk/generated/webhooks/item/rotate_secret/rotate_secret_request_builder.rb', line 24 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/webhooks/{id}/rotate-secret") end |
Instance Method Details
#post(request_configuration = nil) ⇒ Object
Rotates the endpoint’s signing secret. The previous secret keeps signing for a 24h grace window so consumers can update without missing deliveries. Returns the new secret ONCE. Requires the webhooks.manage permission and the webhooks feature.
32 33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/teambattles_sdk/generated/webhooks/item/rotate_secret/rotate_secret_request_builder.rb', line 32 def post(request_configuration=nil) request_info = self.to_post_request_information( request_configuration ) error_mapping = Hash.new error_mapping["400"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["401"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["403"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["404"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["429"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| TeamBattlesSdk::Generated::Models::WebhookSecret.create_from_discriminator_value(pn) }, error_mapping) end |
#to_post_request_information(request_configuration = nil) ⇒ Object
Rotates the endpoint’s signing secret. The previous secret keeps signing for a 24h grace window so consumers can update without missing deliveries. Returns the new secret ONCE. Requires the webhooks.manage permission and the webhooks feature.
49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/teambattles_sdk/generated/webhooks/item/rotate_secret/rotate_secret_request_builder.rb', line 49 def to_post_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.try_add('Accept', 'application/json') return request_info end |
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
66 67 68 69 |
# File 'lib/teambattles_sdk/generated/webhooks/item/rotate_secret/rotate_secret_request_builder.rb', line 66 def with_url(raw_url) raise StandardError, 'raw_url cannot be null' if raw_url.nil? return RotateSecretRequestBuilder.new(raw_url, @request_adapter) end |