Class: TeamBattlesSdk::Generated::Webhooks::WebhooksRequestBuilder

Inherits:
MicrosoftKiotaAbstractions::BaseRequestBuilder
  • Object
show all
Defined in:
lib/teambattles_sdk/generated/webhooks/webhooks_request_builder.rb

Overview

Builds and executes requests for operations under #webhooks

Instance Method Summary collapse

Constructor Details

#initialize(path_parameters, request_adapter) ⇒ Object

Instantiates a new WebhooksRequestBuilder and sets the default values.

Parameters:

  • path_parameters

    Path parameters for the request

  • request_adapter

    The request adapter to use to execute the requests.



34
35
36
# File 'lib/teambattles_sdk/generated/webhooks/webhooks_request_builder.rb', line 34

def initialize(path_parameters, request_adapter)
    super(path_parameters, request_adapter, "{+baseurl}/webhooks")
end

Instance Method Details

#by_id(id) ⇒ Object

Gets an item from the TeamBattlesSdk::Generated.webhooks.item collection

Parameters:

  • id

    Webhook endpoint id.

Returns:

  • a webhooks_item_request_builder

Raises:

  • (StandardError)


22
23
24
25
26
27
# File 'lib/teambattles_sdk/generated/webhooks/webhooks_request_builder.rb', line 22

def by_id(id)
    raise StandardError, 'id cannot be null' if id.nil?
    url_tpl_params = @path_parameters.clone
    url_tpl_params["id"] = id
    return TeamBattlesSdk::Generated::Webhooks::Item::WebhooksItemRequestBuilder.new(url_tpl_params, @request_adapter)
end

#get(request_configuration = nil) ⇒ Object

Lists the API key’s webhook endpoints within its derived scope. Secret material is never returned. Requires the webhooks.manage permission and the webhooks feature.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of webhook_list_response



42
43
44
45
46
47
48
49
50
51
52
# File 'lib/teambattles_sdk/generated/webhooks/webhooks_request_builder.rb', line 42

def get(request_configuration=nil)
    request_info = self.to_get_request_information(
        request_configuration
    )
    error_mapping = Hash.new
    error_mapping["400"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) }
    error_mapping["401"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) }
    error_mapping["403"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) }
    error_mapping["429"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| TeamBattlesSdk::Generated::Models::WebhookListResponse.create_from_discriminator_value(pn) }, error_mapping)
end

#post(body, request_configuration = nil) ⇒ Object

Creates a webhook endpoint in the API key’s derived scope (personal -> user, developer-app -> game, league-operator -> league). Returns the signing secret ONCE. Requires the webhooks.manage permission and the webhooks feature.

Parameters:

  • body

    Create a webhook endpoint in the caller’s scope.

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a Fiber of webhook_secret

Raises:

  • (StandardError)


59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/teambattles_sdk/generated/webhooks/webhooks_request_builder.rb', line 59

def post(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = self.to_post_request_information(
        body, request_configuration
    )
    error_mapping = Hash.new
    error_mapping["400"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) }
    error_mapping["401"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) }
    error_mapping["403"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) }
    error_mapping["409"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) }
    error_mapping["429"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) }
    return @request_adapter.send_async(request_info, lambda {|pn| TeamBattlesSdk::Generated::Models::WebhookSecret.create_from_discriminator_value(pn) }, error_mapping)
end

#to_get_request_information(request_configuration = nil) ⇒ Object

Lists the API key’s webhook endpoints within its derived scope. Secret material is never returned. Requires the webhooks.manage permission and the webhooks feature.

Parameters:

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information



77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/teambattles_sdk/generated/webhooks/webhooks_request_builder.rb', line 77

def to_get_request_information(request_configuration=nil)
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :GET
    request_info.headers.try_add('Accept', 'application/json')
    return request_info
end

#to_post_request_information(body, request_configuration = nil) ⇒ Object

Creates a webhook endpoint in the API key’s derived scope (personal -> user, developer-app -> game, league-operator -> league). Returns the signing secret ONCE. Requires the webhooks.manage permission and the webhooks feature.

Parameters:

  • body

    Create a webhook endpoint in the caller’s scope.

  • request_configuration (defaults to: nil)

    Configuration for the request such as headers, query parameters, and middleware options.

Returns:

  • a request_information

Raises:

  • (StandardError)


95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/teambattles_sdk/generated/webhooks/webhooks_request_builder.rb', line 95

def to_post_request_information(body, request_configuration=nil)
    raise StandardError, 'body cannot be null' if body.nil?
    request_info = MicrosoftKiotaAbstractions::RequestInformation.new()
    unless request_configuration.nil?
        request_info.add_headers_from_raw_object(request_configuration.headers)
        request_info.add_request_options(request_configuration.options)
    end
    request_info.set_content_from_parsable(@request_adapter, 'application/json', body)
    request_info.url_template = @url_template
    request_info.path_parameters = @path_parameters
    request_info.http_method = :POST
    request_info.headers.try_add('Accept', 'application/json')
    return request_info
end

#with_url(raw_url) ⇒ Object

Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.

Parameters:

  • raw_url

    The raw URL to use for the request builder.

Returns:

  • a webhooks_request_builder

Raises:

  • (StandardError)


114
115
116
117
# File 'lib/teambattles_sdk/generated/webhooks/webhooks_request_builder.rb', line 114

def with_url(raw_url)
    raise StandardError, 'raw_url cannot be null' if raw_url.nil?
    return WebhooksRequestBuilder.new(raw_url, @request_adapter)
end