Class: TeamBattlesSdk::Generated::Game::Matches::MatchesPostResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Game::Matches::MatchesPostResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/game/matches/matches_post_response.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#count ⇒ Object
Gets the count property value.
-
#count=(value) ⇒ Object
Sets the count property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#matches ⇒ Object
Gets the matches property value.
-
#matches=(value) ⇒ Object
Sets the matches property value.
-
#pagination ⇒ Object
Gets the pagination property value.
-
#pagination=(value) ⇒ Object
Sets the pagination property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
45 46 47 48 |
# File 'lib/teambattles_sdk/generated/game/matches/matches_post_response.rb', line 45 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return MatchesPostResponse.new end |
Instance Method Details
#count ⇒ Object
Gets the count property value. The count property
29 30 31 |
# File 'lib/teambattles_sdk/generated/game/matches/matches_post_response.rb', line 29 def count return @count end |
#count=(value) ⇒ Object
Sets the count property value. The count property
37 38 39 |
# File 'lib/teambattles_sdk/generated/game/matches/matches_post_response.rb', line 37 def count=(value) @count = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
53 54 55 56 57 58 59 60 |
# File 'lib/teambattles_sdk/generated/game/matches/matches_post_response.rb', line 53 def get_field_deserializers() return { "count" => lambda {|n| @count = n.get_number_value() }, "matches" => lambda {|n| @matches = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::GameMatch.create_from_discriminator_value(pn) }) }, "pagination" => lambda {|n| @pagination = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Game::Matches::MatchesPostResponsePagination.create_from_discriminator_value(pn) }) }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, } end |
#matches ⇒ Object
Gets the matches property value. The matches property
65 66 67 |
# File 'lib/teambattles_sdk/generated/game/matches/matches_post_response.rb', line 65 def matches return @matches end |
#matches=(value) ⇒ Object
Sets the matches property value. The matches property
73 74 75 |
# File 'lib/teambattles_sdk/generated/game/matches/matches_post_response.rb', line 73 def matches=(value) @matches = value end |
#pagination ⇒ Object
Gets the pagination property value. The pagination property
80 81 82 |
# File 'lib/teambattles_sdk/generated/game/matches/matches_post_response.rb', line 80 def pagination return @pagination end |
#pagination=(value) ⇒ Object
Sets the pagination property value. The pagination property
88 89 90 |
# File 'lib/teambattles_sdk/generated/game/matches/matches_post_response.rb', line 88 def pagination=(value) @pagination = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
96 97 98 99 100 101 102 |
# File 'lib/teambattles_sdk/generated/game/matches/matches_post_response.rb', line 96 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("count", @count) writer.write_collection_of_object_values("matches", @matches) writer.write_object_value("pagination", @pagination) writer.write_string_value("timestamp", @timestamp) end |
#timestamp ⇒ Object
Gets the timestamp property value. The timestamp property
107 108 109 |
# File 'lib/teambattles_sdk/generated/game/matches/matches_post_response.rb', line 107 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. The timestamp property
115 116 117 |
# File 'lib/teambattles_sdk/generated/game/matches/matches_post_response.rb', line 115 def (value) @timestamp = value end |