Class: TeamBattlesSdk::Generated::Matches::Item::Chat::ChatGetResponse::ChatGetResponseNextCursor
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Matches::Item::Chat::ChatGetResponse::ChatGetResponseNextCursor
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/matches/item/chat/chat_get_response.rb
Overview
Composed type wrapper for classes ChatGetResponseNextCursorMember1, string
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#chat_get_response_next_cursor_member1 ⇒ Object
Gets the chatGetResponse_nextCursorMember1 property value.
-
#chat_get_response_next_cursor_member1=(value) ⇒ Object
Sets the chatGetResponse_nextCursorMember1 property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#string ⇒ Object
Gets the string property value.
-
#string=(value) ⇒ Object
Sets the string property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
151 152 153 154 |
# File 'lib/teambattles_sdk/generated/matches/item/chat/chat_get_response.rb', line 151 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ChatGetResponseNextCursor.new end |
Instance Method Details
#chat_get_response_next_cursor_member1 ⇒ Object
Gets the chatGetResponse_nextCursorMember1 property value. Composed type representation for type ChatGetResponseNextCursorMember1
135 136 137 |
# File 'lib/teambattles_sdk/generated/matches/item/chat/chat_get_response.rb', line 135 def chat_get_response_next_cursor_member1 return @chat_get_response_next_cursor_member1 end |
#chat_get_response_next_cursor_member1=(value) ⇒ Object
Sets the chatGetResponse_nextCursorMember1 property value. Composed type representation for type ChatGetResponseNextCursorMember1
143 144 145 |
# File 'lib/teambattles_sdk/generated/matches/item/chat/chat_get_response.rb', line 143 def chat_get_response_next_cursor_member1=(value) @chat_get_response_next_cursor_member1 = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
159 160 161 162 163 164 |
# File 'lib/teambattles_sdk/generated/matches/item/chat/chat_get_response.rb', line 159 def get_field_deserializers() return { "chatGetResponse_nextCursorMember1" => lambda {|n| @chat_get_response_next_cursor_member1 = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Matches::Item::Chat::ChatGetResponseNextCursorMember1.create_from_discriminator_value(pn) }) }, "string" => lambda {|n| @string = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
170 171 172 173 174 |
# File 'lib/teambattles_sdk/generated/matches/item/chat/chat_get_response.rb', line 170 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("chatGetResponse_nextCursorMember1", @chat_get_response_next_cursor_member1) writer.write_string_value("string", @string) end |
#string ⇒ Object
Gets the string property value. Composed type representation for type string
179 180 181 |
# File 'lib/teambattles_sdk/generated/matches/item/chat/chat_get_response.rb', line 179 def string return @string end |
#string=(value) ⇒ Object
Sets the string property value. Composed type representation for type string
187 188 189 |
# File 'lib/teambattles_sdk/generated/matches/item/chat/chat_get_response.rb', line 187 def string=(value) @string = value end |