Class: TeamBattlesSdk::Generated::Models::ApiGameCatalogResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::ApiGameCatalogResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/api_game_catalog_response.rb
Overview
Game catalog list response.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#games ⇒ Object
Gets the games property value.
-
#games=(value) ⇒ Object
Sets the games property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#objectives ⇒ Object
Gets the objectives property value.
-
#objectives=(value) ⇒ Object
Sets the objectives property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
26 27 28 29 |
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_response.rb', line 26 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ApiGameCatalogResponse.new end |
Instance Method Details
#games ⇒ Object
Gets the games property value. The games property
34 35 36 |
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_response.rb', line 34 def games return @games end |
#games=(value) ⇒ Object
Sets the games property value. The games property
42 43 44 |
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_response.rb', line 42 def games=(value) @games = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
49 50 51 52 53 54 55 |
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_response.rb', line 49 def get_field_deserializers() return { "games" => lambda {|n| @games = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiGameCatalogEntry.create_from_discriminator_value(pn) }) }, "objectives" => lambda {|n| @objectives = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiObjective.create_from_discriminator_value(pn) }) }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, } end |
#objectives ⇒ Object
Gets the objectives property value. The objectives property
60 61 62 |
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_response.rb', line 60 def objectives return @objectives end |
#objectives=(value) ⇒ Object
Sets the objectives property value. The objectives property
68 69 70 |
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_response.rb', line 68 def objectives=(value) @objectives = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
76 77 78 79 80 81 |
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_response.rb', line 76 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_collection_of_object_values("games", @games) writer.write_collection_of_object_values("objectives", @objectives) writer.write_string_value("timestamp", @timestamp) end |
#timestamp ⇒ Object
Gets the timestamp property value. The timestamp property
86 87 88 |
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_response.rb', line 86 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. The timestamp property
94 95 96 |
# File 'lib/teambattles_sdk/generated/models/api_game_catalog_response.rb', line 94 def (value) @timestamp = value end |