Class: TeamBattlesSdk::Generated::Models::ApiGamePlaylist
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::ApiGamePlaylist
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/api_game_playlist.rb
Overview
Game-scoped playlist definition.
Defined Under Namespace
Classes: ApiGamePlaylistDescriptionKey, ApiGamePlaylistImage
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#allowed_game_mode_ids ⇒ Object
Gets the allowedGameModeIds property value.
-
#allowed_game_mode_ids=(value) ⇒ Object
Sets the allowedGameModeIds property value.
-
#description_key ⇒ Object
Gets the descriptionKey property value.
-
#description_key=(value) ⇒ Object
Sets the descriptionKey property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#id ⇒ Object
Gets the id property value.
-
#id=(value) ⇒ Object
Sets the id property value.
-
#image ⇒ Object
Gets the image property value.
-
#image=(value) ⇒ Object
Sets the image property value.
-
#name_key ⇒ Object
Gets the nameKey property value.
-
#name_key=(value) ⇒ Object
Sets the nameKey property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
47 48 49 50 |
# File 'lib/teambattles_sdk/generated/models/api_game_playlist.rb', line 47 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ApiGamePlaylist.new end |
Instance Method Details
#allowed_game_mode_ids ⇒ Object
Gets the allowedGameModeIds property value. The allowedGameModeIds property
31 32 33 |
# File 'lib/teambattles_sdk/generated/models/api_game_playlist.rb', line 31 def allowed_game_mode_ids return @allowed_game_mode_ids end |
#allowed_game_mode_ids=(value) ⇒ Object
Sets the allowedGameModeIds property value. The allowedGameModeIds property
39 40 41 |
# File 'lib/teambattles_sdk/generated/models/api_game_playlist.rb', line 39 def allowed_game_mode_ids=(value) @allowed_game_mode_ids = value end |
#description_key ⇒ Object
Gets the descriptionKey property value. The descriptionKey property
55 56 57 |
# File 'lib/teambattles_sdk/generated/models/api_game_playlist.rb', line 55 def description_key return @description_key end |
#description_key=(value) ⇒ Object
Sets the descriptionKey property value. The descriptionKey property
63 64 65 |
# File 'lib/teambattles_sdk/generated/models/api_game_playlist.rb', line 63 def description_key=(value) @description_key = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
70 71 72 73 74 75 76 77 78 |
# File 'lib/teambattles_sdk/generated/models/api_game_playlist.rb', line 70 def get_field_deserializers() return { "allowedGameModeIds" => lambda {|n| @allowed_game_mode_ids = n.get_collection_of_primitive_values(String) }, "descriptionKey" => lambda {|n| @description_key = n.get_object_value(lambda {|pn| ApiGamePlaylist::ApiGamePlaylistDescriptionKey.create_from_discriminator_value(pn) }) }, "id" => lambda {|n| @id = n.get_string_value() }, "image" => lambda {|n| @image = n.get_object_value(lambda {|pn| ApiGamePlaylist::ApiGamePlaylistImage.create_from_discriminator_value(pn) }) }, "nameKey" => lambda {|n| @name_key = n.get_string_value() }, } end |
#id ⇒ Object
Gets the id property value. The id property
83 84 85 |
# File 'lib/teambattles_sdk/generated/models/api_game_playlist.rb', line 83 def id return @id end |
#id=(value) ⇒ Object
Sets the id property value. The id property
91 92 93 |
# File 'lib/teambattles_sdk/generated/models/api_game_playlist.rb', line 91 def id=(value) @id = value end |
#image ⇒ Object
Gets the image property value. The image property
98 99 100 |
# File 'lib/teambattles_sdk/generated/models/api_game_playlist.rb', line 98 def image return @image end |
#image=(value) ⇒ Object
Sets the image property value. The image property
106 107 108 |
# File 'lib/teambattles_sdk/generated/models/api_game_playlist.rb', line 106 def image=(value) @image = value end |
#name_key ⇒ Object
Gets the nameKey property value. The nameKey property
113 114 115 |
# File 'lib/teambattles_sdk/generated/models/api_game_playlist.rb', line 113 def name_key return @name_key end |
#name_key=(value) ⇒ Object
Sets the nameKey property value. The nameKey property
121 122 123 |
# File 'lib/teambattles_sdk/generated/models/api_game_playlist.rb', line 121 def name_key=(value) @name_key = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
129 130 131 132 133 134 135 136 |
# File 'lib/teambattles_sdk/generated/models/api_game_playlist.rb', line 129 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_collection_of_primitive_values("allowedGameModeIds", @allowed_game_mode_ids) writer.write_object_value("descriptionKey", @description_key) writer.write_string_value("id", @id) writer.write_object_value("image", @image) writer.write_string_value("nameKey", @name_key) end |