Class: TeamBattlesSdk::Generated::Models::ApiUserConnection
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::ApiUserConnection
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/api_user_connection.rb
Overview
API-safe public account connection.
Defined Under Namespace
Classes: ApiUserConnectionConnectedAt, ApiUserConnectionUrl, ApiUserConnectionUsername
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#connected_at ⇒ Object
Gets the connectedAt property value.
-
#connected_at=(value) ⇒ Object
Sets the connectedAt property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#id ⇒ Object
Gets the id property value.
-
#id=(value) ⇒ Object
Sets the id property value.
-
#is_primary ⇒ Object
Gets the isPrimary property value.
-
#is_primary=(value) ⇒ Object
Sets the isPrimary property value.
-
#is_verified ⇒ Object
Gets the isVerified property value.
-
#is_verified=(value) ⇒ Object
Sets the isVerified property value.
-
#platform ⇒ Object
Gets the platform property value.
-
#platform=(value) ⇒ Object
Sets the platform property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#url ⇒ Object
Gets the url property value.
-
#url=(value) ⇒ Object
Sets the url property value.
-
#username ⇒ Object
Gets the username property value.
-
#username=(value) ⇒ Object
Sets the username property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
53 54 55 56 |
# File 'lib/teambattles_sdk/generated/models/api_user_connection.rb', line 53 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ApiUserConnection.new end |
Instance Method Details
#connected_at ⇒ Object
Gets the connectedAt property value. The connectedAt property
37 38 39 |
# File 'lib/teambattles_sdk/generated/models/api_user_connection.rb', line 37 def connected_at return @connected_at end |
#connected_at=(value) ⇒ Object
Sets the connectedAt property value. The connectedAt property
45 46 47 |
# File 'lib/teambattles_sdk/generated/models/api_user_connection.rb', line 45 def connected_at=(value) @connected_at = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/teambattles_sdk/generated/models/api_user_connection.rb', line 61 def get_field_deserializers() return { "connectedAt" => lambda {|n| @connected_at = n.get_object_value(lambda {|pn| ApiUserConnection::ApiUserConnectionConnectedAt.create_from_discriminator_value(pn) }) }, "id" => lambda {|n| @id = n.get_string_value() }, "isPrimary" => lambda {|n| @is_primary = n.get_boolean_value() }, "isVerified" => lambda {|n| @is_verified = n.get_boolean_value() }, "platform" => lambda {|n| @platform = n.get_string_value() }, "url" => lambda {|n| @url = n.get_object_value(lambda {|pn| ApiUserConnection::ApiUserConnectionUrl.create_from_discriminator_value(pn) }) }, "username" => lambda {|n| @username = n.get_object_value(lambda {|pn| ApiUserConnection::ApiUserConnectionUsername.create_from_discriminator_value(pn) }) }, } end |
#id ⇒ Object
Gets the id property value. Connection ID.
76 77 78 |
# File 'lib/teambattles_sdk/generated/models/api_user_connection.rb', line 76 def id return @id end |
#id=(value) ⇒ Object
Sets the id property value. Connection ID.
84 85 86 |
# File 'lib/teambattles_sdk/generated/models/api_user_connection.rb', line 84 def id=(value) @id = value end |
#is_primary ⇒ Object
Gets the isPrimary property value. The isPrimary property
91 92 93 |
# File 'lib/teambattles_sdk/generated/models/api_user_connection.rb', line 91 def is_primary return @is_primary end |
#is_primary=(value) ⇒ Object
Sets the isPrimary property value. The isPrimary property
99 100 101 |
# File 'lib/teambattles_sdk/generated/models/api_user_connection.rb', line 99 def is_primary=(value) @is_primary = value end |
#is_verified ⇒ Object
Gets the isVerified property value. The isVerified property
106 107 108 |
# File 'lib/teambattles_sdk/generated/models/api_user_connection.rb', line 106 def is_verified return @is_verified end |
#is_verified=(value) ⇒ Object
Sets the isVerified property value. The isVerified property
114 115 116 |
# File 'lib/teambattles_sdk/generated/models/api_user_connection.rb', line 114 def is_verified=(value) @is_verified = value end |
#platform ⇒ Object
Gets the platform property value. Connected platform.
121 122 123 |
# File 'lib/teambattles_sdk/generated/models/api_user_connection.rb', line 121 def platform return @platform end |
#platform=(value) ⇒ Object
Sets the platform property value. Connected platform.
129 130 131 |
# File 'lib/teambattles_sdk/generated/models/api_user_connection.rb', line 129 def platform=(value) @platform = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
137 138 139 140 141 142 143 144 145 146 |
# File 'lib/teambattles_sdk/generated/models/api_user_connection.rb', line 137 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("connectedAt", @connected_at) writer.write_string_value("id", @id) writer.write_boolean_value("isPrimary", @is_primary) writer.write_boolean_value("isVerified", @is_verified) writer.write_string_value("platform", @platform) writer.write_object_value("url", @url) writer.write_object_value("username", @username) end |
#url ⇒ Object
Gets the url property value. The url property
151 152 153 |
# File 'lib/teambattles_sdk/generated/models/api_user_connection.rb', line 151 def url return @url end |
#url=(value) ⇒ Object
Sets the url property value. The url property
159 160 161 |
# File 'lib/teambattles_sdk/generated/models/api_user_connection.rb', line 159 def url=(value) @url = value end |
#username ⇒ Object
Gets the username property value. The username property
166 167 168 |
# File 'lib/teambattles_sdk/generated/models/api_user_connection.rb', line 166 def username return @username end |
#username=(value) ⇒ Object
Sets the username property value. The username property
174 175 176 |
# File 'lib/teambattles_sdk/generated/models/api_user_connection.rb', line 174 def username=(value) @username = value end |