Class: TeamBattlesSdk::Generated::Models::GameForfeitResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::GameForfeitResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/game_forfeit_response.rb
Overview
Result of a successful match forfeit.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#forfeited_by_team_id ⇒ Object
Gets the forfeitedByTeamId property value.
-
#forfeited_by_team_id=(value) ⇒ Object
Sets the forfeitedByTeamId property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#match_id ⇒ Object
Gets the matchId property value.
-
#match_id=(value) ⇒ Object
Sets the matchId property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#success ⇒ Object
Gets the success property value.
-
#success=(value) ⇒ Object
Sets the success property value.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
29 30 31 32 |
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 29 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return GameForfeitResponse.new end |
Instance Method Details
#forfeited_by_team_id ⇒ Object
Gets the forfeitedByTeamId property value. ID of the team that forfeited.
37 38 39 |
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 37 def forfeited_by_team_id return @forfeited_by_team_id end |
#forfeited_by_team_id=(value) ⇒ Object
Sets the forfeitedByTeamId property value. ID of the team that forfeited.
45 46 47 |
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 45 def forfeited_by_team_id=(value) @forfeited_by_team_id = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
52 53 54 55 56 57 58 59 |
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 52 def get_field_deserializers() return { "forfeitedByTeamId" => lambda {|n| @forfeited_by_team_id = n.get_string_value() }, "matchId" => lambda {|n| @match_id = n.get_string_value() }, "success" => lambda {|n| @success = n.get_boolean_value() }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, } end |
#match_id ⇒ Object
Gets the matchId property value. ID of the forfeited match.
64 65 66 |
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 64 def match_id return @match_id end |
#match_id=(value) ⇒ Object
Sets the matchId property value. ID of the forfeited match.
72 73 74 |
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 72 def match_id=(value) @match_id = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
80 81 82 83 84 85 86 |
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 80 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("forfeitedByTeamId", @forfeited_by_team_id) writer.write_string_value("matchId", @match_id) writer.write_boolean_value("success", @success) writer.write_string_value("timestamp", @timestamp) end |
#success ⇒ Object
Gets the success property value. The success property
91 92 93 |
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 91 def success return @success end |
#success=(value) ⇒ Object
Sets the success property value. The success property
99 100 101 |
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 99 def success=(value) @success = value end |
#timestamp ⇒ Object
Gets the timestamp property value. Server response time (ISO 8601).
106 107 108 |
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 106 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. Server response time (ISO 8601).
114 115 116 |
# File 'lib/teambattles_sdk/generated/models/game_forfeit_response.rb', line 114 def (value) @timestamp = value end |