Class: TeamBattlesSdk::Generated::Models::GameMapScoreInput
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::GameMapScoreInput
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/game_map_score_input.rb
Overview
One map’s score within a batch submission.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#creator_team_score ⇒ Object
Gets the creatorTeamScore property value.
-
#creator_team_score=(value) ⇒ Object
Sets the creatorTeamScore property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new GameMapScoreInput and sets the default values.
-
#map_id ⇒ Object
Gets the mapId property value.
-
#map_id=(value) ⇒ Object
Sets the mapId property value.
-
#map_index ⇒ Object
Gets the mapIndex property value.
-
#map_index=(value) ⇒ Object
Sets the mapIndex property value.
-
#opponent_team_score ⇒ Object
Gets the opponentTeamScore property value.
-
#opponent_team_score=(value) ⇒ Object
Sets the opponentTeamScore property value.
-
#player_stats ⇒ Object
Gets the playerStats property value.
-
#player_stats=(value) ⇒ Object
Sets the playerStats property value.
-
#screenshot_storage_ids ⇒ Object
Gets the screenshotStorageIds property value.
-
#screenshot_storage_ids=(value) ⇒ Object
Sets the screenshotStorageIds property value.
-
#screenshot_urls ⇒ Object
Gets the screenshotUrls property value.
-
#screenshot_urls=(value) ⇒ Object
Sets the screenshotUrls property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Constructor Details
#initialize ⇒ Object
Instantiates a new GameMapScoreInput and sets the default values.
55 56 57 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 55 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
63 64 65 66 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 63 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return GameMapScoreInput.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
40 41 42 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 40 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
48 49 50 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 48 def additional_data=(value) @additional_data = value end |
#creator_team_score ⇒ Object
Gets the creatorTeamScore property value. Score for the creator team (integer, 0-1000).
71 72 73 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 71 def creator_team_score return @creator_team_score end |
#creator_team_score=(value) ⇒ Object
Sets the creatorTeamScore property value. Score for the creator team (integer, 0-1000).
79 80 81 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 79 def creator_team_score=(value) @creator_team_score = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 86 def get_field_deserializers() return { "creatorTeamScore" => lambda {|n| @creator_team_score = n.get_number_value() }, "mapId" => lambda {|n| @map_id = n.get_string_value() }, "mapIndex" => lambda {|n| @map_index = n.get_number_value() }, "opponentTeamScore" => lambda {|n| @opponent_team_score = n.get_number_value() }, "playerStats" => lambda {|n| @player_stats = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::GameMapScoreInputPlayerStats.create_from_discriminator_value(pn) }) }, "screenshotStorageIds" => lambda {|n| @screenshot_storage_ids = n.get_collection_of_primitive_values(String) }, "screenshotUrls" => lambda {|n| @screenshot_urls = n.get_collection_of_primitive_values(String) }, } end |
#map_id ⇒ Object
Gets the mapId property value. Identifier of the map that was played.
101 102 103 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 101 def map_id return @map_id end |
#map_id=(value) ⇒ Object
Sets the mapId property value. Identifier of the map that was played.
109 110 111 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 109 def map_id=(value) @map_id = value end |
#map_index ⇒ Object
Gets the mapIndex property value. Zero-based index of the map within the series.
116 117 118 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 116 def map_index return @map_index end |
#map_index=(value) ⇒ Object
Sets the mapIndex property value. Zero-based index of the map within the series.
124 125 126 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 124 def map_index=(value) @map_index = value end |
#opponent_team_score ⇒ Object
Gets the opponentTeamScore property value. Score for the opponent (accepted) team (integer, 0-1000).
131 132 133 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 131 def opponent_team_score return @opponent_team_score end |
#opponent_team_score=(value) ⇒ Object
Sets the opponentTeamScore property value. Score for the opponent (accepted) team (integer, 0-1000).
139 140 141 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 139 def opponent_team_score=(value) @opponent_team_score = value end |
#player_stats ⇒ Object
Gets the playerStats property value. Optional per-player stats keyed by user ID.
146 147 148 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 146 def player_stats return @player_stats end |
#player_stats=(value) ⇒ Object
Sets the playerStats property value. Optional per-player stats keyed by user ID.
154 155 156 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 154 def player_stats=(value) @player_stats = value end |
#screenshot_storage_ids ⇒ Object
Gets the screenshotStorageIds property value. Optional storage IDs for screenshots uploaded via POST /uploads/image-url. Preferred over screenshotUrls: each is validated (size, content-type, ownership) and resolved to a URL server-side.
161 162 163 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 161 def screenshot_storage_ids return @screenshot_storage_ids end |
#screenshot_storage_ids=(value) ⇒ Object
Sets the screenshotStorageIds property value. Optional storage IDs for screenshots uploaded via POST /uploads/image-url. Preferred over screenshotUrls: each is validated (size, content-type, ownership) and resolved to a URL server-side.
169 170 171 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 169 def screenshot_storage_ids=(value) @screenshot_storage_ids = value end |
#screenshot_urls ⇒ Object
Gets the screenshotUrls property value. Optional external screenshot URLs supporting the reported score. Each must be a public https URL. Prefer screenshotStorageIds (validated blobs) where possible.
176 177 178 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 176 def screenshot_urls return @screenshot_urls end |
#screenshot_urls=(value) ⇒ Object
Sets the screenshotUrls property value. Optional external screenshot URLs supporting the reported score. Each must be a public https URL. Prefer screenshotStorageIds (validated blobs) where possible.
184 185 186 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 184 def screenshot_urls=(value) @screenshot_urls = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/teambattles_sdk/generated/models/game_map_score_input.rb', line 192 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("creatorTeamScore", @creator_team_score) writer.write_string_value("mapId", @map_id) writer.write_number_value("mapIndex", @map_index) writer.write_number_value("opponentTeamScore", @opponent_team_score) writer.write_object_value("playerStats", @player_stats) writer.write_collection_of_primitive_values("screenshotStorageIds", @screenshot_storage_ids) writer.write_collection_of_primitive_values("screenshotUrls", @screenshot_urls) writer.write_additional_data(@additional_data) end |