Class: TeamBattlesSdk::Generated::Models::GameMatchDetail::GameMatchDetailLeagueSeasonId
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::GameMatchDetail::GameMatchDetailLeagueSeasonId
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/game_match_detail.rb
Overview
Composed type wrapper for classes GameMatchDetailLeagueSeasonIdMember1, string
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#game_match_detail_league_season_id_member1 ⇒ Object
Gets the GameMatchDetail_leagueSeasonIdMember1 property value.
-
#game_match_detail_league_season_id_member1=(value) ⇒ Object
Sets the GameMatchDetail_leagueSeasonIdMember1 property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#string ⇒ Object
Gets the string property value.
-
#string=(value) ⇒ Object
Sets the string property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
748 749 750 751 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 748 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return GameMatchDetailLeagueSeasonId.new end |
Instance Method Details
#game_match_detail_league_season_id_member1 ⇒ Object
Gets the GameMatchDetail_leagueSeasonIdMember1 property value. Composed type representation for type GameMatchDetailLeagueSeasonIdMember1
756 757 758 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 756 def game_match_detail_league_season_id_member1 return @game_match_detail_league_season_id_member1 end |
#game_match_detail_league_season_id_member1=(value) ⇒ Object
Sets the GameMatchDetail_leagueSeasonIdMember1 property value. Composed type representation for type GameMatchDetailLeagueSeasonIdMember1
764 765 766 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 764 def game_match_detail_league_season_id_member1=(value) @game_match_detail_league_season_id_member1 = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
771 772 773 774 775 776 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 771 def get_field_deserializers() return { "GameMatchDetail_leagueSeasonIdMember1" => lambda {|n| @game_match_detail_league_season_id_member1 = n.get_object_value(lambda {|pn| TeamBattlesSdk::Generated::Models::GameMatchDetailLeagueSeasonIdMember1.create_from_discriminator_value(pn) }) }, "string" => lambda {|n| @string = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
782 783 784 785 786 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 782 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("GameMatchDetail_leagueSeasonIdMember1", @game_match_detail_league_season_id_member1) writer.write_string_value("string", @string) end |
#string ⇒ Object
Gets the string property value. Composed type representation for type string
791 792 793 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 791 def string return @string end |
#string=(value) ⇒ Object
Sets the string property value. Composed type representation for type string
799 800 801 |
# File 'lib/teambattles_sdk/generated/models/game_match_detail.rb', line 799 def string=(value) @string = value end |