Class: TeamBattlesSdk::Generated::Models::LeagueBrandingSocials
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::LeagueBrandingSocials
- Includes:
- MicrosoftKiotaAbstractions::AdditionalDataHolder, MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/league_branding_socials.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#additional_data ⇒ Object
Gets the AdditionalData property value.
-
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value.
-
#discord ⇒ Object
Gets the discord property value.
-
#discord=(value) ⇒ Object
Sets the discord property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#initialize ⇒ Object
constructor
Instantiates a new LeagueBrandingSocials and sets the default values.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#twitch ⇒ Object
Gets the twitch property value.
-
#twitch=(value) ⇒ Object
Sets the twitch property value.
-
#twitter ⇒ Object
Gets the twitter property value.
-
#twitter=(value) ⇒ Object
Sets the twitter property value.
-
#website ⇒ Object
Gets the website property value.
-
#website=(value) ⇒ Object
Sets the website property value.
-
#youtube ⇒ Object
Gets the youtube property value.
-
#youtube=(value) ⇒ Object
Sets the youtube property value.
Constructor Details
#initialize ⇒ Object
Instantiates a new LeagueBrandingSocials and sets the default values.
47 48 49 |
# File 'lib/teambattles_sdk/generated/models/league_branding_socials.rb', line 47 def initialize() @additional_data = Hash.new end |
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
55 56 57 58 |
# File 'lib/teambattles_sdk/generated/models/league_branding_socials.rb', line 55 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return LeagueBrandingSocials.new end |
Instance Method Details
#additional_data ⇒ Object
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
32 33 34 |
# File 'lib/teambattles_sdk/generated/models/league_branding_socials.rb', line 32 def additional_data return @additional_data end |
#additional_data=(value) ⇒ Object
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
40 41 42 |
# File 'lib/teambattles_sdk/generated/models/league_branding_socials.rb', line 40 def additional_data=(value) @additional_data = value end |
#discord ⇒ Object
Gets the discord property value. The discord property
63 64 65 |
# File 'lib/teambattles_sdk/generated/models/league_branding_socials.rb', line 63 def discord return @discord end |
#discord=(value) ⇒ Object
Sets the discord property value. The discord property
71 72 73 |
# File 'lib/teambattles_sdk/generated/models/league_branding_socials.rb', line 71 def discord=(value) @discord = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
78 79 80 81 82 83 84 85 86 |
# File 'lib/teambattles_sdk/generated/models/league_branding_socials.rb', line 78 def get_field_deserializers() return { "discord" => lambda {|n| @discord = n.get_string_value() }, "twitch" => lambda {|n| @twitch = n.get_string_value() }, "twitter" => lambda {|n| @twitter = n.get_string_value() }, "website" => lambda {|n| @website = n.get_string_value() }, "youtube" => lambda {|n| @youtube = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
92 93 94 95 96 97 98 99 100 |
# File 'lib/teambattles_sdk/generated/models/league_branding_socials.rb', line 92 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("discord", @discord) writer.write_string_value("twitch", @twitch) writer.write_string_value("twitter", @twitter) writer.write_string_value("website", @website) writer.write_string_value("youtube", @youtube) writer.write_additional_data(@additional_data) end |
#twitch ⇒ Object
Gets the twitch property value. The twitch property
105 106 107 |
# File 'lib/teambattles_sdk/generated/models/league_branding_socials.rb', line 105 def twitch return @twitch end |
#twitch=(value) ⇒ Object
Sets the twitch property value. The twitch property
113 114 115 |
# File 'lib/teambattles_sdk/generated/models/league_branding_socials.rb', line 113 def twitch=(value) @twitch = value end |
#twitter ⇒ Object
Gets the twitter property value. The twitter property
120 121 122 |
# File 'lib/teambattles_sdk/generated/models/league_branding_socials.rb', line 120 def twitter return @twitter end |
#twitter=(value) ⇒ Object
Sets the twitter property value. The twitter property
128 129 130 |
# File 'lib/teambattles_sdk/generated/models/league_branding_socials.rb', line 128 def twitter=(value) @twitter = value end |
#website ⇒ Object
Gets the website property value. The website property
135 136 137 |
# File 'lib/teambattles_sdk/generated/models/league_branding_socials.rb', line 135 def website return @website end |
#website=(value) ⇒ Object
Sets the website property value. The website property
143 144 145 |
# File 'lib/teambattles_sdk/generated/models/league_branding_socials.rb', line 143 def website=(value) @website = value end |
#youtube ⇒ Object
Gets the youtube property value. The youtube property
150 151 152 |
# File 'lib/teambattles_sdk/generated/models/league_branding_socials.rb', line 150 def youtube return @youtube end |
#youtube=(value) ⇒ Object
Sets the youtube property value. The youtube property
158 159 160 |
# File 'lib/teambattles_sdk/generated/models/league_branding_socials.rb', line 158 def youtube=(value) @youtube = value end |