Class: TeamBattlesSdk::Generated::Models::LeagueDashboardStatsResponseStats
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::LeagueDashboardStatsResponseStats
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/league_dashboard_stats_response_stats.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#active_seasons ⇒ Object
Gets the activeSeasons property value.
-
#active_seasons=(value) ⇒ Object
Sets the activeSeasons property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#open_tickets ⇒ Object
Gets the openTickets property value.
-
#open_tickets=(value) ⇒ Object
Sets the openTickets property value.
-
#pending_applications ⇒ Object
Gets the pendingApplications property value.
-
#pending_applications=(value) ⇒ Object
Sets the pendingApplications property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#team_count ⇒ Object
Gets the teamCount property value.
-
#team_count=(value) ⇒ Object
Sets the teamCount property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
42 43 44 45 |
# File 'lib/teambattles_sdk/generated/models/league_dashboard_stats_response_stats.rb', line 42 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return LeagueDashboardStatsResponseStats.new end |
Instance Method Details
#active_seasons ⇒ Object
Gets the activeSeasons property value. The activeSeasons property
26 27 28 |
# File 'lib/teambattles_sdk/generated/models/league_dashboard_stats_response_stats.rb', line 26 def active_seasons return @active_seasons end |
#active_seasons=(value) ⇒ Object
Sets the activeSeasons property value. The activeSeasons property
34 35 36 |
# File 'lib/teambattles_sdk/generated/models/league_dashboard_stats_response_stats.rb', line 34 def active_seasons=(value) @active_seasons = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
50 51 52 53 54 55 56 57 |
# File 'lib/teambattles_sdk/generated/models/league_dashboard_stats_response_stats.rb', line 50 def get_field_deserializers() return { "activeSeasons" => lambda {|n| @active_seasons = n.get_number_value() }, "openTickets" => lambda {|n| @open_tickets = n.get_number_value() }, "pendingApplications" => lambda {|n| @pending_applications = n.get_number_value() }, "teamCount" => lambda {|n| @team_count = n.get_number_value() }, } end |
#open_tickets ⇒ Object
Gets the openTickets property value. The openTickets property
62 63 64 |
# File 'lib/teambattles_sdk/generated/models/league_dashboard_stats_response_stats.rb', line 62 def open_tickets return @open_tickets end |
#open_tickets=(value) ⇒ Object
Sets the openTickets property value. The openTickets property
70 71 72 |
# File 'lib/teambattles_sdk/generated/models/league_dashboard_stats_response_stats.rb', line 70 def open_tickets=(value) @open_tickets = value end |
#pending_applications ⇒ Object
Gets the pendingApplications property value. The pendingApplications property
77 78 79 |
# File 'lib/teambattles_sdk/generated/models/league_dashboard_stats_response_stats.rb', line 77 def pending_applications return @pending_applications end |
#pending_applications=(value) ⇒ Object
Sets the pendingApplications property value. The pendingApplications property
85 86 87 |
# File 'lib/teambattles_sdk/generated/models/league_dashboard_stats_response_stats.rb', line 85 def pending_applications=(value) @pending_applications = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
93 94 95 96 97 98 99 |
# File 'lib/teambattles_sdk/generated/models/league_dashboard_stats_response_stats.rb', line 93 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("activeSeasons", @active_seasons) writer.write_number_value("openTickets", @open_tickets) writer.write_number_value("pendingApplications", @pending_applications) writer.write_number_value("teamCount", @team_count) end |
#team_count ⇒ Object
Gets the teamCount property value. The teamCount property
104 105 106 |
# File 'lib/teambattles_sdk/generated/models/league_dashboard_stats_response_stats.rb', line 104 def team_count return @team_count end |
#team_count=(value) ⇒ Object
Sets the teamCount property value. The teamCount property
112 113 114 |
# File 'lib/teambattles_sdk/generated/models/league_dashboard_stats_response_stats.rb', line 112 def team_count=(value) @team_count = value end |