Class: TeamBattlesSdk::Generated::Models::LeagueGames
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::LeagueGames
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/league_games.rb
Overview
Games configured for a league.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#count ⇒ Object
Gets the count property value.
-
#count=(value) ⇒ Object
Sets the count property value.
-
#games ⇒ Object
Gets the games property value.
-
#games=(value) ⇒ Object
Sets the games property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
41 42 43 44 |
# File 'lib/teambattles_sdk/generated/models/league_games.rb', line 41 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return LeagueGames.new end |
Instance Method Details
#count ⇒ Object
Gets the count property value. Number of configured games returned.
25 26 27 |
# File 'lib/teambattles_sdk/generated/models/league_games.rb', line 25 def count return @count end |
#count=(value) ⇒ Object
Sets the count property value. Number of configured games returned.
33 34 35 |
# File 'lib/teambattles_sdk/generated/models/league_games.rb', line 33 def count=(value) @count = value end |
#games ⇒ Object
Gets the games property value. Games configured for the league.
49 50 51 |
# File 'lib/teambattles_sdk/generated/models/league_games.rb', line 49 def games return @games end |
#games=(value) ⇒ Object
Sets the games property value. Games configured for the league.
57 58 59 |
# File 'lib/teambattles_sdk/generated/models/league_games.rb', line 57 def games=(value) @games = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
64 65 66 67 68 69 70 |
# File 'lib/teambattles_sdk/generated/models/league_games.rb', line 64 def get_field_deserializers() return { "count" => lambda {|n| @count = n.get_number_value() }, "games" => lambda {|n| @games = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::LeagueGamesGames.create_from_discriminator_value(pn) }) }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
76 77 78 79 80 81 |
# File 'lib/teambattles_sdk/generated/models/league_games.rb', line 76 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_number_value("count", @count) writer.write_collection_of_object_values("games", @games) writer.write_string_value("timestamp", @timestamp) end |
#timestamp ⇒ Object
Gets the timestamp property value. Response generation time (ISO 8601).
86 87 88 |
# File 'lib/teambattles_sdk/generated/models/league_games.rb', line 86 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. Response generation time (ISO 8601).
94 95 96 |
# File 'lib/teambattles_sdk/generated/models/league_games.rb', line 94 def (value) @timestamp = value end |