Class: TeamBattlesSdk::Generated::Models::OngoingMatchesResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::OngoingMatchesResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/ongoing_matches_response.rb
Overview
Ongoing matches for the API key owner’s active teams.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#matches ⇒ Object
Gets the matches property value.
-
#matches=(value) ⇒ Object
Sets the matches property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
23 24 25 26 |
# File 'lib/teambattles_sdk/generated/models/ongoing_matches_response.rb', line 23 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return OngoingMatchesResponse.new end |
Instance Method Details
#get_field_deserializers ⇒ Object
The deserialization information for the current model
31 32 33 34 35 36 |
# File 'lib/teambattles_sdk/generated/models/ongoing_matches_response.rb', line 31 def get_field_deserializers() return { "matches" => lambda {|n| @matches = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiMatchDetail.create_from_discriminator_value(pn) }) }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, } end |
#matches ⇒ Object
Gets the matches property value. The matches property
41 42 43 |
# File 'lib/teambattles_sdk/generated/models/ongoing_matches_response.rb', line 41 def matches return @matches end |
#matches=(value) ⇒ Object
Sets the matches property value. The matches property
49 50 51 |
# File 'lib/teambattles_sdk/generated/models/ongoing_matches_response.rb', line 49 def matches=(value) @matches = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
57 58 59 60 61 |
# File 'lib/teambattles_sdk/generated/models/ongoing_matches_response.rb', line 57 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_collection_of_object_values("matches", @matches) writer.write_string_value("timestamp", @timestamp) end |
#timestamp ⇒ Object
Gets the timestamp property value. The timestamp property
66 67 68 |
# File 'lib/teambattles_sdk/generated/models/ongoing_matches_response.rb', line 66 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. The timestamp property
74 75 76 |
# File 'lib/teambattles_sdk/generated/models/ongoing_matches_response.rb', line 74 def (value) @timestamp = value end |