Class: TeamBattlesSdk::Generated::Models::ScoreConfirmer
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::Models::ScoreConfirmer
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/models/score_confirmer.rb
Overview
Identity of the captain who confirmed a score.
Defined Under Namespace
Classes: ScoreConfirmerConfirmedAt
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#confirmed_at ⇒ Object
Gets the confirmedAt property value.
-
#confirmed_at=(value) ⇒ Object
Sets the confirmedAt property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#team_id ⇒ Object
Gets the teamId property value.
-
#team_id=(value) ⇒ Object
Sets the teamId property value.
-
#user_id ⇒ Object
Gets the userId property value.
-
#user_id=(value) ⇒ Object
Sets the userId property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
41 42 43 44 |
# File 'lib/teambattles_sdk/generated/models/score_confirmer.rb', line 41 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ScoreConfirmer.new end |
Instance Method Details
#confirmed_at ⇒ Object
Gets the confirmedAt property value. Confirmation time (ISO 8601).
25 26 27 |
# File 'lib/teambattles_sdk/generated/models/score_confirmer.rb', line 25 def confirmed_at return @confirmed_at end |
#confirmed_at=(value) ⇒ Object
Sets the confirmedAt property value. Confirmation time (ISO 8601).
33 34 35 |
# File 'lib/teambattles_sdk/generated/models/score_confirmer.rb', line 33 def confirmed_at=(value) @confirmed_at = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
49 50 51 52 53 54 55 |
# File 'lib/teambattles_sdk/generated/models/score_confirmer.rb', line 49 def get_field_deserializers() return { "confirmedAt" => lambda {|n| @confirmed_at = n.get_object_value(lambda {|pn| ScoreConfirmer::ScoreConfirmerConfirmedAt.create_from_discriminator_value(pn) }) }, "teamId" => lambda {|n| @team_id = n.get_string_value() }, "userId" => lambda {|n| @user_id = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
61 62 63 64 65 66 |
# File 'lib/teambattles_sdk/generated/models/score_confirmer.rb', line 61 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_object_value("confirmedAt", @confirmed_at) writer.write_string_value("teamId", @team_id) writer.write_string_value("userId", @user_id) end |
#team_id ⇒ Object
Gets the teamId property value. The teamId property
71 72 73 |
# File 'lib/teambattles_sdk/generated/models/score_confirmer.rb', line 71 def team_id return @team_id end |
#team_id=(value) ⇒ Object
Sets the teamId property value. The teamId property
79 80 81 |
# File 'lib/teambattles_sdk/generated/models/score_confirmer.rb', line 79 def team_id=(value) @team_id = value end |
#user_id ⇒ Object
Gets the userId property value. The userId property
86 87 88 |
# File 'lib/teambattles_sdk/generated/models/score_confirmer.rb', line 86 def user_id return @user_id end |
#user_id=(value) ⇒ Object
Sets the userId property value. The userId property
94 95 96 |
# File 'lib/teambattles_sdk/generated/models/score_confirmer.rb', line 94 def user_id=(value) @user_id = value end |