Class: TeamBattlesSdk::Generated::Orgs::Item::Stats::StatsRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- TeamBattlesSdk::Generated::Orgs::Item::Stats::StatsRequestBuilder
- Defined in:
- lib/teambattles_sdk/generated/orgs/item/stats/stats_request_builder.rb
Overview
Builds and executes requests for operations under #orgs#identifier#stats
Instance Method Summary collapse
-
#get(request_configuration = nil) ⇒ Object
Returns an organization’s aggregate competitive stats by slug or organization ID.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new StatsRequestBuilder and sets the default values.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Returns an organization’s aggregate competitive stats by slug or organization ID.
-
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new StatsRequestBuilder and sets the default values.
23 24 25 |
# File 'lib/teambattles_sdk/generated/orgs/item/stats/stats_request_builder.rb', line 23 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/orgs/{identifier}/stats") end |
Instance Method Details
#get(request_configuration = nil) ⇒ Object
Returns an organization’s aggregate competitive stats by slug or organization ID. Stats are returned when the organization profile is limited or public, or when the API key owner is an active organization member (members can read stats for a private org too); a private organization viewed by a non-member returns 403, and an inactive or unknown organization returns 404. ‘teams` and `members` count only active, enabled teams and active members. `wins`, `losses`, and `matchesPlayed` are aggregated across the organization’s active, enabled teams. ‘winRate` is wins divided by matchesPlayed and is 0 when no matches have been played. Requires orgs.profile:read.
31 32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/teambattles_sdk/generated/orgs/item/stats/stats_request_builder.rb', line 31 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["401"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["403"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["404"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["429"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["500"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| TeamBattlesSdk::Generated::Orgs::Item::Stats::StatsGetResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Returns an organization’s aggregate competitive stats by slug or organization ID. Stats are returned when the organization profile is limited or public, or when the API key owner is an active organization member (members can read stats for a private org too); a private organization viewed by a non-member returns 403, and an inactive or unknown organization returns 404. ‘teams` and `members` count only active, enabled teams and active members. `wins`, `losses`, and `matchesPlayed` are aggregated across the organization’s active, enabled teams. ‘winRate` is wins divided by matchesPlayed and is 0 when no matches have been played. Requires orgs.profile:read.
48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/teambattles_sdk/generated/orgs/item/stats/stats_request_builder.rb', line 48 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.try_add('Accept', 'application/json') return request_info end |
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
65 66 67 68 |
# File 'lib/teambattles_sdk/generated/orgs/item/stats/stats_request_builder.rb', line 65 def with_url(raw_url) raise StandardError, 'raw_url cannot be null' if raw_url.nil? return StatsRequestBuilder.new(raw_url, @request_adapter) end |