Class: TeamBattlesSdk::Generated::Uploads::ImageUrl::ImageUrlRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- TeamBattlesSdk::Generated::Uploads::ImageUrl::ImageUrlRequestBuilder
- Defined in:
- lib/teambattles_sdk/generated/uploads/image_url/image_url_request_builder.rb
Overview
Builds and executes requests for operations under #uploads#image-url
Instance Method Summary collapse
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new ImageUrlRequestBuilder and sets the default values.
-
#post(request_configuration = nil) ⇒ Object
Returns a short-lived, single-use Convex storage upload URL for the API key owner.
-
#to_post_request_information(request_configuration = nil) ⇒ Object
Returns a short-lived, single-use Convex storage upload URL for the API key owner.
-
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new ImageUrlRequestBuilder and sets the default values.
22 23 24 |
# File 'lib/teambattles_sdk/generated/uploads/image_url/image_url_request_builder.rb', line 22 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/uploads/image-url") end |
Instance Method Details
#post(request_configuration = nil) ⇒ Object
Returns a short-lived, single-use Convex storage upload URL for the API key owner. POST the image bytes to the returned URL to receive a storageId, then supply that storageId on a downstream write (e.g. a score-ingest screenshotStorageIds). The owner is always derived from the API key. Requires uploads.upload:read-write and the writes feature (api_pro).
30 31 32 33 34 35 36 37 38 39 40 |
# File 'lib/teambattles_sdk/generated/uploads/image_url/image_url_request_builder.rb', line 30 def post(request_configuration=nil) request_info = self.to_post_request_information( request_configuration ) error_mapping = Hash.new error_mapping["401"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["403"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["429"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["500"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| TeamBattlesSdk::Generated::Models::ImageUploadUrlResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#to_post_request_information(request_configuration = nil) ⇒ Object
Returns a short-lived, single-use Convex storage upload URL for the API key owner. POST the image bytes to the returned URL to receive a storageId, then supply that storageId on a downstream write (e.g. a score-ingest screenshotStorageIds). The owner is always derived from the API key. Requires uploads.upload:read-write and the writes feature (api_pro).
46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/teambattles_sdk/generated/uploads/image_url/image_url_request_builder.rb', line 46 def to_post_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.try_add('Accept', 'application/json') return request_info end |
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
63 64 65 66 |
# File 'lib/teambattles_sdk/generated/uploads/image_url/image_url_request_builder.rb', line 63 def with_url(raw_url) raise StandardError, 'raw_url cannot be null' if raw_url.nil? return ImageUrlRequestBuilder.new(raw_url, @request_adapter) end |