Class: TeamBattlesSdk::Generated::User::Connections::ConnectionsGetResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::User::Connections::ConnectionsGetResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/user/connections/connections_get_response.rb
Overview
Envelope containing connections, count, and a response timestamp.
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#connections ⇒ Object
Gets the connections property value.
-
#connections=(value) ⇒ Object
Sets the connections property value.
-
#count ⇒ Object
Gets the count property value.
-
#count=(value) ⇒ Object
Sets the count property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
-
#timestamp ⇒ Object
Gets the timestamp property value.
-
#timestamp=(value) ⇒ Object
Sets the timestamp property value.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
59 60 61 62 |
# File 'lib/teambattles_sdk/generated/user/connections/connections_get_response.rb', line 59 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return ConnectionsGetResponse.new end |
Instance Method Details
#connections ⇒ Object
Gets the connections property value. The connections property
28 29 30 |
# File 'lib/teambattles_sdk/generated/user/connections/connections_get_response.rb', line 28 def connections return @connections end |
#connections=(value) ⇒ Object
Sets the connections property value. The connections property
36 37 38 |
# File 'lib/teambattles_sdk/generated/user/connections/connections_get_response.rb', line 36 def connections=(value) @connections = value end |
#count ⇒ Object
Gets the count property value. The count property
43 44 45 |
# File 'lib/teambattles_sdk/generated/user/connections/connections_get_response.rb', line 43 def count return @count end |
#count=(value) ⇒ Object
Sets the count property value. The count property
51 52 53 |
# File 'lib/teambattles_sdk/generated/user/connections/connections_get_response.rb', line 51 def count=(value) @count = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
67 68 69 70 71 72 73 |
# File 'lib/teambattles_sdk/generated/user/connections/connections_get_response.rb', line 67 def get_field_deserializers() return { "connections" => lambda {|n| @connections = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::ApiOwnConnection.create_from_discriminator_value(pn) }) }, "count" => lambda {|n| @count = n.get_number_value() }, "timestamp" => lambda {|n| @timestamp = n.get_string_value() }, } end |
#serialize(writer) ⇒ Object
Serializes information the current object
79 80 81 82 83 84 |
# File 'lib/teambattles_sdk/generated/user/connections/connections_get_response.rb', line 79 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_collection_of_object_values("connections", @connections) writer.write_number_value("count", @count) writer.write_string_value("timestamp", @timestamp) end |
#timestamp ⇒ Object
Gets the timestamp property value. ISO 8601 timestamp.
89 90 91 |
# File 'lib/teambattles_sdk/generated/user/connections/connections_get_response.rb', line 89 def return @timestamp end |
#timestamp=(value) ⇒ Object
Sets the timestamp property value. ISO 8601 timestamp.
97 98 99 |
# File 'lib/teambattles_sdk/generated/user/connections/connections_get_response.rb', line 97 def (value) @timestamp = value end |