Class: TeamBattlesSdk::Generated::User::GameRanks::GameRanksRequestBuilder
- Inherits:
-
MicrosoftKiotaAbstractions::BaseRequestBuilder
- Object
- MicrosoftKiotaAbstractions::BaseRequestBuilder
- TeamBattlesSdk::Generated::User::GameRanks::GameRanksRequestBuilder
- Defined in:
- lib/teambattles_sdk/generated/user/game_ranks/game_ranks_request_builder.rb
Overview
Builds and executes requests for operations under #user#game-ranks
Instance Method Summary collapse
-
#by_game_id(game_id) ⇒ Object
Gets an item from the TeamBattlesSdk::Generated.user.gameRanks.item collection.
-
#get(request_configuration = nil) ⇒ Object
Returns every game rank for the API key owner.
-
#initialize(path_parameters, request_adapter) ⇒ Object
constructor
Instantiates a new GameRanksRequestBuilder and sets the default values.
-
#post(body, request_configuration = nil) ⇒ Object
Creates or overwrites the API key owner’s rank for a single (gameId, mode) slot, forcing source to “api”.
-
#to_get_request_information(request_configuration = nil) ⇒ Object
Returns every game rank for the API key owner.
-
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Creates or overwrites the API key owner’s rank for a single (gameId, mode) slot, forcing source to “api”.
-
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL.
Constructor Details
#initialize(path_parameters, request_adapter) ⇒ Object
Instantiates a new GameRanksRequestBuilder and sets the default values.
36 37 38 |
# File 'lib/teambattles_sdk/generated/user/game_ranks/game_ranks_request_builder.rb', line 36 def initialize(path_parameters, request_adapter) super(path_parameters, request_adapter, "{+baseurl}/user/game-ranks") end |
Instance Method Details
#by_game_id(game_id) ⇒ Object
Gets an item from the TeamBattlesSdk::Generated.user.gameRanks.item collection
24 25 26 27 28 29 |
# File 'lib/teambattles_sdk/generated/user/game_ranks/game_ranks_request_builder.rb', line 24 def by_game_id(game_id) raise StandardError, 'game_id cannot be null' if game_id.nil? url_tpl_params = @path_parameters.clone url_tpl_params["gameId"] = game_id return TeamBattlesSdk::Generated::User::GameRanks::Item::WithGameItemRequestBuilder.new(url_tpl_params, @request_adapter) end |
#get(request_configuration = nil) ⇒ Object
Returns every game rank for the API key owner. The user is always derived from the API key. Requires game.ranks:read.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/teambattles_sdk/generated/user/game_ranks/game_ranks_request_builder.rb', line 44 def get(request_configuration=nil) request_info = self.to_get_request_information( request_configuration ) error_mapping = Hash.new error_mapping["401"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["403"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["429"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["500"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| TeamBattlesSdk::Generated::Models::GameRankListResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#post(body, request_configuration = nil) ⇒ Object
Creates or overwrites the API key owner’s rank for a single (gameId, mode) slot, forcing source to “api”. The user is always derived from the API key. Requires game.ranks:read-write and the writes feature (api_pro).
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/teambattles_sdk/generated/user/game_ranks/game_ranks_request_builder.rb', line 61 def post(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = self.to_post_request_information( body, request_configuration ) error_mapping = Hash.new error_mapping["400"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["401"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["403"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["429"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } error_mapping["500"] = lambda {|pn| TeamBattlesSdk::Generated::Models::Error.create_from_discriminator_value(pn) } return @request_adapter.send_async(request_info, lambda {|pn| TeamBattlesSdk::Generated::Models::GameRankUpsertResponse.create_from_discriminator_value(pn) }, error_mapping) end |
#to_get_request_information(request_configuration = nil) ⇒ Object
Returns every game rank for the API key owner. The user is always derived from the API key. Requires game.ranks:read.
79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/teambattles_sdk/generated/user/game_ranks/game_ranks_request_builder.rb', line 79 def to_get_request_information(request_configuration=nil) request_info = MicrosoftKiotaAbstractions::RequestInformation.new() unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :GET request_info.headers.try_add('Accept', 'application/json') return request_info end |
#to_post_request_information(body, request_configuration = nil) ⇒ Object
Creates or overwrites the API key owner’s rank for a single (gameId, mode) slot, forcing source to “api”. The user is always derived from the API key. Requires game.ranks:read-write and the writes feature (api_pro).
97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/teambattles_sdk/generated/user/game_ranks/game_ranks_request_builder.rb', line 97 def to_post_request_information(body, request_configuration=nil) raise StandardError, 'body cannot be null' if body.nil? request_info = MicrosoftKiotaAbstractions::RequestInformation.new() unless request_configuration.nil? request_info.add_headers_from_raw_object(request_configuration.headers) request_info.(request_configuration.) end request_info.set_content_from_parsable(@request_adapter, 'application/json', body) request_info.url_template = @url_template request_info.path_parameters = @path_parameters request_info.http_method = :POST request_info.headers.try_add('Accept', 'application/json') return request_info end |
#with_url(raw_url) ⇒ Object
Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
116 117 118 119 |
# File 'lib/teambattles_sdk/generated/user/game_ranks/game_ranks_request_builder.rb', line 116 def with_url(raw_url) raise StandardError, 'raw_url cannot be null' if raw_url.nil? return GameRanksRequestBuilder.new(raw_url, @request_adapter) end |