Class: TeamBattlesSdk::Generated::User::Matches::MatchesPostResponse
- Inherits:
-
Object
- Object
- TeamBattlesSdk::Generated::User::Matches::MatchesPostResponse
- Includes:
- MicrosoftKiotaAbstractions::Parsable
- Defined in:
- lib/teambattles_sdk/generated/user/matches/matches_post_response.rb
Class Method Summary collapse
-
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value.
Instance Method Summary collapse
-
#continue_cursor ⇒ Object
Gets the continueCursor property value.
-
#continue_cursor=(value) ⇒ Object
Sets the continueCursor property value.
-
#get_field_deserializers ⇒ Object
The deserialization information for the current model.
-
#is_done ⇒ Object
Gets the isDone property value.
-
#is_done=(value) ⇒ Object
Sets the isDone property value.
-
#page ⇒ Object
Gets the page property value.
-
#page=(value) ⇒ Object
Sets the page property value.
-
#serialize(writer) ⇒ Object
Serializes information the current object.
Class Method Details
.create_from_discriminator_value(parse_node) ⇒ Object
Creates a new instance of the appropriate class based on discriminator value
42 43 44 45 |
# File 'lib/teambattles_sdk/generated/user/matches/matches_post_response.rb', line 42 def self.create_from_discriminator_value(parse_node) raise StandardError, 'parse_node cannot be null' if parse_node.nil? return MatchesPostResponse.new end |
Instance Method Details
#continue_cursor ⇒ Object
Gets the continueCursor property value. The continueCursor property
26 27 28 |
# File 'lib/teambattles_sdk/generated/user/matches/matches_post_response.rb', line 26 def continue_cursor return @continue_cursor end |
#continue_cursor=(value) ⇒ Object
Sets the continueCursor property value. The continueCursor property
34 35 36 |
# File 'lib/teambattles_sdk/generated/user/matches/matches_post_response.rb', line 34 def continue_cursor=(value) @continue_cursor = value end |
#get_field_deserializers ⇒ Object
The deserialization information for the current model
50 51 52 53 54 55 56 |
# File 'lib/teambattles_sdk/generated/user/matches/matches_post_response.rb', line 50 def get_field_deserializers() return { "continueCursor" => lambda {|n| @continue_cursor = n.get_string_value() }, "isDone" => lambda {|n| @is_done = n.get_boolean_value() }, "page" => lambda {|n| @page = n.get_collection_of_object_values(lambda {|pn| TeamBattlesSdk::Generated::Models::UserMatch.create_from_discriminator_value(pn) }) }, } end |
#is_done ⇒ Object
Gets the isDone property value. The isDone property
61 62 63 |
# File 'lib/teambattles_sdk/generated/user/matches/matches_post_response.rb', line 61 def is_done return @is_done end |
#is_done=(value) ⇒ Object
Sets the isDone property value. The isDone property
69 70 71 |
# File 'lib/teambattles_sdk/generated/user/matches/matches_post_response.rb', line 69 def is_done=(value) @is_done = value end |
#page ⇒ Object
Gets the page property value. The page property
76 77 78 |
# File 'lib/teambattles_sdk/generated/user/matches/matches_post_response.rb', line 76 def page return @page end |
#page=(value) ⇒ Object
Sets the page property value. The page property
84 85 86 |
# File 'lib/teambattles_sdk/generated/user/matches/matches_post_response.rb', line 84 def page=(value) @page = value end |
#serialize(writer) ⇒ Object
Serializes information the current object
92 93 94 95 96 97 |
# File 'lib/teambattles_sdk/generated/user/matches/matches_post_response.rb', line 92 def serialize(writer) raise StandardError, 'writer cannot be null' if writer.nil? writer.write_string_value("continueCursor", @continue_cursor) writer.write_boolean_value("isDone", @is_done) writer.write_collection_of_object_values("page", @page) end |